(function(){const P=document.createElement("link").relList;if(P&&P.supports&&P.supports("modulepreload"))return;for(const X of document.querySelectorAll('link[rel="modulepreload"]'))m(X);new MutationObserver(X=>{for(const B of X)if(B.type==="childList")for(const tl of B.addedNodes)tl.tagName==="LINK"&&tl.rel==="modulepreload"&&m(tl)}).observe(document,{childList:!0,subtree:!0});function J(X){const B={};return X.integrity&&(B.integrity=X.integrity),X.referrerPolicy&&(B.referrerPolicy=X.referrerPolicy),X.crossOrigin==="use-credentials"?B.credentials="include":X.crossOrigin==="anonymous"?B.credentials="omit":B.credentials="same-origin",B}function m(X){if(X.ep)return;X.ep=!0;const B=J(X);fetch(X.href,B)}})();var kf={exports:{}},me={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var $1;function Rd(){if($1)return me;$1=1;var z=Symbol.for("react.transitional.element"),P=Symbol.for("react.fragment");function J(m,X,B){var tl=null;if(B!==void 0&&(tl=""+B),X.key!==void 0&&(tl=""+X.key),"key"in X){B={};for(var yl in X)yl!=="key"&&(B[yl]=X[yl])}else B=X;return X=B.ref,{$$typeof:z,type:m,key:tl,ref:X!==void 0?X:null,props:B}}return me.Fragment=P,me.jsx=J,me.jsxs=J,me}var k1;function pd(){return k1||(k1=1,kf.exports=Rd()),kf.exports}var N=pd(),Ff={exports:{}},Z={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var F1;function Nd(){if(F1)return Z;F1=1;var z=Symbol.for("react.transitional.element"),P=Symbol.for("react.portal"),J=Symbol.for("react.fragment"),m=Symbol.for("react.strict_mode"),X=Symbol.for("react.profiler"),B=Symbol.for("react.consumer"),tl=Symbol.for("react.context"),yl=Symbol.for("react.forward_ref"),U=Symbol.for("react.suspense"),T=Symbol.for("react.memo"),R=Symbol.for("react.lazy"),w=Symbol.iterator;function q(s){return s===null||typeof s!="object"?null:(s=w&&s[w]||s["@@iterator"],typeof s=="function"?s:null)}var dl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Rl=Object.assign,I={};function ol(s,A,M){this.props=s,this.context=A,this.refs=I,this.updater=M||dl}ol.prototype.isReactComponent={},ol.prototype.setState=function(s,A){if(typeof s!="object"&&typeof s!="function"&&s!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,s,A,"setState")},ol.prototype.forceUpdate=function(s){this.updater.enqueueForceUpdate(this,s,"forceUpdate")};function yt(){}yt.prototype=ol.prototype;function pl(s,A,M){this.props=s,this.context=A,this.refs=I,this.updater=M||dl}var _l=pl.prototype=new yt;_l.constructor=pl,Rl(_l,ol.prototype),_l.isPureReactComponent=!0;var rt=Array.isArray,$={H:null,A:null,T:null,S:null,V:null},Jl=Object.prototype.hasOwnProperty;function wl(s,A,M,_,H,k){return M=k.ref,{$$typeof:z,type:s,key:A,ref:M!==void 0?M:null,props:k}}function Wl(s,A){return wl(s.type,A,void 0,void 0,void 0,s.props)}function bt(s){return typeof s=="object"&&s!==null&&s.$$typeof===z}function Cu(s){var A={"=":"=0",":":"=2"};return"$"+s.replace(/[=:]/g,function(M){return A[M]})}var Mt=/\/+/g;function ql(s,A){return typeof s=="object"&&s!==null&&s.key!=null?Cu(""+s.key):A.toString(36)}function hu(){}function yu(s){switch(s.status){case"fulfilled":return s.value;case"rejected":throw s.reason;default:switch(typeof s.status=="string"?s.then(hu,hu):(s.status="pending",s.then(function(A){s.status==="pending"&&(s.status="fulfilled",s.value=A)},function(A){s.status==="pending"&&(s.status="rejected",s.reason=A)})),s.status){case"fulfilled":return s.value;case"rejected":throw s.reason}}throw s}function xl(s,A,M,_,H){var k=typeof s;(k==="undefined"||k==="boolean")&&(s=null);var G=!1;if(s===null)G=!0;else switch(k){case"bigint":case"string":case"number":G=!0;break;case"object":switch(s.$$typeof){case z:case P:G=!0;break;case R:return G=s._init,xl(G(s._payload),A,M,_,H)}}if(G)return H=H(s),G=_===""?"."+ql(s,0):_,rt(H)?(M="",G!=null&&(M=G.replace(Mt,"$&/")+"/"),xl(H,A,M,"",function(Qt){return Qt})):H!=null&&(bt(H)&&(H=Wl(H,M+(H.key==null||s&&s.key===H.key?"":(""+H.key).replace(Mt,"$&/")+"/")+G)),A.push(H)),1;G=0;var $l=_===""?".":_+":";if(rt(s))for(var vl=0;vl<s.length;vl++)_=s[vl],k=$l+ql(_,vl),G+=xl(_,A,M,k,H);else if(vl=q(s),typeof vl=="function")for(s=vl.call(s),vl=0;!(_=s.next()).done;)_=_.value,k=$l+ql(_,vl++),G+=xl(_,A,M,k,H);else if(k==="object"){if(typeof s.then=="function")return xl(yu(s),A,M,_,H);throw A=String(s),Error("Objects are not valid as a React child (found: "+(A==="[object Object]"?"object with keys {"+Object.keys(s).join(", ")+"}":A)+"). If you meant to render a collection of children, use an array instead.")}return G}function S(s,A,M){if(s==null)return s;var _=[],H=0;return xl(s,_,"","",function(k){return A.call(M,k,H++)}),_}function O(s){if(s._status===-1){var A=s._result;A=A(),A.then(function(M){(s._status===0||s._status===-1)&&(s._status=1,s._result=M)},function(M){(s._status===0||s._status===-1)&&(s._status=2,s._result=M)}),s._status===-1&&(s._status=0,s._result=A)}if(s._status===1)return s._result.default;throw s._result}var j=typeof reportError=="function"?reportError:function(s){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var A=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof s=="object"&&s!==null&&typeof s.message=="string"?String(s.message):String(s),error:s});if(!window.dispatchEvent(A))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",s);return}console.error(s)};function fl(){}return Z.Children={map:S,forEach:function(s,A,M){S(s,function(){A.apply(this,arguments)},M)},count:function(s){var A=0;return S(s,function(){A++}),A},toArray:function(s){return S(s,function(A){return A})||[]},only:function(s){if(!bt(s))throw Error("React.Children.only expected to receive a single React element child.");return s}},Z.Component=ol,Z.Fragment=J,Z.Profiler=X,Z.PureComponent=pl,Z.StrictMode=m,Z.Suspense=U,Z.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=$,Z.__COMPILER_RUNTIME={__proto__:null,c:function(s){return $.H.useMemoCache(s)}},Z.cache=function(s){return function(){return s.apply(null,arguments)}},Z.cloneElement=function(s,A,M){if(s==null)throw Error("The argument must be a React element, but you passed "+s+".");var _=Rl({},s.props),H=s.key,k=void 0;if(A!=null)for(G in A.ref!==void 0&&(k=void 0),A.key!==void 0&&(H=""+A.key),A)!Jl.call(A,G)||G==="key"||G==="__self"||G==="__source"||G==="ref"&&A.ref===void 0||(_[G]=A[G]);var G=arguments.length-2;if(G===1)_.children=M;else if(1<G){for(var $l=Array(G),vl=0;vl<G;vl++)$l[vl]=arguments[vl+2];_.children=$l}return wl(s.type,H,void 0,void 0,k,_)},Z.createContext=function(s){return s={$$typeof:tl,_currentValue:s,_currentValue2:s,_threadCount:0,Provider:null,Consumer:null},s.Provider=s,s.Consumer={$$typeof:B,_context:s},s},Z.createElement=function(s,A,M){var _,H={},k=null;if(A!=null)for(_ in A.key!==void 0&&(k=""+A.key),A)Jl.call(A,_)&&_!=="key"&&_!=="__self"&&_!=="__source"&&(H[_]=A[_]);var G=arguments.length-2;if(G===1)H.children=M;else if(1<G){for(var $l=Array(G),vl=0;vl<G;vl++)$l[vl]=arguments[vl+2];H.children=$l}if(s&&s.defaultProps)for(_ in G=s.defaultProps,G)H[_]===void 0&&(H[_]=G[_]);return wl(s,k,void 0,void 0,null,H)},Z.createRef=function(){return{current:null}},Z.forwardRef=function(s){return{$$typeof:yl,render:s}},Z.isValidElement=bt,Z.lazy=function(s){return{$$typeof:R,_payload:{_status:-1,_result:s},_init:O}},Z.memo=function(s,A){return{$$typeof:T,type:s,compare:A===void 0?null:A}},Z.startTransition=function(s){var A=$.T,M={};$.T=M;try{var _=s(),H=$.S;H!==null&&H(M,_),typeof _=="object"&&_!==null&&typeof _.then=="function"&&_.then(fl,j)}catch(k){j(k)}finally{$.T=A}},Z.unstable_useCacheRefresh=function(){return $.H.useCacheRefresh()},Z.use=function(s){return $.H.use(s)},Z.useActionState=function(s,A,M){return $.H.useActionState(s,A,M)},Z.useCallback=function(s,A){return $.H.useCallback(s,A)},Z.useContext=function(s){return $.H.useContext(s)},Z.useDebugValue=function(){},Z.useDeferredValue=function(s,A){return $.H.useDeferredValue(s,A)},Z.useEffect=function(s,A,M){var _=$.H;if(typeof M=="function")throw Error("useEffect CRUD overload is not enabled in this build of React.");return _.useEffect(s,A)},Z.useId=function(){return $.H.useId()},Z.useImperativeHandle=function(s,A,M){return $.H.useImperativeHandle(s,A,M)},Z.useInsertionEffect=function(s,A){return $.H.useInsertionEffect(s,A)},Z.useLayoutEffect=function(s,A){return $.H.useLayoutEffect(s,A)},Z.useMemo=function(s,A){return $.H.useMemo(s,A)},Z.useOptimistic=function(s,A){return $.H.useOptimistic(s,A)},Z.useReducer=function(s,A,M){return $.H.useReducer(s,A,M)},Z.useRef=function(s){return $.H.useRef(s)},Z.useState=function(s){return $.H.useState(s)},Z.useSyncExternalStore=function(s,A,M){return $.H.useSyncExternalStore(s,A,M)},Z.useTransition=function(){return $.H.useTransition()},Z.version="19.1.1",Z}var P1;function ui(){return P1||(P1=1,Ff.exports=Nd()),Ff.exports}var Xl=ui(),Pf={exports:{}},ge={},If={exports:{}},li={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var I1;function Hd(){return I1||(I1=1,(function(z){function P(S,O){var j=S.length;S.push(O);l:for(;0<j;){var fl=j-1>>>1,s=S[fl];if(0<X(s,O))S[fl]=O,S[j]=s,j=fl;else break l}}function J(S){return S.length===0?null:S[0]}function m(S){if(S.length===0)return null;var O=S[0],j=S.pop();if(j!==O){S[0]=j;l:for(var fl=0,s=S.length,A=s>>>1;fl<A;){var M=2*(fl+1)-1,_=S[M],H=M+1,k=S[H];if(0>X(_,j))H<s&&0>X(k,_)?(S[fl]=k,S[H]=j,fl=H):(S[fl]=_,S[M]=j,fl=M);else if(H<s&&0>X(k,j))S[fl]=k,S[H]=j,fl=H;else break l}}return O}function X(S,O){var j=S.sortIndex-O.sortIndex;return j!==0?j:S.id-O.id}if(z.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var B=performance;z.unstable_now=function(){return B.now()}}else{var tl=Date,yl=tl.now();z.unstable_now=function(){return tl.now()-yl}}var U=[],T=[],R=1,w=null,q=3,dl=!1,Rl=!1,I=!1,ol=!1,yt=typeof setTimeout=="function"?setTimeout:null,pl=typeof clearTimeout=="function"?clearTimeout:null,_l=typeof setImmediate<"u"?setImmediate:null;function rt(S){for(var O=J(T);O!==null;){if(O.callback===null)m(T);else if(O.startTime<=S)m(T),O.sortIndex=O.expirationTime,P(U,O);else break;O=J(T)}}function $(S){if(I=!1,rt(S),!Rl)if(J(U)!==null)Rl=!0,Jl||(Jl=!0,ql());else{var O=J(T);O!==null&&xl($,O.startTime-S)}}var Jl=!1,wl=-1,Wl=5,bt=-1;function Cu(){return ol?!0:!(z.unstable_now()-bt<Wl)}function Mt(){if(ol=!1,Jl){var S=z.unstable_now();bt=S;var O=!0;try{l:{Rl=!1,I&&(I=!1,pl(wl),wl=-1),dl=!0;var j=q;try{t:{for(rt(S),w=J(U);w!==null&&!(w.expirationTime>S&&Cu());){var fl=w.callback;if(typeof fl=="function"){w.callback=null,q=w.priorityLevel;var s=fl(w.expirationTime<=S);if(S=z.unstable_now(),typeof s=="function"){w.callback=s,rt(S),O=!0;break t}w===J(U)&&m(U),rt(S)}else m(U);w=J(U)}if(w!==null)O=!0;else{var A=J(T);A!==null&&xl($,A.startTime-S),O=!1}}break l}finally{w=null,q=j,dl=!1}O=void 0}}finally{O?ql():Jl=!1}}}var ql;if(typeof _l=="function")ql=function(){_l(Mt)};else if(typeof MessageChannel<"u"){var hu=new MessageChannel,yu=hu.port2;hu.port1.onmessage=Mt,ql=function(){yu.postMessage(null)}}else ql=function(){yt(Mt,0)};function xl(S,O){wl=yt(function(){S(z.unstable_now())},O)}z.unstable_IdlePriority=5,z.unstable_ImmediatePriority=1,z.unstable_LowPriority=4,z.unstable_NormalPriority=3,z.unstable_Profiling=null,z.unstable_UserBlockingPriority=2,z.unstable_cancelCallback=function(S){S.callback=null},z.unstable_forceFrameRate=function(S){0>S||125<S?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Wl=0<S?Math.floor(1e3/S):5},z.unstable_getCurrentPriorityLevel=function(){return q},z.unstable_next=function(S){switch(q){case 1:case 2:case 3:var O=3;break;default:O=q}var j=q;q=O;try{return S()}finally{q=j}},z.unstable_requestPaint=function(){ol=!0},z.unstable_runWithPriority=function(S,O){switch(S){case 1:case 2:case 3:case 4:case 5:break;default:S=3}var j=q;q=S;try{return O()}finally{q=j}},z.unstable_scheduleCallback=function(S,O,j){var fl=z.unstable_now();switch(typeof j=="object"&&j!==null?(j=j.delay,j=typeof j=="number"&&0<j?fl+j:fl):j=fl,S){case 1:var s=-1;break;case 2:s=250;break;case 5:s=1073741823;break;case 4:s=1e4;break;default:s=5e3}return s=j+s,S={id:R++,callback:O,priorityLevel:S,startTime:j,expirationTime:s,sortIndex:-1},j>fl?(S.sortIndex=j,P(T,S),J(U)===null&&S===J(T)&&(I?(pl(wl),wl=-1):I=!0,xl($,j-fl))):(S.sortIndex=s,P(U,S),Rl||dl||(Rl=!0,Jl||(Jl=!0,ql()))),S},z.unstable_shouldYield=Cu,z.unstable_wrapCallback=function(S){var O=q;return function(){var j=q;q=O;try{return S.apply(this,arguments)}finally{q=j}}}})(li)),li}var ls;function Cd(){return ls||(ls=1,If.exports=Hd()),If.exports}var ti={exports:{}},Bl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ts;function qd(){if(ts)return Bl;ts=1;var z=ui();function P(U){var T="https://react.dev/errors/"+U;if(1<arguments.length){T+="?args[]="+encodeURIComponent(arguments[1]);for(var R=2;R<arguments.length;R++)T+="&args[]="+encodeURIComponent(arguments[R])}return"Minified React error #"+U+"; visit "+T+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function J(){}var m={d:{f:J,r:function(){throw Error(P(522))},D:J,C:J,L:J,m:J,X:J,S:J,M:J},p:0,findDOMNode:null},X=Symbol.for("react.portal");function B(U,T,R){var w=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:X,key:w==null?null:""+w,children:U,containerInfo:T,implementation:R}}var tl=z.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function yl(U,T){if(U==="font")return"";if(typeof T=="string")return T==="use-credentials"?T:""}return Bl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=m,Bl.createPortal=function(U,T){var R=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!T||T.nodeType!==1&&T.nodeType!==9&&T.nodeType!==11)throw Error(P(299));return B(U,T,null,R)},Bl.flushSync=function(U){var T=tl.T,R=m.p;try{if(tl.T=null,m.p=2,U)return U()}finally{tl.T=T,m.p=R,m.d.f()}},Bl.preconnect=function(U,T){typeof U=="string"&&(T?(T=T.crossOrigin,T=typeof T=="string"?T==="use-credentials"?T:"":void 0):T=null,m.d.C(U,T))},Bl.prefetchDNS=function(U){typeof U=="string"&&m.d.D(U)},Bl.preinit=function(U,T){if(typeof U=="string"&&T&&typeof T.as=="string"){var R=T.as,w=yl(R,T.crossOrigin),q=typeof T.integrity=="string"?T.integrity:void 0,dl=typeof T.fetchPriority=="string"?T.fetchPriority:void 0;R==="style"?m.d.S(U,typeof T.precedence=="string"?T.precedence:void 0,{crossOrigin:w,integrity:q,fetchPriority:dl}):R==="script"&&m.d.X(U,{crossOrigin:w,integrity:q,fetchPriority:dl,nonce:typeof T.nonce=="string"?T.nonce:void 0})}},Bl.preinitModule=function(U,T){if(typeof U=="string")if(typeof T=="object"&&T!==null){if(T.as==null||T.as==="script"){var R=yl(T.as,T.crossOrigin);m.d.M(U,{crossOrigin:R,integrity:typeof T.integrity=="string"?T.integrity:void 0,nonce:typeof T.nonce=="string"?T.nonce:void 0})}}else T==null&&m.d.M(U)},Bl.preload=function(U,T){if(typeof U=="string"&&typeof T=="object"&&T!==null&&typeof T.as=="string"){var R=T.as,w=yl(R,T.crossOrigin);m.d.L(U,R,{crossOrigin:w,integrity:typeof T.integrity=="string"?T.integrity:void 0,nonce:typeof T.nonce=="string"?T.nonce:void 0,type:typeof T.type=="string"?T.type:void 0,fetchPriority:typeof T.fetchPriority=="string"?T.fetchPriority:void 0,referrerPolicy:typeof T.referrerPolicy=="string"?T.referrerPolicy:void 0,imageSrcSet:typeof T.imageSrcSet=="string"?T.imageSrcSet:void 0,imageSizes:typeof T.imageSizes=="string"?T.imageSizes:void 0,media:typeof T.media=="string"?T.media:void 0})}},Bl.preloadModule=function(U,T){if(typeof U=="string")if(T){var R=yl(T.as,T.crossOrigin);m.d.m(U,{as:typeof T.as=="string"&&T.as!=="script"?T.as:void 0,crossOrigin:R,integrity:typeof T.integrity=="string"?T.integrity:void 0})}else m.d.m(U)},Bl.requestFormReset=function(U){m.d.r(U)},Bl.unstable_batchedUpdates=function(U,T){return U(T)},Bl.useFormState=function(U,T,R){return tl.H.useFormState(U,T,R)},Bl.useFormStatus=function(){return tl.H.useHostTransitionStatus()},Bl.version="19.1.1",Bl}var us;function xd(){if(us)return ti.exports;us=1;function z(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(z)}catch(P){console.error(P)}}return z(),ti.exports=qd(),ti.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var as;function jd(){if(as)return ge;as=1;var z=Cd(),P=ui(),J=xd();function m(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var u=2;u<arguments.length;u++)t+="&args[]="+encodeURIComponent(arguments[u])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function X(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function B(l){var t=l,u=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(u=t.return),l=t.return;while(l)}return t.tag===3?u:null}function tl(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function yl(l){if(B(l)!==l)throw Error(m(188))}function U(l){var t=l.alternate;if(!t){if(t=B(l),t===null)throw Error(m(188));return t!==l?null:l}for(var u=l,a=t;;){var e=u.return;if(e===null)break;var n=e.alternate;if(n===null){if(a=e.return,a!==null){u=a;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===u)return yl(e),l;if(n===a)return yl(e),t;n=n.sibling}throw Error(m(188))}if(u.return!==a.return)u=e,a=n;else{for(var c=!1,f=e.child;f;){if(f===u){c=!0,u=e,a=n;break}if(f===a){c=!0,a=e,u=n;break}f=f.sibling}if(!c){for(f=n.child;f;){if(f===u){c=!0,u=n,a=e;break}if(f===a){c=!0,a=n,u=e;break}f=f.sibling}if(!c)throw Error(m(189))}}if(u.alternate!==a)throw Error(m(190))}if(u.tag!==3)throw Error(m(188));return u.stateNode.current===u?l:t}function T(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=T(l),t!==null)return t;l=l.sibling}return null}var R=Object.assign,w=Symbol.for("react.element"),q=Symbol.for("react.transitional.element"),dl=Symbol.for("react.portal"),Rl=Symbol.for("react.fragment"),I=Symbol.for("react.strict_mode"),ol=Symbol.for("react.profiler"),yt=Symbol.for("react.provider"),pl=Symbol.for("react.consumer"),_l=Symbol.for("react.context"),rt=Symbol.for("react.forward_ref"),$=Symbol.for("react.suspense"),Jl=Symbol.for("react.suspense_list"),wl=Symbol.for("react.memo"),Wl=Symbol.for("react.lazy"),bt=Symbol.for("react.activity"),Cu=Symbol.for("react.memo_cache_sentinel"),Mt=Symbol.iterator;function ql(l){return l===null||typeof l!="object"?null:(l=Mt&&l[Mt]||l["@@iterator"],typeof l=="function"?l:null)}var hu=Symbol.for("react.client.reference");function yu(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===hu?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case Rl:return"Fragment";case ol:return"Profiler";case I:return"StrictMode";case $:return"Suspense";case Jl:return"SuspenseList";case bt:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case dl:return"Portal";case _l:return(l.displayName||"Context")+".Provider";case pl:return(l._context.displayName||"Context")+".Consumer";case rt:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case wl:return t=l.displayName||null,t!==null?t:yu(l.type)||"Memo";case Wl:t=l._payload,l=l._init;try{return yu(l(t))}catch{}}return null}var xl=Array.isArray,S=P.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,O=J.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,j={pending:!1,data:null,method:null,action:null},fl=[],s=-1;function A(l){return{current:l}}function M(l){0>s||(l.current=fl[s],fl[s]=null,s--)}function _(l,t){s++,fl[s]=l.current,l.current=t}var H=A(null),k=A(null),G=A(null),$l=A(null);function vl(l,t){switch(_(G,t),_(k,l),_(H,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?z1(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=z1(t),l=_1(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}M(H),_(H,l)}function Qt(){M(H),M(k),M(G)}function qn(l){l.memoizedState!==null&&_($l,l);var t=H.current,u=_1(t,l.type);t!==u&&(_(k,l),_(H,u))}function Se(l){k.current===l&&(M(H),M(k)),$l.current===l&&(M($l),oe._currentValue=j)}var xn=Object.prototype.hasOwnProperty,jn=z.unstable_scheduleCallback,Yn=z.unstable_cancelCallback,fs=z.unstable_shouldYield,is=z.unstable_requestPaint,Et=z.unstable_now,ss=z.unstable_getCurrentPriorityLevel,ai=z.unstable_ImmediatePriority,ei=z.unstable_UserBlockingPriority,be=z.unstable_NormalPriority,ds=z.unstable_LowPriority,ni=z.unstable_IdlePriority,os=z.log,vs=z.unstable_setDisableYieldValue,ba=null,kl=null;function Vt(l){if(typeof os=="function"&&vs(l),kl&&typeof kl.setStrictMode=="function")try{kl.setStrictMode(ba,l)}catch{}}var Fl=Math.clz32?Math.clz32:rs,hs=Math.log,ys=Math.LN2;function rs(l){return l>>>=0,l===0?32:31-(hs(l)/ys|0)|0}var Ee=256,Te=4194304;function ru(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Ae(l,t,u){var a=l.pendingLanes;if(a===0)return 0;var e=0,n=l.suspendedLanes,c=l.pingedLanes;l=l.warmLanes;var f=a&134217727;return f!==0?(a=f&~n,a!==0?e=ru(a):(c&=f,c!==0?e=ru(c):u||(u=f&~l,u!==0&&(e=ru(u))))):(f=a&~n,f!==0?e=ru(f):c!==0?e=ru(c):u||(u=a&~l,u!==0&&(e=ru(u)))),e===0?0:t!==0&&t!==e&&(t&n)===0&&(n=e&-e,u=t&-t,n>=u||n===32&&(u&4194048)!==0)?t:e}function Ea(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function ms(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function ci(){var l=Ee;return Ee<<=1,(Ee&4194048)===0&&(Ee=256),l}function fi(){var l=Te;return Te<<=1,(Te&62914560)===0&&(Te=4194304),l}function Bn(l){for(var t=[],u=0;31>u;u++)t.push(l);return t}function Ta(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function gs(l,t,u,a,e,n){var c=l.pendingLanes;l.pendingLanes=u,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=u,l.entangledLanes&=u,l.errorRecoveryDisabledLanes&=u,l.shellSuspendCounter=0;var f=l.entanglements,i=l.expirationTimes,h=l.hiddenUpdates;for(u=c&~u;0<u;){var g=31-Fl(u),E=1<<g;f[g]=0,i[g]=-1;var y=h[g];if(y!==null)for(h[g]=null,g=0;g<y.length;g++){var r=y[g];r!==null&&(r.lane&=-536870913)}u&=~E}a!==0&&ii(l,a,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(c&~t))}function ii(l,t,u){l.pendingLanes|=t,l.suspendedLanes&=~t;var a=31-Fl(t);l.entangledLanes|=t,l.entanglements[a]=l.entanglements[a]|1073741824|u&4194090}function si(l,t){var u=l.entangledLanes|=t;for(l=l.entanglements;u;){var a=31-Fl(u),e=1<<a;e&t|l[a]&t&&(l[a]|=t),u&=~e}}function Gn(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function Xn(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function di(){var l=O.p;return l!==0?l:(l=window.event,l===void 0?32:V1(l.type))}function Ss(l,t){var u=O.p;try{return O.p=l,t()}finally{O.p=u}}var Lt=Math.random().toString(36).slice(2),jl="__reactFiber$"+Lt,Zl="__reactProps$"+Lt,qu="__reactContainer$"+Lt,Zn="__reactEvents$"+Lt,bs="__reactListeners$"+Lt,Es="__reactHandles$"+Lt,oi="__reactResources$"+Lt,Aa="__reactMarker$"+Lt;function Qn(l){delete l[jl],delete l[Zl],delete l[Zn],delete l[bs],delete l[Es]}function xu(l){var t=l[jl];if(t)return t;for(var u=l.parentNode;u;){if(t=u[qu]||u[jl]){if(u=t.alternate,t.child!==null||u!==null&&u.child!==null)for(l=U1(l);l!==null;){if(u=l[jl])return u;l=U1(l)}return t}l=u,u=l.parentNode}return null}function ju(l){if(l=l[jl]||l[qu]){var t=l.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return l}return null}function za(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(m(33))}function Yu(l){var t=l[oi];return t||(t=l[oi]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Ol(l){l[Aa]=!0}var vi=new Set,hi={};function mu(l,t){Bu(l,t),Bu(l+"Capture",t)}function Bu(l,t){for(hi[l]=t,l=0;l<t.length;l++)vi.add(t[l])}var Ts=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),yi={},ri={};function As(l){return xn.call(ri,l)?!0:xn.call(yi,l)?!1:Ts.test(l)?ri[l]=!0:(yi[l]=!0,!1)}function ze(l,t,u){if(As(t))if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+u)}}function _e(l,t,u){if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+u)}}function Dt(l,t,u,a){if(a===null)l.removeAttribute(u);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(u);return}l.setAttributeNS(t,u,""+a)}}var Vn,mi;function Gu(l){if(Vn===void 0)try{throw Error()}catch(u){var t=u.stack.trim().match(/\n( *(at )?)/);Vn=t&&t[1]||"",mi=-1<u.stack.indexOf(`
    at`)?" (<anonymous>)":-1<u.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Vn+l+mi}var Ln=!1;function Kn(l,t){if(!l||Ln)return"";Ln=!0;var u=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var E=function(){throw Error()};if(Object.defineProperty(E.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(E,[])}catch(r){var y=r}Reflect.construct(l,[],E)}else{try{E.call()}catch(r){y=r}l.call(E.prototype)}}else{try{throw Error()}catch(r){y=r}(E=l())&&typeof E.catch=="function"&&E.catch(function(){})}}catch(r){if(r&&y&&typeof r.stack=="string")return[r.stack,y.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=a.DetermineComponentFrameRoot(),c=n[0],f=n[1];if(c&&f){var i=c.split(`
`),h=f.split(`
`);for(e=a=0;a<i.length&&!i[a].includes("DetermineComponentFrameRoot");)a++;for(;e<h.length&&!h[e].includes("DetermineComponentFrameRoot");)e++;if(a===i.length||e===h.length)for(a=i.length-1,e=h.length-1;1<=a&&0<=e&&i[a]!==h[e];)e--;for(;1<=a&&0<=e;a--,e--)if(i[a]!==h[e]){if(a!==1||e!==1)do if(a--,e--,0>e||i[a]!==h[e]){var g=`
`+i[a].replace(" at new "," at ");return l.displayName&&g.includes("<anonymous>")&&(g=g.replace("<anonymous>",l.displayName)),g}while(1<=a&&0<=e);break}}}finally{Ln=!1,Error.prepareStackTrace=u}return(u=l?l.displayName||l.name:"")?Gu(u):""}function zs(l){switch(l.tag){case 26:case 27:case 5:return Gu(l.type);case 16:return Gu("Lazy");case 13:return Gu("Suspense");case 19:return Gu("SuspenseList");case 0:case 15:return Kn(l.type,!1);case 11:return Kn(l.type.render,!1);case 1:return Kn(l.type,!0);case 31:return Gu("Activity");default:return""}}function gi(l){try{var t="";do t+=zs(l),l=l.return;while(l);return t}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}function nt(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Si(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function _s(l){var t=Si(l)?"checked":"value",u=Object.getOwnPropertyDescriptor(l.constructor.prototype,t),a=""+l[t];if(!l.hasOwnProperty(t)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var e=u.get,n=u.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(c){a=""+c,n.call(this,c)}}),Object.defineProperty(l,t,{enumerable:u.enumerable}),{getValue:function(){return a},setValue:function(c){a=""+c},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function Oe(l){l._valueTracker||(l._valueTracker=_s(l))}function bi(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var u=t.getValue(),a="";return l&&(a=Si(l)?l.checked?"true":"false":l.value),l=a,l!==u?(t.setValue(l),!0):!1}function Me(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var Os=/[\n"\\]/g;function ct(l){return l.replace(Os,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function Jn(l,t,u,a,e,n,c,f){l.name="",c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.type=c:l.removeAttribute("type"),t!=null?c==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+nt(t)):l.value!==""+nt(t)&&(l.value=""+nt(t)):c!=="submit"&&c!=="reset"||l.removeAttribute("value"),t!=null?wn(l,c,nt(t)):u!=null?wn(l,c,nt(u)):a!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.name=""+nt(f):l.removeAttribute("name")}function Ei(l,t,u,a,e,n,c,f){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||u!=null){if(!(n!=="submit"&&n!=="reset"||t!=null))return;u=u!=null?""+nt(u):"",t=t!=null?""+nt(t):u,f||t===l.value||(l.value=t),l.defaultValue=t}a=a??e,a=typeof a!="function"&&typeof a!="symbol"&&!!a,l.checked=f?l.checked:!!a,l.defaultChecked=!!a,c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(l.name=c)}function wn(l,t,u){t==="number"&&Me(l.ownerDocument)===l||l.defaultValue===""+u||(l.defaultValue=""+u)}function Xu(l,t,u,a){if(l=l.options,t){t={};for(var e=0;e<u.length;e++)t["$"+u[e]]=!0;for(u=0;u<l.length;u++)e=t.hasOwnProperty("$"+l[u].value),l[u].selected!==e&&(l[u].selected=e),e&&a&&(l[u].defaultSelected=!0)}else{for(u=""+nt(u),t=null,e=0;e<l.length;e++){if(l[e].value===u){l[e].selected=!0,a&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function Ti(l,t,u){if(t!=null&&(t=""+nt(t),t!==l.value&&(l.value=t),u==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=u!=null?""+nt(u):""}function Ai(l,t,u,a){if(t==null){if(a!=null){if(u!=null)throw Error(m(92));if(xl(a)){if(1<a.length)throw Error(m(93));a=a[0]}u=a}u==null&&(u=""),t=u}u=nt(t),l.defaultValue=u,a=l.textContent,a===u&&a!==""&&a!==null&&(l.value=a)}function Zu(l,t){if(t){var u=l.firstChild;if(u&&u===l.lastChild&&u.nodeType===3){u.nodeValue=t;return}}l.textContent=t}var Ms=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function zi(l,t,u){var a=t.indexOf("--")===0;u==null||typeof u=="boolean"||u===""?a?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":a?l.setProperty(t,u):typeof u!="number"||u===0||Ms.has(t)?t==="float"?l.cssFloat=u:l[t]=(""+u).trim():l[t]=u+"px"}function _i(l,t,u){if(t!=null&&typeof t!="object")throw Error(m(62));if(l=l.style,u!=null){for(var a in u)!u.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?l.setProperty(a,""):a==="float"?l.cssFloat="":l[a]="");for(var e in t)a=t[e],t.hasOwnProperty(e)&&u[e]!==a&&zi(l,e,a)}else for(var n in t)t.hasOwnProperty(n)&&zi(l,n,t[n])}function Wn(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Ds=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Us=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function De(l){return Us.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}var $n=null;function kn(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Qu=null,Vu=null;function Oi(l){var t=ju(l);if(t&&(l=t.stateNode)){var u=l[Zl]||null;l:switch(l=t.stateNode,t.type){case"input":if(Jn(l,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name),t=u.name,u.type==="radio"&&t!=null){for(u=l;u.parentNode;)u=u.parentNode;for(u=u.querySelectorAll('input[name="'+ct(""+t)+'"][type="radio"]'),t=0;t<u.length;t++){var a=u[t];if(a!==l&&a.form===l.form){var e=a[Zl]||null;if(!e)throw Error(m(90));Jn(a,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<u.length;t++)a=u[t],a.form===l.form&&bi(a)}break l;case"textarea":Ti(l,u.value,u.defaultValue);break l;case"select":t=u.value,t!=null&&Xu(l,!!u.multiple,t,!1)}}}var Fn=!1;function Mi(l,t,u){if(Fn)return l(t,u);Fn=!0;try{var a=l(t);return a}finally{if(Fn=!1,(Qu!==null||Vu!==null)&&(hn(),Qu&&(t=Qu,l=Vu,Vu=Qu=null,Oi(t),l)))for(t=0;t<l.length;t++)Oi(l[t])}}function _a(l,t){var u=l.stateNode;if(u===null)return null;var a=u[Zl]||null;if(a===null)return null;u=a[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(l=l.type,a=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!a;break l;default:l=!1}if(l)return null;if(u&&typeof u!="function")throw Error(m(231,t,typeof u));return u}var Ut=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Pn=!1;if(Ut)try{var Oa={};Object.defineProperty(Oa,"passive",{get:function(){Pn=!0}}),window.addEventListener("test",Oa,Oa),window.removeEventListener("test",Oa,Oa)}catch{Pn=!1}var Kt=null,In=null,Ue=null;function Di(){if(Ue)return Ue;var l,t=In,u=t.length,a,e="value"in Kt?Kt.value:Kt.textContent,n=e.length;for(l=0;l<u&&t[l]===e[l];l++);var c=u-l;for(a=1;a<=c&&t[u-a]===e[n-a];a++);return Ue=e.slice(l,1<a?1-a:void 0)}function Re(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function pe(){return!0}function Ui(){return!1}function Ql(l){function t(u,a,e,n,c){this._reactName=u,this._targetInst=e,this.type=a,this.nativeEvent=n,this.target=c,this.currentTarget=null;for(var f in l)l.hasOwnProperty(f)&&(u=l[f],this[f]=u?u(n):n[f]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?pe:Ui,this.isPropagationStopped=Ui,this}return R(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var u=this.nativeEvent;u&&(u.preventDefault?u.preventDefault():typeof u.returnValue!="unknown"&&(u.returnValue=!1),this.isDefaultPrevented=pe)},stopPropagation:function(){var u=this.nativeEvent;u&&(u.stopPropagation?u.stopPropagation():typeof u.cancelBubble!="unknown"&&(u.cancelBubble=!0),this.isPropagationStopped=pe)},persist:function(){},isPersistent:pe}),t}var gu={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Ne=Ql(gu),Ma=R({},gu,{view:0,detail:0}),Rs=Ql(Ma),lc,tc,Da,He=R({},Ma,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:ac,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Da&&(Da&&l.type==="mousemove"?(lc=l.screenX-Da.screenX,tc=l.screenY-Da.screenY):tc=lc=0,Da=l),lc)},movementY:function(l){return"movementY"in l?l.movementY:tc}}),Ri=Ql(He),ps=R({},He,{dataTransfer:0}),Ns=Ql(ps),Hs=R({},Ma,{relatedTarget:0}),uc=Ql(Hs),Cs=R({},gu,{animationName:0,elapsedTime:0,pseudoElement:0}),qs=Ql(Cs),xs=R({},gu,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),js=Ql(xs),Ys=R({},gu,{data:0}),pi=Ql(Ys),Bs={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Gs={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Xs={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Zs(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=Xs[l])?!!t[l]:!1}function ac(){return Zs}var Qs=R({},Ma,{key:function(l){if(l.key){var t=Bs[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Re(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?Gs[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:ac,charCode:function(l){return l.type==="keypress"?Re(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Re(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),Vs=Ql(Qs),Ls=R({},He,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Ni=Ql(Ls),Ks=R({},Ma,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:ac}),Js=Ql(Ks),ws=R({},gu,{propertyName:0,elapsedTime:0,pseudoElement:0}),Ws=Ql(ws),$s=R({},He,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),ks=Ql($s),Fs=R({},gu,{newState:0,oldState:0}),Ps=Ql(Fs),Is=[9,13,27,32],ec=Ut&&"CompositionEvent"in window,Ua=null;Ut&&"documentMode"in document&&(Ua=document.documentMode);var l4=Ut&&"TextEvent"in window&&!Ua,Hi=Ut&&(!ec||Ua&&8<Ua&&11>=Ua),Ci=" ",qi=!1;function xi(l,t){switch(l){case"keyup":return Is.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function ji(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var Lu=!1;function t4(l,t){switch(l){case"compositionend":return ji(t);case"keypress":return t.which!==32?null:(qi=!0,Ci);case"textInput":return l=t.data,l===Ci&&qi?null:l;default:return null}}function u4(l,t){if(Lu)return l==="compositionend"||!ec&&xi(l,t)?(l=Di(),Ue=In=Kt=null,Lu=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Hi&&t.locale!=="ko"?null:t.data;default:return null}}var a4={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Yi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!a4[l.type]:t==="textarea"}function Bi(l,t,u,a){Qu?Vu?Vu.push(a):Vu=[a]:Qu=a,t=bn(t,"onChange"),0<t.length&&(u=new Ne("onChange","change",null,u,a),l.push({event:u,listeners:t}))}var Ra=null,pa=null;function e4(l){S1(l,0)}function Ce(l){var t=za(l);if(bi(t))return l}function Gi(l,t){if(l==="change")return t}var Xi=!1;if(Ut){var nc;if(Ut){var cc="oninput"in document;if(!cc){var Zi=document.createElement("div");Zi.setAttribute("oninput","return;"),cc=typeof Zi.oninput=="function"}nc=cc}else nc=!1;Xi=nc&&(!document.documentMode||9<document.documentMode)}function Qi(){Ra&&(Ra.detachEvent("onpropertychange",Vi),pa=Ra=null)}function Vi(l){if(l.propertyName==="value"&&Ce(pa)){var t=[];Bi(t,pa,l,kn(l)),Mi(e4,t)}}function n4(l,t,u){l==="focusin"?(Qi(),Ra=t,pa=u,Ra.attachEvent("onpropertychange",Vi)):l==="focusout"&&Qi()}function c4(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ce(pa)}function f4(l,t){if(l==="click")return Ce(t)}function i4(l,t){if(l==="input"||l==="change")return Ce(t)}function s4(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var Pl=typeof Object.is=="function"?Object.is:s4;function Na(l,t){if(Pl(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var u=Object.keys(l),a=Object.keys(t);if(u.length!==a.length)return!1;for(a=0;a<u.length;a++){var e=u[a];if(!xn.call(t,e)||!Pl(l[e],t[e]))return!1}return!0}function Li(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function Ki(l,t){var u=Li(l);l=0;for(var a;u;){if(u.nodeType===3){if(a=l+u.textContent.length,l<=t&&a>=t)return{node:u,offset:t-l};l=a}l:{for(;u;){if(u.nextSibling){u=u.nextSibling;break l}u=u.parentNode}u=void 0}u=Li(u)}}function Ji(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?Ji(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function wi(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Me(l.document);t instanceof l.HTMLIFrameElement;){try{var u=typeof t.contentWindow.location.href=="string"}catch{u=!1}if(u)l=t.contentWindow;else break;t=Me(l.document)}return t}function fc(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var d4=Ut&&"documentMode"in document&&11>=document.documentMode,Ku=null,ic=null,Ha=null,sc=!1;function Wi(l,t,u){var a=u.window===u?u.document:u.nodeType===9?u:u.ownerDocument;sc||Ku==null||Ku!==Me(a)||(a=Ku,"selectionStart"in a&&fc(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Ha&&Na(Ha,a)||(Ha=a,a=bn(ic,"onSelect"),0<a.length&&(t=new Ne("onSelect","select",null,t,u),l.push({event:t,listeners:a}),t.target=Ku)))}function Su(l,t){var u={};return u[l.toLowerCase()]=t.toLowerCase(),u["Webkit"+l]="webkit"+t,u["Moz"+l]="moz"+t,u}var Ju={animationend:Su("Animation","AnimationEnd"),animationiteration:Su("Animation","AnimationIteration"),animationstart:Su("Animation","AnimationStart"),transitionrun:Su("Transition","TransitionRun"),transitionstart:Su("Transition","TransitionStart"),transitioncancel:Su("Transition","TransitionCancel"),transitionend:Su("Transition","TransitionEnd")},dc={},$i={};Ut&&($i=document.createElement("div").style,"AnimationEvent"in window||(delete Ju.animationend.animation,delete Ju.animationiteration.animation,delete Ju.animationstart.animation),"TransitionEvent"in window||delete Ju.transitionend.transition);function bu(l){if(dc[l])return dc[l];if(!Ju[l])return l;var t=Ju[l],u;for(u in t)if(t.hasOwnProperty(u)&&u in $i)return dc[l]=t[u];return l}var ki=bu("animationend"),Fi=bu("animationiteration"),Pi=bu("animationstart"),o4=bu("transitionrun"),v4=bu("transitionstart"),h4=bu("transitioncancel"),Ii=bu("transitionend"),l0=new Map,oc="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");oc.push("scrollEnd");function mt(l,t){l0.set(l,t),mu(t,[l])}var t0=new WeakMap;function ft(l,t){if(typeof l=="object"&&l!==null){var u=t0.get(l);return u!==void 0?u:(t={value:l,source:t,stack:gi(t)},t0.set(l,t),t)}return{value:l,source:t,stack:gi(t)}}var it=[],wu=0,vc=0;function qe(){for(var l=wu,t=vc=wu=0;t<l;){var u=it[t];it[t++]=null;var a=it[t];it[t++]=null;var e=it[t];it[t++]=null;var n=it[t];if(it[t++]=null,a!==null&&e!==null){var c=a.pending;c===null?e.next=e:(e.next=c.next,c.next=e),a.pending=e}n!==0&&u0(u,e,n)}}function xe(l,t,u,a){it[wu++]=l,it[wu++]=t,it[wu++]=u,it[wu++]=a,vc|=a,l.lanes|=a,l=l.alternate,l!==null&&(l.lanes|=a)}function hc(l,t,u,a){return xe(l,t,u,a),je(l)}function Wu(l,t){return xe(l,null,null,t),je(l)}function u0(l,t,u){l.lanes|=u;var a=l.alternate;a!==null&&(a.lanes|=u);for(var e=!1,n=l.return;n!==null;)n.childLanes|=u,a=n.alternate,a!==null&&(a.childLanes|=u),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,e&&t!==null&&(e=31-Fl(u),l=n.hiddenUpdates,a=l[e],a===null?l[e]=[t]:a.push(t),t.lane=u|536870912),n):null}function je(l){if(50<ae)throw ae=0,Ef=null,Error(m(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var $u={};function y4(l,t,u,a){this.tag=l,this.key=u,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Il(l,t,u,a){return new y4(l,t,u,a)}function yc(l){return l=l.prototype,!(!l||!l.isReactComponent)}function Rt(l,t){var u=l.alternate;return u===null?(u=Il(l.tag,t,l.key,l.mode),u.elementType=l.elementType,u.type=l.type,u.stateNode=l.stateNode,u.alternate=l,l.alternate=u):(u.pendingProps=t,u.type=l.type,u.flags=0,u.subtreeFlags=0,u.deletions=null),u.flags=l.flags&65011712,u.childLanes=l.childLanes,u.lanes=l.lanes,u.child=l.child,u.memoizedProps=l.memoizedProps,u.memoizedState=l.memoizedState,u.updateQueue=l.updateQueue,t=l.dependencies,u.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},u.sibling=l.sibling,u.index=l.index,u.ref=l.ref,u.refCleanup=l.refCleanup,u}function a0(l,t){l.flags&=65011714;var u=l.alternate;return u===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=u.childLanes,l.lanes=u.lanes,l.child=u.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=u.memoizedProps,l.memoizedState=u.memoizedState,l.updateQueue=u.updateQueue,l.type=u.type,t=u.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Ye(l,t,u,a,e,n){var c=0;if(a=l,typeof l=="function")yc(l)&&(c=1);else if(typeof l=="string")c=md(l,u,H.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case bt:return l=Il(31,u,t,e),l.elementType=bt,l.lanes=n,l;case Rl:return Eu(u.children,e,n,t);case I:c=8,e|=24;break;case ol:return l=Il(12,u,t,e|2),l.elementType=ol,l.lanes=n,l;case $:return l=Il(13,u,t,e),l.elementType=$,l.lanes=n,l;case Jl:return l=Il(19,u,t,e),l.elementType=Jl,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case yt:case _l:c=10;break l;case pl:c=9;break l;case rt:c=11;break l;case wl:c=14;break l;case Wl:c=16,a=null;break l}c=29,u=Error(m(130,l===null?"null":typeof l,"")),a=null}return t=Il(c,u,t,e),t.elementType=l,t.type=a,t.lanes=n,t}function Eu(l,t,u,a){return l=Il(7,l,a,t),l.lanes=u,l}function rc(l,t,u){return l=Il(6,l,null,t),l.lanes=u,l}function mc(l,t,u){return t=Il(4,l.children!==null?l.children:[],l.key,t),t.lanes=u,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var ku=[],Fu=0,Be=null,Ge=0,st=[],dt=0,Tu=null,pt=1,Nt="";function Au(l,t){ku[Fu++]=Ge,ku[Fu++]=Be,Be=l,Ge=t}function e0(l,t,u){st[dt++]=pt,st[dt++]=Nt,st[dt++]=Tu,Tu=l;var a=pt;l=Nt;var e=32-Fl(a)-1;a&=~(1<<e),u+=1;var n=32-Fl(t)+e;if(30<n){var c=e-e%5;n=(a&(1<<c)-1).toString(32),a>>=c,e-=c,pt=1<<32-Fl(t)+e|u<<e|a,Nt=n+l}else pt=1<<n|u<<e|a,Nt=l}function gc(l){l.return!==null&&(Au(l,1),e0(l,1,0))}function Sc(l){for(;l===Be;)Be=ku[--Fu],ku[Fu]=null,Ge=ku[--Fu],ku[Fu]=null;for(;l===Tu;)Tu=st[--dt],st[dt]=null,Nt=st[--dt],st[dt]=null,pt=st[--dt],st[dt]=null}var Gl=null,ml=null,ll=!1,zu=null,Tt=!1,bc=Error(m(519));function _u(l){var t=Error(m(418,""));throw xa(ft(t,l)),bc}function n0(l){var t=l.stateNode,u=l.type,a=l.memoizedProps;switch(t[jl]=l,t[Zl]=a,u){case"dialog":K("cancel",t),K("close",t);break;case"iframe":case"object":case"embed":K("load",t);break;case"video":case"audio":for(u=0;u<ne.length;u++)K(ne[u],t);break;case"source":K("error",t);break;case"img":case"image":case"link":K("error",t),K("load",t);break;case"details":K("toggle",t);break;case"input":K("invalid",t),Ei(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0),Oe(t);break;case"select":K("invalid",t);break;case"textarea":K("invalid",t),Ai(t,a.value,a.defaultValue,a.children),Oe(t)}u=a.children,typeof u!="string"&&typeof u!="number"&&typeof u!="bigint"||t.textContent===""+u||a.suppressHydrationWarning===!0||A1(t.textContent,u)?(a.popover!=null&&(K("beforetoggle",t),K("toggle",t)),a.onScroll!=null&&K("scroll",t),a.onScrollEnd!=null&&K("scrollend",t),a.onClick!=null&&(t.onclick=En),t=!0):t=!1,t||_u(l)}function c0(l){for(Gl=l.return;Gl;)switch(Gl.tag){case 5:case 13:Tt=!1;return;case 27:case 3:Tt=!0;return;default:Gl=Gl.return}}function Ca(l){if(l!==Gl)return!1;if(!ll)return c0(l),ll=!0,!1;var t=l.tag,u;if((u=t!==3&&t!==27)&&((u=t===5)&&(u=l.type,u=!(u!=="form"&&u!=="button")||jf(l.type,l.memoizedProps)),u=!u),u&&ml&&_u(l),c0(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(m(317));l:{for(l=l.nextSibling,t=0;l;){if(l.nodeType===8)if(u=l.data,u==="/$"){if(t===0){ml=St(l.nextSibling);break l}t--}else u!=="$"&&u!=="$!"&&u!=="$?"||t++;l=l.nextSibling}ml=null}}else t===27?(t=ml,fu(l.type)?(l=Xf,Xf=null,ml=l):ml=t):ml=Gl?St(l.stateNode.nextSibling):null;return!0}function qa(){ml=Gl=null,ll=!1}function f0(){var l=zu;return l!==null&&(Kl===null?Kl=l:Kl.push.apply(Kl,l),zu=null),l}function xa(l){zu===null?zu=[l]:zu.push(l)}var Ec=A(null),Ou=null,Ht=null;function Jt(l,t,u){_(Ec,t._currentValue),t._currentValue=u}function Ct(l){l._currentValue=Ec.current,M(Ec)}function Tc(l,t,u){for(;l!==null;){var a=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),l===u)break;l=l.return}}function Ac(l,t,u,a){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var c=e.child;n=n.firstContext;l:for(;n!==null;){var f=n;n=e;for(var i=0;i<t.length;i++)if(f.context===t[i]){n.lanes|=u,f=n.alternate,f!==null&&(f.lanes|=u),Tc(n.return,u,l),a||(c=null);break l}n=f.next}}else if(e.tag===18){if(c=e.return,c===null)throw Error(m(341));c.lanes|=u,n=c.alternate,n!==null&&(n.lanes|=u),Tc(c,u,l),c=null}else c=e.child;if(c!==null)c.return=e;else for(c=e;c!==null;){if(c===l){c=null;break}if(e=c.sibling,e!==null){e.return=c.return,c=e;break}c=c.return}e=c}}function ja(l,t,u,a){l=null;for(var e=t,n=!1;e!==null;){if(!n){if((e.flags&524288)!==0)n=!0;else if((e.flags&262144)!==0)break}if(e.tag===10){var c=e.alternate;if(c===null)throw Error(m(387));if(c=c.memoizedProps,c!==null){var f=e.type;Pl(e.pendingProps.value,c.value)||(l!==null?l.push(f):l=[f])}}else if(e===$l.current){if(c=e.alternate,c===null)throw Error(m(387));c.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(oe):l=[oe])}e=e.return}l!==null&&Ac(t,l,u,a),t.flags|=262144}function Xe(l){for(l=l.firstContext;l!==null;){if(!Pl(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Mu(l){Ou=l,Ht=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Yl(l){return i0(Ou,l)}function Ze(l,t){return Ou===null&&Mu(l),i0(l,t)}function i0(l,t){var u=t._currentValue;if(t={context:t,memoizedValue:u,next:null},Ht===null){if(l===null)throw Error(m(308));Ht=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Ht=Ht.next=t;return u}var r4=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(u,a){l.push(a)}};this.abort=function(){t.aborted=!0,l.forEach(function(u){return u()})}},m4=z.unstable_scheduleCallback,g4=z.unstable_NormalPriority,Al={$$typeof:_l,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function zc(){return{controller:new r4,data:new Map,refCount:0}}function Ya(l){l.refCount--,l.refCount===0&&m4(g4,function(){l.controller.abort()})}var Ba=null,_c=0,Pu=0,Iu=null;function S4(l,t){if(Ba===null){var u=Ba=[];_c=0,Pu=Df(),Iu={status:"pending",value:void 0,then:function(a){u.push(a)}}}return _c++,t.then(s0,s0),t}function s0(){if(--_c===0&&Ba!==null){Iu!==null&&(Iu.status="fulfilled");var l=Ba;Ba=null,Pu=0,Iu=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function b4(l,t){var u=[],a={status:"pending",value:null,reason:null,then:function(e){u.push(e)}};return l.then(function(){a.status="fulfilled",a.value=t;for(var e=0;e<u.length;e++)(0,u[e])(t)},function(e){for(a.status="rejected",a.reason=e,e=0;e<u.length;e++)(0,u[e])(void 0)}),a}var d0=S.S;S.S=function(l,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&S4(l,t),d0!==null&&d0(l,t)};var Du=A(null);function Oc(){var l=Du.current;return l!==null?l:sl.pooledCache}function Qe(l,t){t===null?_(Du,Du.current):_(Du,t.pool)}function o0(){var l=Oc();return l===null?null:{parent:Al._currentValue,pool:l}}var Ga=Error(m(460)),v0=Error(m(474)),Ve=Error(m(542)),Mc={then:function(){}};function h0(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Le(){}function y0(l,t,u){switch(u=l[u],u===void 0?l.push(t):u!==t&&(t.then(Le,Le),t=u),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,m0(l),l;default:if(typeof t.status=="string")t.then(Le,Le);else{if(l=sl,l!==null&&100<l.shellSuspendCounter)throw Error(m(482));l=t,l.status="pending",l.then(function(a){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=a}},function(a){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,m0(l),l}throw Xa=t,Ga}}var Xa=null;function r0(){if(Xa===null)throw Error(m(459));var l=Xa;return Xa=null,l}function m0(l){if(l===Ga||l===Ve)throw Error(m(483))}var wt=!1;function Dc(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Uc(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function Wt(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function $t(l,t,u){var a=l.updateQueue;if(a===null)return null;if(a=a.shared,(ul&2)!==0){var e=a.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),a.pending=t,t=je(l),u0(l,null,u),t}return xe(l,a,t,u),je(l)}function Za(l,t,u){if(t=t.updateQueue,t!==null&&(t=t.shared,(u&4194048)!==0)){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,si(l,u)}}function Rc(l,t){var u=l.updateQueue,a=l.alternate;if(a!==null&&(a=a.updateQueue,u===a)){var e=null,n=null;if(u=u.firstBaseUpdate,u!==null){do{var c={lane:u.lane,tag:u.tag,payload:u.payload,callback:null,next:null};n===null?e=n=c:n=n.next=c,u=u.next}while(u!==null);n===null?e=n=t:n=n.next=t}else e=n=t;u={baseState:a.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:a.shared,callbacks:a.callbacks},l.updateQueue=u;return}l=u.lastBaseUpdate,l===null?u.firstBaseUpdate=t:l.next=t,u.lastBaseUpdate=t}var pc=!1;function Qa(){if(pc){var l=Iu;if(l!==null)throw l}}function Va(l,t,u,a){pc=!1;var e=l.updateQueue;wt=!1;var n=e.firstBaseUpdate,c=e.lastBaseUpdate,f=e.shared.pending;if(f!==null){e.shared.pending=null;var i=f,h=i.next;i.next=null,c===null?n=h:c.next=h,c=i;var g=l.alternate;g!==null&&(g=g.updateQueue,f=g.lastBaseUpdate,f!==c&&(f===null?g.firstBaseUpdate=h:f.next=h,g.lastBaseUpdate=i))}if(n!==null){var E=e.baseState;c=0,g=h=i=null,f=n;do{var y=f.lane&-536870913,r=y!==f.lane;if(r?(W&y)===y:(a&y)===y){y!==0&&y===Pu&&(pc=!0),g!==null&&(g=g.next={lane:0,tag:f.tag,payload:f.payload,callback:null,next:null});l:{var Y=l,C=f;y=t;var cl=u;switch(C.tag){case 1:if(Y=C.payload,typeof Y=="function"){E=Y.call(cl,E,y);break l}E=Y;break l;case 3:Y.flags=Y.flags&-65537|128;case 0:if(Y=C.payload,y=typeof Y=="function"?Y.call(cl,E,y):Y,y==null)break l;E=R({},E,y);break l;case 2:wt=!0}}y=f.callback,y!==null&&(l.flags|=64,r&&(l.flags|=8192),r=e.callbacks,r===null?e.callbacks=[y]:r.push(y))}else r={lane:y,tag:f.tag,payload:f.payload,callback:f.callback,next:null},g===null?(h=g=r,i=E):g=g.next=r,c|=y;if(f=f.next,f===null){if(f=e.shared.pending,f===null)break;r=f,f=r.next,r.next=null,e.lastBaseUpdate=r,e.shared.pending=null}}while(!0);g===null&&(i=E),e.baseState=i,e.firstBaseUpdate=h,e.lastBaseUpdate=g,n===null&&(e.shared.lanes=0),au|=c,l.lanes=c,l.memoizedState=E}}function g0(l,t){if(typeof l!="function")throw Error(m(191,l));l.call(t)}function S0(l,t){var u=l.callbacks;if(u!==null)for(l.callbacks=null,l=0;l<u.length;l++)g0(u[l],t)}var la=A(null),Ke=A(0);function b0(l,t){l=Xt,_(Ke,l),_(la,t),Xt=l|t.baseLanes}function Nc(){_(Ke,Xt),_(la,la.current)}function Hc(){Xt=Ke.current,M(la),M(Ke)}var kt=0,Q=null,el=null,El=null,Je=!1,ta=!1,Uu=!1,we=0,La=0,ua=null,E4=0;function Sl(){throw Error(m(321))}function Cc(l,t){if(t===null)return!1;for(var u=0;u<t.length&&u<l.length;u++)if(!Pl(l[u],t[u]))return!1;return!0}function qc(l,t,u,a,e,n){return kt=n,Q=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,S.H=l===null||l.memoizedState===null?u2:a2,Uu=!1,n=u(a,e),Uu=!1,ta&&(n=T0(t,u,a,e)),E0(l),n}function E0(l){S.H=Ie;var t=el!==null&&el.next!==null;if(kt=0,El=el=Q=null,Je=!1,La=0,ua=null,t)throw Error(m(300));l===null||Ml||(l=l.dependencies,l!==null&&Xe(l)&&(Ml=!0))}function T0(l,t,u,a){Q=l;var e=0;do{if(ta&&(ua=null),La=0,ta=!1,25<=e)throw Error(m(301));if(e+=1,El=el=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}S.H=D4,n=t(u,a)}while(ta);return n}function T4(){var l=S.H,t=l.useState()[0];return t=typeof t.then=="function"?Ka(t):t,l=l.useState()[0],(el!==null?el.memoizedState:null)!==l&&(Q.flags|=1024),t}function xc(){var l=we!==0;return we=0,l}function jc(l,t,u){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~u}function Yc(l){if(Je){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}Je=!1}kt=0,El=el=Q=null,ta=!1,La=we=0,ua=null}function Vl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return El===null?Q.memoizedState=El=l:El=El.next=l,El}function Tl(){if(el===null){var l=Q.alternate;l=l!==null?l.memoizedState:null}else l=el.next;var t=El===null?Q.memoizedState:El.next;if(t!==null)El=t,el=l;else{if(l===null)throw Q.alternate===null?Error(m(467)):Error(m(310));el=l,l={memoizedState:el.memoizedState,baseState:el.baseState,baseQueue:el.baseQueue,queue:el.queue,next:null},El===null?Q.memoizedState=El=l:El=El.next=l}return El}function Bc(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Ka(l){var t=La;return La+=1,ua===null&&(ua=[]),l=y0(ua,l,t),t=Q,(El===null?t.memoizedState:El.next)===null&&(t=t.alternate,S.H=t===null||t.memoizedState===null?u2:a2),l}function We(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return Ka(l);if(l.$$typeof===_l)return Yl(l)}throw Error(m(438,String(l)))}function Gc(l){var t=null,u=Q.updateQueue;if(u!==null&&(t=u.memoCache),t==null){var a=Q.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),u===null&&(u=Bc(),Q.updateQueue=u),u.memoCache=t,u=t.data[t.index],u===void 0)for(u=t.data[t.index]=Array(l),a=0;a<l;a++)u[a]=Cu;return t.index++,u}function qt(l,t){return typeof t=="function"?t(l):t}function $e(l){var t=Tl();return Xc(t,el,l)}function Xc(l,t,u){var a=l.queue;if(a===null)throw Error(m(311));a.lastRenderedReducer=u;var e=l.baseQueue,n=a.pending;if(n!==null){if(e!==null){var c=e.next;e.next=n.next,n.next=c}t.baseQueue=e=n,a.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var f=c=null,i=null,h=t,g=!1;do{var E=h.lane&-536870913;if(E!==h.lane?(W&E)===E:(kt&E)===E){var y=h.revertLane;if(y===0)i!==null&&(i=i.next={lane:0,revertLane:0,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null}),E===Pu&&(g=!0);else if((kt&y)===y){h=h.next,y===Pu&&(g=!0);continue}else E={lane:0,revertLane:h.revertLane,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null},i===null?(f=i=E,c=n):i=i.next=E,Q.lanes|=y,au|=y;E=h.action,Uu&&u(n,E),n=h.hasEagerState?h.eagerState:u(n,E)}else y={lane:E,revertLane:h.revertLane,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null},i===null?(f=i=y,c=n):i=i.next=y,Q.lanes|=E,au|=E;h=h.next}while(h!==null&&h!==t);if(i===null?c=n:i.next=f,!Pl(n,l.memoizedState)&&(Ml=!0,g&&(u=Iu,u!==null)))throw u;l.memoizedState=n,l.baseState=c,l.baseQueue=i,a.lastRenderedState=n}return e===null&&(a.lanes=0),[l.memoizedState,a.dispatch]}function Zc(l){var t=Tl(),u=t.queue;if(u===null)throw Error(m(311));u.lastRenderedReducer=l;var a=u.dispatch,e=u.pending,n=t.memoizedState;if(e!==null){u.pending=null;var c=e=e.next;do n=l(n,c.action),c=c.next;while(c!==e);Pl(n,t.memoizedState)||(Ml=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),u.lastRenderedState=n}return[n,a]}function A0(l,t,u){var a=Q,e=Tl(),n=ll;if(n){if(u===void 0)throw Error(m(407));u=u()}else u=t();var c=!Pl((el||e).memoizedState,u);c&&(e.memoizedState=u,Ml=!0),e=e.queue;var f=O0.bind(null,a,e,l);if(Ja(2048,8,f,[l]),e.getSnapshot!==t||c||El!==null&&El.memoizedState.tag&1){if(a.flags|=2048,aa(9,ke(),_0.bind(null,a,e,u,t),null),sl===null)throw Error(m(349));n||(kt&124)!==0||z0(a,t,u)}return u}function z0(l,t,u){l.flags|=16384,l={getSnapshot:t,value:u},t=Q.updateQueue,t===null?(t=Bc(),Q.updateQueue=t,t.stores=[l]):(u=t.stores,u===null?t.stores=[l]:u.push(l))}function _0(l,t,u,a){t.value=u,t.getSnapshot=a,M0(t)&&D0(l)}function O0(l,t,u){return u(function(){M0(t)&&D0(l)})}function M0(l){var t=l.getSnapshot;l=l.value;try{var u=t();return!Pl(l,u)}catch{return!0}}function D0(l){var t=Wu(l,2);t!==null&&et(t,l,2)}function Qc(l){var t=Vl();if(typeof l=="function"){var u=l;if(l=u(),Uu){Vt(!0);try{u()}finally{Vt(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:qt,lastRenderedState:l},t}function U0(l,t,u,a){return l.baseState=u,Xc(l,el,typeof a=="function"?a:qt)}function A4(l,t,u,a,e){if(Pe(l))throw Error(m(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(c){n.listeners.push(c)}};S.T!==null?u(!0):n.isTransition=!1,a(n),u=t.pending,u===null?(n.next=t.pending=n,R0(t,n)):(n.next=u.next,t.pending=u.next=n)}}function R0(l,t){var u=t.action,a=t.payload,e=l.state;if(t.isTransition){var n=S.T,c={};S.T=c;try{var f=u(e,a),i=S.S;i!==null&&i(c,f),p0(l,t,f)}catch(h){Vc(l,t,h)}finally{S.T=n}}else try{n=u(e,a),p0(l,t,n)}catch(h){Vc(l,t,h)}}function p0(l,t,u){u!==null&&typeof u=="object"&&typeof u.then=="function"?u.then(function(a){N0(l,t,a)},function(a){return Vc(l,t,a)}):N0(l,t,u)}function N0(l,t,u){t.status="fulfilled",t.value=u,H0(t),l.state=u,t=l.pending,t!==null&&(u=t.next,u===t?l.pending=null:(u=u.next,t.next=u,R0(l,u)))}function Vc(l,t,u){var a=l.pending;if(l.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=u,H0(t),t=t.next;while(t!==a)}l.action=null}function H0(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function C0(l,t){return t}function q0(l,t){if(ll){var u=sl.formState;if(u!==null){l:{var a=Q;if(ll){if(ml){t:{for(var e=ml,n=Tt;e.nodeType!==8;){if(!n){e=null;break t}if(e=St(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){ml=St(e.nextSibling),a=e.data==="F!";break l}}_u(a)}a=!1}a&&(t=u[0])}}return u=Vl(),u.memoizedState=u.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:C0,lastRenderedState:t},u.queue=a,u=I0.bind(null,Q,a),a.dispatch=u,a=Qc(!1),n=Wc.bind(null,Q,!1,a.queue),a=Vl(),e={state:t,dispatch:null,action:l,pending:null},a.queue=e,u=A4.bind(null,Q,e,n,u),e.dispatch=u,a.memoizedState=l,[t,u,!1]}function x0(l){var t=Tl();return j0(t,el,l)}function j0(l,t,u){if(t=Xc(l,t,C0)[0],l=$e(qt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var a=Ka(t)}catch(c){throw c===Ga?Ve:c}else a=t;t=Tl();var e=t.queue,n=e.dispatch;return u!==t.memoizedState&&(Q.flags|=2048,aa(9,ke(),z4.bind(null,e,u),null)),[a,n,l]}function z4(l,t){l.action=t}function Y0(l){var t=Tl(),u=el;if(u!==null)return j0(t,u,l);Tl(),t=t.memoizedState,u=Tl();var a=u.queue.dispatch;return u.memoizedState=l,[t,a,!1]}function aa(l,t,u,a){return l={tag:l,create:u,deps:a,inst:t,next:null},t=Q.updateQueue,t===null&&(t=Bc(),Q.updateQueue=t),u=t.lastEffect,u===null?t.lastEffect=l.next=l:(a=u.next,u.next=l,l.next=a,t.lastEffect=l),l}function ke(){return{destroy:void 0,resource:void 0}}function B0(){return Tl().memoizedState}function Fe(l,t,u,a){var e=Vl();a=a===void 0?null:a,Q.flags|=l,e.memoizedState=aa(1|t,ke(),u,a)}function Ja(l,t,u,a){var e=Tl();a=a===void 0?null:a;var n=e.memoizedState.inst;el!==null&&a!==null&&Cc(a,el.memoizedState.deps)?e.memoizedState=aa(t,n,u,a):(Q.flags|=l,e.memoizedState=aa(1|t,n,u,a))}function G0(l,t){Fe(8390656,8,l,t)}function X0(l,t){Ja(2048,8,l,t)}function Z0(l,t){return Ja(4,2,l,t)}function Q0(l,t){return Ja(4,4,l,t)}function V0(l,t){if(typeof t=="function"){l=l();var u=t(l);return function(){typeof u=="function"?u():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function L0(l,t,u){u=u!=null?u.concat([l]):null,Ja(4,4,V0.bind(null,t,l),u)}function Lc(){}function K0(l,t){var u=Tl();t=t===void 0?null:t;var a=u.memoizedState;return t!==null&&Cc(t,a[1])?a[0]:(u.memoizedState=[l,t],l)}function J0(l,t){var u=Tl();t=t===void 0?null:t;var a=u.memoizedState;if(t!==null&&Cc(t,a[1]))return a[0];if(a=l(),Uu){Vt(!0);try{l()}finally{Vt(!1)}}return u.memoizedState=[a,t],a}function Kc(l,t,u){return u===void 0||(kt&1073741824)!==0?l.memoizedState=t:(l.memoizedState=u,l=$2(),Q.lanes|=l,au|=l,u)}function w0(l,t,u,a){return Pl(u,t)?u:la.current!==null?(l=Kc(l,u,a),Pl(l,t)||(Ml=!0),l):(kt&42)===0?(Ml=!0,l.memoizedState=u):(l=$2(),Q.lanes|=l,au|=l,t)}function W0(l,t,u,a,e){var n=O.p;O.p=n!==0&&8>n?n:8;var c=S.T,f={};S.T=f,Wc(l,!1,t,u);try{var i=e(),h=S.S;if(h!==null&&h(f,i),i!==null&&typeof i=="object"&&typeof i.then=="function"){var g=b4(i,a);wa(l,t,g,at(l))}else wa(l,t,a,at(l))}catch(E){wa(l,t,{then:function(){},status:"rejected",reason:E},at())}finally{O.p=n,S.T=c}}function _4(){}function Jc(l,t,u,a){if(l.tag!==5)throw Error(m(476));var e=$0(l).queue;W0(l,e,t,j,u===null?_4:function(){return k0(l),u(a)})}function $0(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:j,baseState:j,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:qt,lastRenderedState:j},next:null};var u={};return t.next={memoizedState:u,baseState:u,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:qt,lastRenderedState:u},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function k0(l){var t=$0(l).next.queue;wa(l,t,{},at())}function wc(){return Yl(oe)}function F0(){return Tl().memoizedState}function P0(){return Tl().memoizedState}function O4(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var u=at();l=Wt(u);var a=$t(t,l,u);a!==null&&(et(a,t,u),Za(a,t,u)),t={cache:zc()},l.payload=t;return}t=t.return}}function M4(l,t,u){var a=at();u={lane:a,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null},Pe(l)?l2(t,u):(u=hc(l,t,u,a),u!==null&&(et(u,l,a),t2(u,t,a)))}function I0(l,t,u){var a=at();wa(l,t,u,a)}function wa(l,t,u,a){var e={lane:a,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null};if(Pe(l))l2(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var c=t.lastRenderedState,f=n(c,u);if(e.hasEagerState=!0,e.eagerState=f,Pl(f,c))return xe(l,t,e,0),sl===null&&qe(),!1}catch{}finally{}if(u=hc(l,t,e,a),u!==null)return et(u,l,a),t2(u,t,a),!0}return!1}function Wc(l,t,u,a){if(a={lane:2,revertLane:Df(),action:a,hasEagerState:!1,eagerState:null,next:null},Pe(l)){if(t)throw Error(m(479))}else t=hc(l,u,a,2),t!==null&&et(t,l,2)}function Pe(l){var t=l.alternate;return l===Q||t!==null&&t===Q}function l2(l,t){ta=Je=!0;var u=l.pending;u===null?t.next=t:(t.next=u.next,u.next=t),l.pending=t}function t2(l,t,u){if((u&4194048)!==0){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,si(l,u)}}var Ie={readContext:Yl,use:We,useCallback:Sl,useContext:Sl,useEffect:Sl,useImperativeHandle:Sl,useLayoutEffect:Sl,useInsertionEffect:Sl,useMemo:Sl,useReducer:Sl,useRef:Sl,useState:Sl,useDebugValue:Sl,useDeferredValue:Sl,useTransition:Sl,useSyncExternalStore:Sl,useId:Sl,useHostTransitionStatus:Sl,useFormState:Sl,useActionState:Sl,useOptimistic:Sl,useMemoCache:Sl,useCacheRefresh:Sl},u2={readContext:Yl,use:We,useCallback:function(l,t){return Vl().memoizedState=[l,t===void 0?null:t],l},useContext:Yl,useEffect:G0,useImperativeHandle:function(l,t,u){u=u!=null?u.concat([l]):null,Fe(4194308,4,V0.bind(null,t,l),u)},useLayoutEffect:function(l,t){return Fe(4194308,4,l,t)},useInsertionEffect:function(l,t){Fe(4,2,l,t)},useMemo:function(l,t){var u=Vl();t=t===void 0?null:t;var a=l();if(Uu){Vt(!0);try{l()}finally{Vt(!1)}}return u.memoizedState=[a,t],a},useReducer:function(l,t,u){var a=Vl();if(u!==void 0){var e=u(t);if(Uu){Vt(!0);try{u(t)}finally{Vt(!1)}}}else e=t;return a.memoizedState=a.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},a.queue=l,l=l.dispatch=M4.bind(null,Q,l),[a.memoizedState,l]},useRef:function(l){var t=Vl();return l={current:l},t.memoizedState=l},useState:function(l){l=Qc(l);var t=l.queue,u=I0.bind(null,Q,t);return t.dispatch=u,[l.memoizedState,u]},useDebugValue:Lc,useDeferredValue:function(l,t){var u=Vl();return Kc(u,l,t)},useTransition:function(){var l=Qc(!1);return l=W0.bind(null,Q,l.queue,!0,!1),Vl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,u){var a=Q,e=Vl();if(ll){if(u===void 0)throw Error(m(407));u=u()}else{if(u=t(),sl===null)throw Error(m(349));(W&124)!==0||z0(a,t,u)}e.memoizedState=u;var n={value:u,getSnapshot:t};return e.queue=n,G0(O0.bind(null,a,n,l),[l]),a.flags|=2048,aa(9,ke(),_0.bind(null,a,n,u,t),null),u},useId:function(){var l=Vl(),t=sl.identifierPrefix;if(ll){var u=Nt,a=pt;u=(a&~(1<<32-Fl(a)-1)).toString(32)+u,t="«"+t+"R"+u,u=we++,0<u&&(t+="H"+u.toString(32)),t+="»"}else u=E4++,t="«"+t+"r"+u.toString(32)+"»";return l.memoizedState=t},useHostTransitionStatus:wc,useFormState:q0,useActionState:q0,useOptimistic:function(l){var t=Vl();t.memoizedState=t.baseState=l;var u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=u,t=Wc.bind(null,Q,!0,u),u.dispatch=t,[l,t]},useMemoCache:Gc,useCacheRefresh:function(){return Vl().memoizedState=O4.bind(null,Q)}},a2={readContext:Yl,use:We,useCallback:K0,useContext:Yl,useEffect:X0,useImperativeHandle:L0,useInsertionEffect:Z0,useLayoutEffect:Q0,useMemo:J0,useReducer:$e,useRef:B0,useState:function(){return $e(qt)},useDebugValue:Lc,useDeferredValue:function(l,t){var u=Tl();return w0(u,el.memoizedState,l,t)},useTransition:function(){var l=$e(qt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:Ka(l),t]},useSyncExternalStore:A0,useId:F0,useHostTransitionStatus:wc,useFormState:x0,useActionState:x0,useOptimistic:function(l,t){var u=Tl();return U0(u,el,l,t)},useMemoCache:Gc,useCacheRefresh:P0},D4={readContext:Yl,use:We,useCallback:K0,useContext:Yl,useEffect:X0,useImperativeHandle:L0,useInsertionEffect:Z0,useLayoutEffect:Q0,useMemo:J0,useReducer:Zc,useRef:B0,useState:function(){return Zc(qt)},useDebugValue:Lc,useDeferredValue:function(l,t){var u=Tl();return el===null?Kc(u,l,t):w0(u,el.memoizedState,l,t)},useTransition:function(){var l=Zc(qt)[0],t=Tl().memoizedState;return[typeof l=="boolean"?l:Ka(l),t]},useSyncExternalStore:A0,useId:F0,useHostTransitionStatus:wc,useFormState:Y0,useActionState:Y0,useOptimistic:function(l,t){var u=Tl();return el!==null?U0(u,el,l,t):(u.baseState=l,[l,u.queue.dispatch])},useMemoCache:Gc,useCacheRefresh:P0},ea=null,Wa=0;function ln(l){var t=Wa;return Wa+=1,ea===null&&(ea=[]),y0(ea,l,t)}function $a(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function tn(l,t){throw t.$$typeof===w?Error(m(525)):(l=Object.prototype.toString.call(t),Error(m(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function e2(l){var t=l._init;return t(l._payload)}function n2(l){function t(o,d){if(l){var v=o.deletions;v===null?(o.deletions=[d],o.flags|=16):v.push(d)}}function u(o,d){if(!l)return null;for(;d!==null;)t(o,d),d=d.sibling;return null}function a(o){for(var d=new Map;o!==null;)o.key!==null?d.set(o.key,o):d.set(o.index,o),o=o.sibling;return d}function e(o,d){return o=Rt(o,d),o.index=0,o.sibling=null,o}function n(o,d,v){return o.index=v,l?(v=o.alternate,v!==null?(v=v.index,v<d?(o.flags|=67108866,d):v):(o.flags|=67108866,d)):(o.flags|=1048576,d)}function c(o){return l&&o.alternate===null&&(o.flags|=67108866),o}function f(o,d,v,b){return d===null||d.tag!==6?(d=rc(v,o.mode,b),d.return=o,d):(d=e(d,v),d.return=o,d)}function i(o,d,v,b){var D=v.type;return D===Rl?g(o,d,v.props.children,b,v.key):d!==null&&(d.elementType===D||typeof D=="object"&&D!==null&&D.$$typeof===Wl&&e2(D)===d.type)?(d=e(d,v.props),$a(d,v),d.return=o,d):(d=Ye(v.type,v.key,v.props,null,o.mode,b),$a(d,v),d.return=o,d)}function h(o,d,v,b){return d===null||d.tag!==4||d.stateNode.containerInfo!==v.containerInfo||d.stateNode.implementation!==v.implementation?(d=mc(v,o.mode,b),d.return=o,d):(d=e(d,v.children||[]),d.return=o,d)}function g(o,d,v,b,D){return d===null||d.tag!==7?(d=Eu(v,o.mode,b,D),d.return=o,d):(d=e(d,v),d.return=o,d)}function E(o,d,v){if(typeof d=="string"&&d!==""||typeof d=="number"||typeof d=="bigint")return d=rc(""+d,o.mode,v),d.return=o,d;if(typeof d=="object"&&d!==null){switch(d.$$typeof){case q:return v=Ye(d.type,d.key,d.props,null,o.mode,v),$a(v,d),v.return=o,v;case dl:return d=mc(d,o.mode,v),d.return=o,d;case Wl:var b=d._init;return d=b(d._payload),E(o,d,v)}if(xl(d)||ql(d))return d=Eu(d,o.mode,v,null),d.return=o,d;if(typeof d.then=="function")return E(o,ln(d),v);if(d.$$typeof===_l)return E(o,Ze(o,d),v);tn(o,d)}return null}function y(o,d,v,b){var D=d!==null?d.key:null;if(typeof v=="string"&&v!==""||typeof v=="number"||typeof v=="bigint")return D!==null?null:f(o,d,""+v,b);if(typeof v=="object"&&v!==null){switch(v.$$typeof){case q:return v.key===D?i(o,d,v,b):null;case dl:return v.key===D?h(o,d,v,b):null;case Wl:return D=v._init,v=D(v._payload),y(o,d,v,b)}if(xl(v)||ql(v))return D!==null?null:g(o,d,v,b,null);if(typeof v.then=="function")return y(o,d,ln(v),b);if(v.$$typeof===_l)return y(o,d,Ze(o,v),b);tn(o,v)}return null}function r(o,d,v,b,D){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return o=o.get(v)||null,f(d,o,""+b,D);if(typeof b=="object"&&b!==null){switch(b.$$typeof){case q:return o=o.get(b.key===null?v:b.key)||null,i(d,o,b,D);case dl:return o=o.get(b.key===null?v:b.key)||null,h(d,o,b,D);case Wl:var V=b._init;return b=V(b._payload),r(o,d,v,b,D)}if(xl(b)||ql(b))return o=o.get(v)||null,g(d,o,b,D,null);if(typeof b.then=="function")return r(o,d,v,ln(b),D);if(b.$$typeof===_l)return r(o,d,v,Ze(d,b),D);tn(d,b)}return null}function Y(o,d,v,b){for(var D=null,V=null,p=d,x=d=0,Ul=null;p!==null&&x<v.length;x++){p.index>x?(Ul=p,p=null):Ul=p.sibling;var F=y(o,p,v[x],b);if(F===null){p===null&&(p=Ul);break}l&&p&&F.alternate===null&&t(o,p),d=n(F,d,x),V===null?D=F:V.sibling=F,V=F,p=Ul}if(x===v.length)return u(o,p),ll&&Au(o,x),D;if(p===null){for(;x<v.length;x++)p=E(o,v[x],b),p!==null&&(d=n(p,d,x),V===null?D=p:V.sibling=p,V=p);return ll&&Au(o,x),D}for(p=a(p);x<v.length;x++)Ul=r(p,o,x,v[x],b),Ul!==null&&(l&&Ul.alternate!==null&&p.delete(Ul.key===null?x:Ul.key),d=n(Ul,d,x),V===null?D=Ul:V.sibling=Ul,V=Ul);return l&&p.forEach(function(vu){return t(o,vu)}),ll&&Au(o,x),D}function C(o,d,v,b){if(v==null)throw Error(m(151));for(var D=null,V=null,p=d,x=d=0,Ul=null,F=v.next();p!==null&&!F.done;x++,F=v.next()){p.index>x?(Ul=p,p=null):Ul=p.sibling;var vu=y(o,p,F.value,b);if(vu===null){p===null&&(p=Ul);break}l&&p&&vu.alternate===null&&t(o,p),d=n(vu,d,x),V===null?D=vu:V.sibling=vu,V=vu,p=Ul}if(F.done)return u(o,p),ll&&Au(o,x),D;if(p===null){for(;!F.done;x++,F=v.next())F=E(o,F.value,b),F!==null&&(d=n(F,d,x),V===null?D=F:V.sibling=F,V=F);return ll&&Au(o,x),D}for(p=a(p);!F.done;x++,F=v.next())F=r(p,o,x,F.value,b),F!==null&&(l&&F.alternate!==null&&p.delete(F.key===null?x:F.key),d=n(F,d,x),V===null?D=F:V.sibling=F,V=F);return l&&p.forEach(function(Ud){return t(o,Ud)}),ll&&Au(o,x),D}function cl(o,d,v,b){if(typeof v=="object"&&v!==null&&v.type===Rl&&v.key===null&&(v=v.props.children),typeof v=="object"&&v!==null){switch(v.$$typeof){case q:l:{for(var D=v.key;d!==null;){if(d.key===D){if(D=v.type,D===Rl){if(d.tag===7){u(o,d.sibling),b=e(d,v.props.children),b.return=o,o=b;break l}}else if(d.elementType===D||typeof D=="object"&&D!==null&&D.$$typeof===Wl&&e2(D)===d.type){u(o,d.sibling),b=e(d,v.props),$a(b,v),b.return=o,o=b;break l}u(o,d);break}else t(o,d);d=d.sibling}v.type===Rl?(b=Eu(v.props.children,o.mode,b,v.key),b.return=o,o=b):(b=Ye(v.type,v.key,v.props,null,o.mode,b),$a(b,v),b.return=o,o=b)}return c(o);case dl:l:{for(D=v.key;d!==null;){if(d.key===D)if(d.tag===4&&d.stateNode.containerInfo===v.containerInfo&&d.stateNode.implementation===v.implementation){u(o,d.sibling),b=e(d,v.children||[]),b.return=o,o=b;break l}else{u(o,d);break}else t(o,d);d=d.sibling}b=mc(v,o.mode,b),b.return=o,o=b}return c(o);case Wl:return D=v._init,v=D(v._payload),cl(o,d,v,b)}if(xl(v))return Y(o,d,v,b);if(ql(v)){if(D=ql(v),typeof D!="function")throw Error(m(150));return v=D.call(v),C(o,d,v,b)}if(typeof v.then=="function")return cl(o,d,ln(v),b);if(v.$$typeof===_l)return cl(o,d,Ze(o,v),b);tn(o,v)}return typeof v=="string"&&v!==""||typeof v=="number"||typeof v=="bigint"?(v=""+v,d!==null&&d.tag===6?(u(o,d.sibling),b=e(d,v),b.return=o,o=b):(u(o,d),b=rc(v,o.mode,b),b.return=o,o=b),c(o)):u(o,d)}return function(o,d,v,b){try{Wa=0;var D=cl(o,d,v,b);return ea=null,D}catch(p){if(p===Ga||p===Ve)throw p;var V=Il(29,p,null,o.mode);return V.lanes=b,V.return=o,V}finally{}}}var na=n2(!0),c2=n2(!1),ot=A(null),At=null;function Ft(l){var t=l.alternate;_(zl,zl.current&1),_(ot,l),At===null&&(t===null||la.current!==null||t.memoizedState!==null)&&(At=l)}function f2(l){if(l.tag===22){if(_(zl,zl.current),_(ot,l),At===null){var t=l.alternate;t!==null&&t.memoizedState!==null&&(At=l)}}else Pt()}function Pt(){_(zl,zl.current),_(ot,ot.current)}function xt(l){M(ot),At===l&&(At=null),M(zl)}var zl=A(0);function un(l){for(var t=l;t!==null;){if(t.tag===13){var u=t.memoizedState;if(u!==null&&(u=u.dehydrated,u===null||u.data==="$?"||Gf(u)))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}function $c(l,t,u,a){t=l.memoizedState,u=u(a,t),u=u==null?t:R({},t,u),l.memoizedState=u,l.lanes===0&&(l.updateQueue.baseState=u)}var kc={enqueueSetState:function(l,t,u){l=l._reactInternals;var a=at(),e=Wt(a);e.payload=t,u!=null&&(e.callback=u),t=$t(l,e,a),t!==null&&(et(t,l,a),Za(t,l,a))},enqueueReplaceState:function(l,t,u){l=l._reactInternals;var a=at(),e=Wt(a);e.tag=1,e.payload=t,u!=null&&(e.callback=u),t=$t(l,e,a),t!==null&&(et(t,l,a),Za(t,l,a))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var u=at(),a=Wt(u);a.tag=2,t!=null&&(a.callback=t),t=$t(l,a,u),t!==null&&(et(t,l,u),Za(t,l,u))}};function i2(l,t,u,a,e,n,c){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(a,n,c):t.prototype&&t.prototype.isPureReactComponent?!Na(u,a)||!Na(e,n):!0}function s2(l,t,u,a){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(u,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(u,a),t.state!==l&&kc.enqueueReplaceState(t,t.state,null)}function Ru(l,t){var u=t;if("ref"in t){u={};for(var a in t)a!=="ref"&&(u[a]=t[a])}if(l=l.defaultProps){u===t&&(u=R({},u));for(var e in l)u[e]===void 0&&(u[e]=l[e])}return u}var an=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)};function d2(l){an(l)}function o2(l){console.error(l)}function v2(l){an(l)}function en(l,t){try{var u=l.onUncaughtError;u(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function h2(l,t,u){try{var a=l.onCaughtError;a(u.value,{componentStack:u.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function Fc(l,t,u){return u=Wt(u),u.tag=3,u.payload={element:null},u.callback=function(){en(l,t)},u}function y2(l){return l=Wt(l),l.tag=3,l}function r2(l,t,u,a){var e=u.type.getDerivedStateFromError;if(typeof e=="function"){var n=a.value;l.payload=function(){return e(n)},l.callback=function(){h2(t,u,a)}}var c=u.stateNode;c!==null&&typeof c.componentDidCatch=="function"&&(l.callback=function(){h2(t,u,a),typeof e!="function"&&(eu===null?eu=new Set([this]):eu.add(this));var f=a.stack;this.componentDidCatch(a.value,{componentStack:f!==null?f:""})})}function U4(l,t,u,a,e){if(u.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=u.alternate,t!==null&&ja(t,u,e,!0),u=ot.current,u!==null){switch(u.tag){case 13:return At===null?Af():u.alternate===null&&gl===0&&(gl=3),u.flags&=-257,u.flags|=65536,u.lanes=e,a===Mc?u.flags|=16384:(t=u.updateQueue,t===null?u.updateQueue=new Set([a]):t.add(a),_f(l,a,e)),!1;case 22:return u.flags|=65536,a===Mc?u.flags|=16384:(t=u.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},u.updateQueue=t):(u=t.retryQueue,u===null?t.retryQueue=new Set([a]):u.add(a)),_f(l,a,e)),!1}throw Error(m(435,u.tag))}return _f(l,a,e),Af(),!1}if(ll)return t=ot.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=e,a!==bc&&(l=Error(m(422),{cause:a}),xa(ft(l,u)))):(a!==bc&&(t=Error(m(423),{cause:a}),xa(ft(t,u))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,a=ft(a,u),e=Fc(l.stateNode,a,e),Rc(l,e),gl!==4&&(gl=2)),!1;var n=Error(m(520),{cause:a});if(n=ft(n,u),ue===null?ue=[n]:ue.push(n),gl!==4&&(gl=2),t===null)return!0;a=ft(a,u),u=t;do{switch(u.tag){case 3:return u.flags|=65536,l=e&-e,u.lanes|=l,l=Fc(u.stateNode,a,l),Rc(u,l),!1;case 1:if(t=u.type,n=u.stateNode,(u.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(eu===null||!eu.has(n))))return u.flags|=65536,e&=-e,u.lanes|=e,e=y2(e),r2(e,l,u,a),Rc(u,e),!1}u=u.return}while(u!==null);return!1}var m2=Error(m(461)),Ml=!1;function Nl(l,t,u,a){t.child=l===null?c2(t,null,u,a):na(t,l.child,u,a)}function g2(l,t,u,a,e){u=u.render;var n=t.ref;if("ref"in a){var c={};for(var f in a)f!=="ref"&&(c[f]=a[f])}else c=a;return Mu(t),a=qc(l,t,u,c,n,e),f=xc(),l!==null&&!Ml?(jc(l,t,e),jt(l,t,e)):(ll&&f&&gc(t),t.flags|=1,Nl(l,t,a,e),t.child)}function S2(l,t,u,a,e){if(l===null){var n=u.type;return typeof n=="function"&&!yc(n)&&n.defaultProps===void 0&&u.compare===null?(t.tag=15,t.type=n,b2(l,t,n,a,e)):(l=Ye(u.type,null,a,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!nf(l,e)){var c=n.memoizedProps;if(u=u.compare,u=u!==null?u:Na,u(c,a)&&l.ref===t.ref)return jt(l,t,e)}return t.flags|=1,l=Rt(n,a),l.ref=t.ref,l.return=t,t.child=l}function b2(l,t,u,a,e){if(l!==null){var n=l.memoizedProps;if(Na(n,a)&&l.ref===t.ref)if(Ml=!1,t.pendingProps=a=n,nf(l,e))(l.flags&131072)!==0&&(Ml=!0);else return t.lanes=l.lanes,jt(l,t,e)}return Pc(l,t,u,a,e)}function E2(l,t,u){var a=t.pendingProps,e=a.children,n=l!==null?l.memoizedState:null;if(a.mode==="hidden"){if((t.flags&128)!==0){if(a=n!==null?n.baseLanes|u:u,l!==null){for(e=t.child=l.child,n=0;e!==null;)n=n|e.lanes|e.childLanes,e=e.sibling;t.childLanes=n&~a}else t.childLanes=0,t.child=null;return T2(l,t,a,u)}if((u&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&Qe(t,n!==null?n.cachePool:null),n!==null?b0(t,n):Nc(),f2(t);else return t.lanes=t.childLanes=536870912,T2(l,t,n!==null?n.baseLanes|u:u,u)}else n!==null?(Qe(t,n.cachePool),b0(t,n),Pt(),t.memoizedState=null):(l!==null&&Qe(t,null),Nc(),Pt());return Nl(l,t,e,u),t.child}function T2(l,t,u,a){var e=Oc();return e=e===null?null:{parent:Al._currentValue,pool:e},t.memoizedState={baseLanes:u,cachePool:e},l!==null&&Qe(t,null),Nc(),f2(t),l!==null&&ja(l,t,a,!0),null}function nn(l,t){var u=t.ref;if(u===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof u!="function"&&typeof u!="object")throw Error(m(284));(l===null||l.ref!==u)&&(t.flags|=4194816)}}function Pc(l,t,u,a,e){return Mu(t),u=qc(l,t,u,a,void 0,e),a=xc(),l!==null&&!Ml?(jc(l,t,e),jt(l,t,e)):(ll&&a&&gc(t),t.flags|=1,Nl(l,t,u,e),t.child)}function A2(l,t,u,a,e,n){return Mu(t),t.updateQueue=null,u=T0(t,a,u,e),E0(l),a=xc(),l!==null&&!Ml?(jc(l,t,n),jt(l,t,n)):(ll&&a&&gc(t),t.flags|=1,Nl(l,t,u,n),t.child)}function z2(l,t,u,a,e){if(Mu(t),t.stateNode===null){var n=$u,c=u.contextType;typeof c=="object"&&c!==null&&(n=Yl(c)),n=new u(a,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=kc,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=a,n.state=t.memoizedState,n.refs={},Dc(t),c=u.contextType,n.context=typeof c=="object"&&c!==null?Yl(c):$u,n.state=t.memoizedState,c=u.getDerivedStateFromProps,typeof c=="function"&&($c(t,u,c,a),n.state=t.memoizedState),typeof u.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(c=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),c!==n.state&&kc.enqueueReplaceState(n,n.state,null),Va(t,a,n,e),Qa(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(l===null){n=t.stateNode;var f=t.memoizedProps,i=Ru(u,f);n.props=i;var h=n.context,g=u.contextType;c=$u,typeof g=="object"&&g!==null&&(c=Yl(g));var E=u.getDerivedStateFromProps;g=typeof E=="function"||typeof n.getSnapshotBeforeUpdate=="function",f=t.pendingProps!==f,g||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f||h!==c)&&s2(t,n,a,c),wt=!1;var y=t.memoizedState;n.state=y,Va(t,a,n,e),Qa(),h=t.memoizedState,f||y!==h||wt?(typeof E=="function"&&($c(t,u,E,a),h=t.memoizedState),(i=wt||i2(t,u,i,a,y,h,c))?(g||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=h),n.props=a,n.state=h,n.context=c,a=i):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{n=t.stateNode,Uc(l,t),c=t.memoizedProps,g=Ru(u,c),n.props=g,E=t.pendingProps,y=n.context,h=u.contextType,i=$u,typeof h=="object"&&h!==null&&(i=Yl(h)),f=u.getDerivedStateFromProps,(h=typeof f=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(c!==E||y!==i)&&s2(t,n,a,i),wt=!1,y=t.memoizedState,n.state=y,Va(t,a,n,e),Qa();var r=t.memoizedState;c!==E||y!==r||wt||l!==null&&l.dependencies!==null&&Xe(l.dependencies)?(typeof f=="function"&&($c(t,u,f,a),r=t.memoizedState),(g=wt||i2(t,u,g,a,y,r,i)||l!==null&&l.dependencies!==null&&Xe(l.dependencies))?(h||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(a,r,i),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(a,r,i)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||c===l.memoizedProps&&y===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||c===l.memoizedProps&&y===l.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=r),n.props=a,n.state=r,n.context=i,a=g):(typeof n.componentDidUpdate!="function"||c===l.memoizedProps&&y===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||c===l.memoizedProps&&y===l.memoizedState||(t.flags|=1024),a=!1)}return n=a,nn(l,t),a=(t.flags&128)!==0,n||a?(n=t.stateNode,u=a&&typeof u.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&a?(t.child=na(t,l.child,null,e),t.child=na(t,null,u,e)):Nl(l,t,u,e),t.memoizedState=n.state,l=t.child):l=jt(l,t,e),l}function _2(l,t,u,a){return qa(),t.flags|=256,Nl(l,t,u,a),t.child}var Ic={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function lf(l){return{baseLanes:l,cachePool:o0()}}function tf(l,t,u){return l=l!==null?l.childLanes&~u:0,t&&(l|=vt),l}function O2(l,t,u){var a=t.pendingProps,e=!1,n=(t.flags&128)!==0,c;if((c=n)||(c=l!==null&&l.memoizedState===null?!1:(zl.current&2)!==0),c&&(e=!0,t.flags&=-129),c=(t.flags&32)!==0,t.flags&=-33,l===null){if(ll){if(e?Ft(t):Pt(),ll){var f=ml,i;if(i=f){l:{for(i=f,f=Tt;i.nodeType!==8;){if(!f){f=null;break l}if(i=St(i.nextSibling),i===null){f=null;break l}}f=i}f!==null?(t.memoizedState={dehydrated:f,treeContext:Tu!==null?{id:pt,overflow:Nt}:null,retryLane:536870912,hydrationErrors:null},i=Il(18,null,null,0),i.stateNode=f,i.return=t,t.child=i,Gl=t,ml=null,i=!0):i=!1}i||_u(t)}if(f=t.memoizedState,f!==null&&(f=f.dehydrated,f!==null))return Gf(f)?t.lanes=32:t.lanes=536870912,null;xt(t)}return f=a.children,a=a.fallback,e?(Pt(),e=t.mode,f=cn({mode:"hidden",children:f},e),a=Eu(a,e,u,null),f.return=t,a.return=t,f.sibling=a,t.child=f,e=t.child,e.memoizedState=lf(u),e.childLanes=tf(l,c,u),t.memoizedState=Ic,a):(Ft(t),uf(t,f))}if(i=l.memoizedState,i!==null&&(f=i.dehydrated,f!==null)){if(n)t.flags&256?(Ft(t),t.flags&=-257,t=af(l,t,u)):t.memoizedState!==null?(Pt(),t.child=l.child,t.flags|=128,t=null):(Pt(),e=a.fallback,f=t.mode,a=cn({mode:"visible",children:a.children},f),e=Eu(e,f,u,null),e.flags|=2,a.return=t,e.return=t,a.sibling=e,t.child=a,na(t,l.child,null,u),a=t.child,a.memoizedState=lf(u),a.childLanes=tf(l,c,u),t.memoizedState=Ic,t=e);else if(Ft(t),Gf(f)){if(c=f.nextSibling&&f.nextSibling.dataset,c)var h=c.dgst;c=h,a=Error(m(419)),a.stack="",a.digest=c,xa({value:a,source:null,stack:null}),t=af(l,t,u)}else if(Ml||ja(l,t,u,!1),c=(u&l.childLanes)!==0,Ml||c){if(c=sl,c!==null&&(a=u&-u,a=(a&42)!==0?1:Gn(a),a=(a&(c.suspendedLanes|u))!==0?0:a,a!==0&&a!==i.retryLane))throw i.retryLane=a,Wu(l,a),et(c,l,a),m2;f.data==="$?"||Af(),t=af(l,t,u)}else f.data==="$?"?(t.flags|=192,t.child=l.child,t=null):(l=i.treeContext,ml=St(f.nextSibling),Gl=t,ll=!0,zu=null,Tt=!1,l!==null&&(st[dt++]=pt,st[dt++]=Nt,st[dt++]=Tu,pt=l.id,Nt=l.overflow,Tu=t),t=uf(t,a.children),t.flags|=4096);return t}return e?(Pt(),e=a.fallback,f=t.mode,i=l.child,h=i.sibling,a=Rt(i,{mode:"hidden",children:a.children}),a.subtreeFlags=i.subtreeFlags&65011712,h!==null?e=Rt(h,e):(e=Eu(e,f,u,null),e.flags|=2),e.return=t,a.return=t,a.sibling=e,t.child=a,a=e,e=t.child,f=l.child.memoizedState,f===null?f=lf(u):(i=f.cachePool,i!==null?(h=Al._currentValue,i=i.parent!==h?{parent:h,pool:h}:i):i=o0(),f={baseLanes:f.baseLanes|u,cachePool:i}),e.memoizedState=f,e.childLanes=tf(l,c,u),t.memoizedState=Ic,a):(Ft(t),u=l.child,l=u.sibling,u=Rt(u,{mode:"visible",children:a.children}),u.return=t,u.sibling=null,l!==null&&(c=t.deletions,c===null?(t.deletions=[l],t.flags|=16):c.push(l)),t.child=u,t.memoizedState=null,u)}function uf(l,t){return t=cn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function cn(l,t){return l=Il(22,l,null,t),l.lanes=0,l.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},l}function af(l,t,u){return na(t,l.child,null,u),l=uf(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function M2(l,t,u){l.lanes|=t;var a=l.alternate;a!==null&&(a.lanes|=t),Tc(l.return,t,u)}function ef(l,t,u,a,e){var n=l.memoizedState;n===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:u,tailMode:e}:(n.isBackwards=t,n.rendering=null,n.renderingStartTime=0,n.last=a,n.tail=u,n.tailMode=e)}function D2(l,t,u){var a=t.pendingProps,e=a.revealOrder,n=a.tail;if(Nl(l,t,a.children,u),a=zl.current,(a&2)!==0)a=a&1|2,t.flags|=128;else{if(l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&M2(l,u,t);else if(l.tag===19)M2(l,u,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}a&=1}switch(_(zl,a),e){case"forwards":for(u=t.child,e=null;u!==null;)l=u.alternate,l!==null&&un(l)===null&&(e=u),u=u.sibling;u=e,u===null?(e=t.child,t.child=null):(e=u.sibling,u.sibling=null),ef(t,!1,e,u,n);break;case"backwards":for(u=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&un(l)===null){t.child=e;break}l=e.sibling,e.sibling=u,u=e,e=l}ef(t,!0,u,null,n);break;case"together":ef(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function jt(l,t,u){if(l!==null&&(t.dependencies=l.dependencies),au|=t.lanes,(u&t.childLanes)===0)if(l!==null){if(ja(l,t,u,!1),(u&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(m(153));if(t.child!==null){for(l=t.child,u=Rt(l,l.pendingProps),t.child=u,u.return=t;l.sibling!==null;)l=l.sibling,u=u.sibling=Rt(l,l.pendingProps),u.return=t;u.sibling=null}return t.child}function nf(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Xe(l)))}function R4(l,t,u){switch(t.tag){case 3:vl(t,t.stateNode.containerInfo),Jt(t,Al,l.memoizedState.cache),qa();break;case 27:case 5:qn(t);break;case 4:vl(t,t.stateNode.containerInfo);break;case 10:Jt(t,t.type,t.memoizedProps.value);break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(Ft(t),t.flags|=128,null):(u&t.child.childLanes)!==0?O2(l,t,u):(Ft(t),l=jt(l,t,u),l!==null?l.sibling:null);Ft(t);break;case 19:var e=(l.flags&128)!==0;if(a=(u&t.childLanes)!==0,a||(ja(l,t,u,!1),a=(u&t.childLanes)!==0),e){if(a)return D2(l,t,u);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),_(zl,zl.current),a)break;return null;case 22:case 23:return t.lanes=0,E2(l,t,u);case 24:Jt(t,Al,l.memoizedState.cache)}return jt(l,t,u)}function U2(l,t,u){if(l!==null)if(l.memoizedProps!==t.pendingProps)Ml=!0;else{if(!nf(l,u)&&(t.flags&128)===0)return Ml=!1,R4(l,t,u);Ml=(l.flags&131072)!==0}else Ml=!1,ll&&(t.flags&1048576)!==0&&e0(t,Ge,t.index);switch(t.lanes=0,t.tag){case 16:l:{l=t.pendingProps;var a=t.elementType,e=a._init;if(a=e(a._payload),t.type=a,typeof a=="function")yc(a)?(l=Ru(a,l),t.tag=1,t=z2(null,t,a,l,u)):(t.tag=0,t=Pc(null,t,a,l,u));else{if(a!=null){if(e=a.$$typeof,e===rt){t.tag=11,t=g2(null,t,a,l,u);break l}else if(e===wl){t.tag=14,t=S2(null,t,a,l,u);break l}}throw t=yu(a)||a,Error(m(306,t,""))}}return t;case 0:return Pc(l,t,t.type,t.pendingProps,u);case 1:return a=t.type,e=Ru(a,t.pendingProps),z2(l,t,a,e,u);case 3:l:{if(vl(t,t.stateNode.containerInfo),l===null)throw Error(m(387));a=t.pendingProps;var n=t.memoizedState;e=n.element,Uc(l,t),Va(t,a,null,u);var c=t.memoizedState;if(a=c.cache,Jt(t,Al,a),a!==n.cache&&Ac(t,[Al],u,!0),Qa(),a=c.element,n.isDehydrated)if(n={element:a,isDehydrated:!1,cache:c.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=_2(l,t,a,u);break l}else if(a!==e){e=ft(Error(m(424)),t),xa(e),t=_2(l,t,a,u);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(ml=St(l.firstChild),Gl=t,ll=!0,zu=null,Tt=!0,u=c2(t,null,a,u),t.child=u;u;)u.flags=u.flags&-3|4096,u=u.sibling}else{if(qa(),a===e){t=jt(l,t,u);break l}Nl(l,t,a,u)}t=t.child}return t;case 26:return nn(l,t),l===null?(u=H1(t.type,null,t.pendingProps,null))?t.memoizedState=u:ll||(u=t.type,l=t.pendingProps,a=Tn(G.current).createElement(u),a[jl]=t,a[Zl]=l,Cl(a,u,l),Ol(a),t.stateNode=a):t.memoizedState=H1(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return qn(t),l===null&&ll&&(a=t.stateNode=R1(t.type,t.pendingProps,G.current),Gl=t,Tt=!0,e=ml,fu(t.type)?(Xf=e,ml=St(a.firstChild)):ml=e),Nl(l,t,t.pendingProps.children,u),nn(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&ll&&((e=a=ml)&&(a=ad(a,t.type,t.pendingProps,Tt),a!==null?(t.stateNode=a,Gl=t,ml=St(a.firstChild),Tt=!1,e=!0):e=!1),e||_u(t)),qn(t),e=t.type,n=t.pendingProps,c=l!==null?l.memoizedProps:null,a=n.children,jf(e,n)?a=null:c!==null&&jf(e,c)&&(t.flags|=32),t.memoizedState!==null&&(e=qc(l,t,T4,null,null,u),oe._currentValue=e),nn(l,t),Nl(l,t,a,u),t.child;case 6:return l===null&&ll&&((l=u=ml)&&(u=ed(u,t.pendingProps,Tt),u!==null?(t.stateNode=u,Gl=t,ml=null,l=!0):l=!1),l||_u(t)),null;case 13:return O2(l,t,u);case 4:return vl(t,t.stateNode.containerInfo),a=t.pendingProps,l===null?t.child=na(t,null,a,u):Nl(l,t,a,u),t.child;case 11:return g2(l,t,t.type,t.pendingProps,u);case 7:return Nl(l,t,t.pendingProps,u),t.child;case 8:return Nl(l,t,t.pendingProps.children,u),t.child;case 12:return Nl(l,t,t.pendingProps.children,u),t.child;case 10:return a=t.pendingProps,Jt(t,t.type,a.value),Nl(l,t,a.children,u),t.child;case 9:return e=t.type._context,a=t.pendingProps.children,Mu(t),e=Yl(e),a=a(e),t.flags|=1,Nl(l,t,a,u),t.child;case 14:return S2(l,t,t.type,t.pendingProps,u);case 15:return b2(l,t,t.type,t.pendingProps,u);case 19:return D2(l,t,u);case 31:return a=t.pendingProps,u=t.mode,a={mode:a.mode,children:a.children},l===null?(u=cn(a,u),u.ref=t.ref,t.child=u,u.return=t,t=u):(u=Rt(l.child,a),u.ref=t.ref,t.child=u,u.return=t,t=u),t;case 22:return E2(l,t,u);case 24:return Mu(t),a=Yl(Al),l===null?(e=Oc(),e===null&&(e=sl,n=zc(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=u),e=n),t.memoizedState={parent:a,cache:e},Dc(t),Jt(t,Al,e)):((l.lanes&u)!==0&&(Uc(l,t),Va(t,null,null,u),Qa()),e=l.memoizedState,n=t.memoizedState,e.parent!==a?(e={parent:a,cache:a},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),Jt(t,Al,a)):(a=n.cache,Jt(t,Al,a),a!==e.cache&&Ac(t,[Al],u,!0))),Nl(l,t,t.pendingProps.children,u),t.child;case 29:throw t.pendingProps}throw Error(m(156,t.tag))}function Yt(l){l.flags|=4}function R2(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!Y1(t)){if(t=ot.current,t!==null&&((W&4194048)===W?At!==null:(W&62914560)!==W&&(W&536870912)===0||t!==At))throw Xa=Mc,v0;l.flags|=8192}}function fn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?fi():536870912,l.lanes|=t,sa|=t)}function ka(l,t){if(!ll)switch(l.tailMode){case"hidden":t=l.tail;for(var u=null;t!==null;)t.alternate!==null&&(u=t),t=t.sibling;u===null?l.tail=null:u.sibling=null;break;case"collapsed":u=l.tail;for(var a=null;u!==null;)u.alternate!==null&&(a=u),u=u.sibling;a===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:a.sibling=null}}function rl(l){var t=l.alternate!==null&&l.alternate.child===l.child,u=0,a=0;if(t)for(var e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags&65011712,a|=e.flags&65011712,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags,a|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=a,l.childLanes=u,t}function p4(l,t,u){var a=t.pendingProps;switch(Sc(t),t.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return rl(t),null;case 1:return rl(t),null;case 3:return u=t.stateNode,a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Ct(Al),Qt(),u.pendingContext&&(u.context=u.pendingContext,u.pendingContext=null),(l===null||l.child===null)&&(Ca(t)?Yt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,f0())),rl(t),null;case 26:return u=t.memoizedState,l===null?(Yt(t),u!==null?(rl(t),R2(t,u)):(rl(t),t.flags&=-16777217)):u?u!==l.memoizedState?(Yt(t),rl(t),R2(t,u)):(rl(t),t.flags&=-16777217):(l.memoizedProps!==a&&Yt(t),rl(t),t.flags&=-16777217),null;case 27:Se(t),u=G.current;var e=t.type;if(l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(!a){if(t.stateNode===null)throw Error(m(166));return rl(t),null}l=H.current,Ca(t)?n0(t):(l=R1(e,a,u),t.stateNode=l,Yt(t))}return rl(t),null;case 5:if(Se(t),u=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(!a){if(t.stateNode===null)throw Error(m(166));return rl(t),null}if(l=H.current,Ca(t))n0(t);else{switch(e=Tn(G.current),l){case 1:l=e.createElementNS("http://www.w3.org/2000/svg",u);break;case 2:l=e.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;default:switch(u){case"svg":l=e.createElementNS("http://www.w3.org/2000/svg",u);break;case"math":l=e.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;case"script":l=e.createElement("div"),l.innerHTML="<script><\/script>",l=l.removeChild(l.firstChild);break;case"select":l=typeof a.is=="string"?e.createElement("select",{is:a.is}):e.createElement("select"),a.multiple?l.multiple=!0:a.size&&(l.size=a.size);break;default:l=typeof a.is=="string"?e.createElement(u,{is:a.is}):e.createElement(u)}}l[jl]=t,l[Zl]=a;l:for(e=t.child;e!==null;){if(e.tag===5||e.tag===6)l.appendChild(e.stateNode);else if(e.tag!==4&&e.tag!==27&&e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break l;for(;e.sibling===null;){if(e.return===null||e.return===t)break l;e=e.return}e.sibling.return=e.return,e=e.sibling}t.stateNode=l;l:switch(Cl(l,u,a),u){case"button":case"input":case"select":case"textarea":l=!!a.autoFocus;break l;case"img":l=!0;break l;default:l=!1}l&&Yt(t)}}return rl(t),t.flags&=-16777217,null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(m(166));if(l=G.current,Ca(t)){if(l=t.stateNode,u=t.memoizedProps,a=null,e=Gl,e!==null)switch(e.tag){case 27:case 5:a=e.memoizedProps}l[jl]=t,l=!!(l.nodeValue===u||a!==null&&a.suppressHydrationWarning===!0||A1(l.nodeValue,u)),l||_u(t)}else l=Tn(l).createTextNode(a),l[jl]=t,t.stateNode=l}return rl(t),null;case 13:if(a=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=Ca(t),a!==null&&a.dehydrated!==null){if(l===null){if(!e)throw Error(m(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(m(317));e[jl]=t}else qa(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;rl(t),e=!1}else e=f0(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),e=!0;if(!e)return t.flags&256?(xt(t),t):(xt(t),null)}if(xt(t),(t.flags&128)!==0)return t.lanes=u,t;if(u=a!==null,l=l!==null&&l.memoizedState!==null,u){a=t.child,e=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(e=a.alternate.memoizedState.cachePool.pool);var n=null;a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(n=a.memoizedState.cachePool.pool),n!==e&&(a.flags|=2048)}return u!==l&&u&&(t.child.flags|=8192),fn(t,t.updateQueue),rl(t),null;case 4:return Qt(),l===null&&Nf(t.stateNode.containerInfo),rl(t),null;case 10:return Ct(t.type),rl(t),null;case 19:if(M(zl),e=t.memoizedState,e===null)return rl(t),null;if(a=(t.flags&128)!==0,n=e.rendering,n===null)if(a)ka(e,!1);else{if(gl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=un(l),n!==null){for(t.flags|=128,ka(e,!1),l=n.updateQueue,t.updateQueue=l,fn(t,l),t.subtreeFlags=0,l=u,u=t.child;u!==null;)a0(u,l),u=u.sibling;return _(zl,zl.current&1|2),t.child}l=l.sibling}e.tail!==null&&Et()>on&&(t.flags|=128,a=!0,ka(e,!1),t.lanes=4194304)}else{if(!a)if(l=un(n),l!==null){if(t.flags|=128,a=!0,l=l.updateQueue,t.updateQueue=l,fn(t,l),ka(e,!0),e.tail===null&&e.tailMode==="hidden"&&!n.alternate&&!ll)return rl(t),null}else 2*Et()-e.renderingStartTime>on&&u!==536870912&&(t.flags|=128,a=!0,ka(e,!1),t.lanes=4194304);e.isBackwards?(n.sibling=t.child,t.child=n):(l=e.last,l!==null?l.sibling=n:t.child=n,e.last=n)}return e.tail!==null?(t=e.tail,e.rendering=t,e.tail=t.sibling,e.renderingStartTime=Et(),t.sibling=null,l=zl.current,_(zl,a?l&1|2:l&1),t):(rl(t),null);case 22:case 23:return xt(t),Hc(),a=t.memoizedState!==null,l!==null?l.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?(u&536870912)!==0&&(t.flags&128)===0&&(rl(t),t.subtreeFlags&6&&(t.flags|=8192)):rl(t),u=t.updateQueue,u!==null&&fn(t,u.retryQueue),u=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==u&&(t.flags|=2048),l!==null&&M(Du),null;case 24:return u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),Ct(Al),rl(t),null;case 25:return null;case 30:return null}throw Error(m(156,t.tag))}function N4(l,t){switch(Sc(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Ct(Al),Qt(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return Se(t),null;case 13:if(xt(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(m(340));qa()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return M(zl),null;case 4:return Qt(),null;case 10:return Ct(t.type),null;case 22:case 23:return xt(t),Hc(),l!==null&&M(Du),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Ct(Al),null;case 25:return null;default:return null}}function p2(l,t){switch(Sc(t),t.tag){case 3:Ct(Al),Qt();break;case 26:case 27:case 5:Se(t);break;case 4:Qt();break;case 13:xt(t);break;case 19:M(zl);break;case 10:Ct(t.type);break;case 22:case 23:xt(t),Hc(),l!==null&&M(Du);break;case 24:Ct(Al)}}function Fa(l,t){try{var u=t.updateQueue,a=u!==null?u.lastEffect:null;if(a!==null){var e=a.next;u=e;do{if((u.tag&l)===l){a=void 0;var n=u.create,c=u.inst;a=n(),c.destroy=a}u=u.next}while(u!==e)}}catch(f){il(t,t.return,f)}}function It(l,t,u){try{var a=t.updateQueue,e=a!==null?a.lastEffect:null;if(e!==null){var n=e.next;a=n;do{if((a.tag&l)===l){var c=a.inst,f=c.destroy;if(f!==void 0){c.destroy=void 0,e=t;var i=u,h=f;try{h()}catch(g){il(e,i,g)}}}a=a.next}while(a!==n)}}catch(g){il(t,t.return,g)}}function N2(l){var t=l.updateQueue;if(t!==null){var u=l.stateNode;try{S0(t,u)}catch(a){il(l,l.return,a)}}}function H2(l,t,u){u.props=Ru(l.type,l.memoizedProps),u.state=l.memoizedState;try{u.componentWillUnmount()}catch(a){il(l,t,a)}}function Pa(l,t){try{var u=l.ref;if(u!==null){switch(l.tag){case 26:case 27:case 5:var a=l.stateNode;break;case 30:a=l.stateNode;break;default:a=l.stateNode}typeof u=="function"?l.refCleanup=u(a):u.current=a}}catch(e){il(l,t,e)}}function zt(l,t){var u=l.ref,a=l.refCleanup;if(u!==null)if(typeof a=="function")try{a()}catch(e){il(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof u=="function")try{u(null)}catch(e){il(l,t,e)}else u.current=null}function C2(l){var t=l.type,u=l.memoizedProps,a=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":u.autoFocus&&a.focus();break l;case"img":u.src?a.src=u.src:u.srcSet&&(a.srcset=u.srcSet)}}catch(e){il(l,l.return,e)}}function cf(l,t,u){try{var a=l.stateNode;P4(a,l.type,u,t),a[Zl]=t}catch(e){il(l,l.return,e)}}function q2(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&fu(l.type)||l.tag===4}function ff(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||q2(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&fu(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function sf(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?(u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u).insertBefore(l,t):(t=u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u,t.appendChild(l),u=u._reactRootContainer,u!=null||t.onclick!==null||(t.onclick=En));else if(a!==4&&(a===27&&fu(l.type)&&(u=l.stateNode,t=null),l=l.child,l!==null))for(sf(l,t,u),l=l.sibling;l!==null;)sf(l,t,u),l=l.sibling}function sn(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?u.insertBefore(l,t):u.appendChild(l);else if(a!==4&&(a===27&&fu(l.type)&&(u=l.stateNode),l=l.child,l!==null))for(sn(l,t,u),l=l.sibling;l!==null;)sn(l,t,u),l=l.sibling}function x2(l){var t=l.stateNode,u=l.memoizedProps;try{for(var a=l.type,e=t.attributes;e.length;)t.removeAttributeNode(e[0]);Cl(t,a,u),t[jl]=l,t[Zl]=u}catch(n){il(l,l.return,n)}}var Bt=!1,bl=!1,df=!1,j2=typeof WeakSet=="function"?WeakSet:Set,Dl=null;function H4(l,t){if(l=l.containerInfo,qf=Dn,l=wi(l),fc(l)){if("selectionStart"in l)var u={start:l.selectionStart,end:l.selectionEnd};else l:{u=(u=l.ownerDocument)&&u.defaultView||window;var a=u.getSelection&&u.getSelection();if(a&&a.rangeCount!==0){u=a.anchorNode;var e=a.anchorOffset,n=a.focusNode;a=a.focusOffset;try{u.nodeType,n.nodeType}catch{u=null;break l}var c=0,f=-1,i=-1,h=0,g=0,E=l,y=null;t:for(;;){for(var r;E!==u||e!==0&&E.nodeType!==3||(f=c+e),E!==n||a!==0&&E.nodeType!==3||(i=c+a),E.nodeType===3&&(c+=E.nodeValue.length),(r=E.firstChild)!==null;)y=E,E=r;for(;;){if(E===l)break t;if(y===u&&++h===e&&(f=c),y===n&&++g===a&&(i=c),(r=E.nextSibling)!==null)break;E=y,y=E.parentNode}E=r}u=f===-1||i===-1?null:{start:f,end:i}}else u=null}u=u||{start:0,end:0}}else u=null;for(xf={focusedElem:l,selectionRange:u},Dn=!1,Dl=t;Dl!==null;)if(t=Dl,l=t.child,(t.subtreeFlags&1024)!==0&&l!==null)l.return=t,Dl=l;else for(;Dl!==null;){switch(t=Dl,n=t.alternate,l=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,u=t,e=n.memoizedProps,n=n.memoizedState,a=u.stateNode;try{var Y=Ru(u.type,e,u.elementType===u.type);l=a.getSnapshotBeforeUpdate(Y,n),a.__reactInternalSnapshotBeforeUpdate=l}catch(C){il(u,u.return,C)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,u=l.nodeType,u===9)Bf(l);else if(u===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":Bf(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(m(163))}if(l=t.sibling,l!==null){l.return=t.return,Dl=l;break}Dl=t.return}}function Y2(l,t,u){var a=u.flags;switch(u.tag){case 0:case 11:case 15:lu(l,u),a&4&&Fa(5,u);break;case 1:if(lu(l,u),a&4)if(l=u.stateNode,t===null)try{l.componentDidMount()}catch(c){il(u,u.return,c)}else{var e=Ru(u.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(c){il(u,u.return,c)}}a&64&&N2(u),a&512&&Pa(u,u.return);break;case 3:if(lu(l,u),a&64&&(l=u.updateQueue,l!==null)){if(t=null,u.child!==null)switch(u.child.tag){case 27:case 5:t=u.child.stateNode;break;case 1:t=u.child.stateNode}try{S0(l,t)}catch(c){il(u,u.return,c)}}break;case 27:t===null&&a&4&&x2(u);case 26:case 5:lu(l,u),t===null&&a&4&&C2(u),a&512&&Pa(u,u.return);break;case 12:lu(l,u);break;case 13:lu(l,u),a&4&&X2(l,u),a&64&&(l=u.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(u=Z4.bind(null,u),nd(l,u))));break;case 22:if(a=u.memoizedState!==null||Bt,!a){t=t!==null&&t.memoizedState!==null||bl,e=Bt;var n=bl;Bt=a,(bl=t)&&!n?tu(l,u,(u.subtreeFlags&8772)!==0):lu(l,u),Bt=e,bl=n}break;case 30:break;default:lu(l,u)}}function B2(l){var t=l.alternate;t!==null&&(l.alternate=null,B2(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&Qn(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var hl=null,Ll=!1;function Gt(l,t,u){for(u=u.child;u!==null;)G2(l,t,u),u=u.sibling}function G2(l,t,u){if(kl&&typeof kl.onCommitFiberUnmount=="function")try{kl.onCommitFiberUnmount(ba,u)}catch{}switch(u.tag){case 26:bl||zt(u,t),Gt(l,t,u),u.memoizedState?u.memoizedState.count--:u.stateNode&&(u=u.stateNode,u.parentNode.removeChild(u));break;case 27:bl||zt(u,t);var a=hl,e=Ll;fu(u.type)&&(hl=u.stateNode,Ll=!1),Gt(l,t,u),fe(u.stateNode),hl=a,Ll=e;break;case 5:bl||zt(u,t);case 6:if(a=hl,e=Ll,hl=null,Gt(l,t,u),hl=a,Ll=e,hl!==null)if(Ll)try{(hl.nodeType===9?hl.body:hl.nodeName==="HTML"?hl.ownerDocument.body:hl).removeChild(u.stateNode)}catch(n){il(u,t,n)}else try{hl.removeChild(u.stateNode)}catch(n){il(u,t,n)}break;case 18:hl!==null&&(Ll?(l=hl,D1(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,u.stateNode),re(l)):D1(hl,u.stateNode));break;case 4:a=hl,e=Ll,hl=u.stateNode.containerInfo,Ll=!0,Gt(l,t,u),hl=a,Ll=e;break;case 0:case 11:case 14:case 15:bl||It(2,u,t),bl||It(4,u,t),Gt(l,t,u);break;case 1:bl||(zt(u,t),a=u.stateNode,typeof a.componentWillUnmount=="function"&&H2(u,t,a)),Gt(l,t,u);break;case 21:Gt(l,t,u);break;case 22:bl=(a=bl)||u.memoizedState!==null,Gt(l,t,u),bl=a;break;default:Gt(l,t,u)}}function X2(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{re(l)}catch(u){il(t,t.return,u)}}function C4(l){switch(l.tag){case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new j2),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new j2),t;default:throw Error(m(435,l.tag))}}function of(l,t){var u=C4(l);t.forEach(function(a){var e=Q4.bind(null,l,a);u.has(a)||(u.add(a),a.then(e,e))})}function lt(l,t){var u=t.deletions;if(u!==null)for(var a=0;a<u.length;a++){var e=u[a],n=l,c=t,f=c;l:for(;f!==null;){switch(f.tag){case 27:if(fu(f.type)){hl=f.stateNode,Ll=!1;break l}break;case 5:hl=f.stateNode,Ll=!1;break l;case 3:case 4:hl=f.stateNode.containerInfo,Ll=!0;break l}f=f.return}if(hl===null)throw Error(m(160));G2(n,c,e),hl=null,Ll=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)Z2(t,l),t=t.sibling}var gt=null;function Z2(l,t){var u=l.alternate,a=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:lt(t,l),tt(l),a&4&&(It(3,l,l.return),Fa(3,l),It(5,l,l.return));break;case 1:lt(t,l),tt(l),a&512&&(bl||u===null||zt(u,u.return)),a&64&&Bt&&(l=l.updateQueue,l!==null&&(a=l.callbacks,a!==null&&(u=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=u===null?a:u.concat(a))));break;case 26:var e=gt;if(lt(t,l),tt(l),a&512&&(bl||u===null||zt(u,u.return)),a&4){var n=u!==null?u.memoizedState:null;if(a=l.memoizedState,u===null)if(a===null)if(l.stateNode===null){l:{a=l.type,u=l.memoizedProps,e=e.ownerDocument||e;t:switch(a){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Aa]||n[jl]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(a),e.head.insertBefore(n,e.querySelector("head > title"))),Cl(n,a,u),n[jl]=l,Ol(n),a=n;break l;case"link":var c=x1("link","href",e).get(a+(u.href||""));if(c){for(var f=0;f<c.length;f++)if(n=c[f],n.getAttribute("href")===(u.href==null||u.href===""?null:u.href)&&n.getAttribute("rel")===(u.rel==null?null:u.rel)&&n.getAttribute("title")===(u.title==null?null:u.title)&&n.getAttribute("crossorigin")===(u.crossOrigin==null?null:u.crossOrigin)){c.splice(f,1);break t}}n=e.createElement(a),Cl(n,a,u),e.head.appendChild(n);break;case"meta":if(c=x1("meta","content",e).get(a+(u.content||""))){for(f=0;f<c.length;f++)if(n=c[f],n.getAttribute("content")===(u.content==null?null:""+u.content)&&n.getAttribute("name")===(u.name==null?null:u.name)&&n.getAttribute("property")===(u.property==null?null:u.property)&&n.getAttribute("http-equiv")===(u.httpEquiv==null?null:u.httpEquiv)&&n.getAttribute("charset")===(u.charSet==null?null:u.charSet)){c.splice(f,1);break t}}n=e.createElement(a),Cl(n,a,u),e.head.appendChild(n);break;default:throw Error(m(468,a))}n[jl]=l,Ol(n),a=n}l.stateNode=a}else j1(e,l.type,l.stateNode);else l.stateNode=q1(e,a,l.memoizedProps);else n!==a?(n===null?u.stateNode!==null&&(u=u.stateNode,u.parentNode.removeChild(u)):n.count--,a===null?j1(e,l.type,l.stateNode):q1(e,a,l.memoizedProps)):a===null&&l.stateNode!==null&&cf(l,l.memoizedProps,u.memoizedProps)}break;case 27:lt(t,l),tt(l),a&512&&(bl||u===null||zt(u,u.return)),u!==null&&a&4&&cf(l,l.memoizedProps,u.memoizedProps);break;case 5:if(lt(t,l),tt(l),a&512&&(bl||u===null||zt(u,u.return)),l.flags&32){e=l.stateNode;try{Zu(e,"")}catch(r){il(l,l.return,r)}}a&4&&l.stateNode!=null&&(e=l.memoizedProps,cf(l,e,u!==null?u.memoizedProps:e)),a&1024&&(df=!0);break;case 6:if(lt(t,l),tt(l),a&4){if(l.stateNode===null)throw Error(m(162));a=l.memoizedProps,u=l.stateNode;try{u.nodeValue=a}catch(r){il(l,l.return,r)}}break;case 3:if(_n=null,e=gt,gt=An(t.containerInfo),lt(t,l),gt=e,tt(l),a&4&&u!==null&&u.memoizedState.isDehydrated)try{re(t.containerInfo)}catch(r){il(l,l.return,r)}df&&(df=!1,Q2(l));break;case 4:a=gt,gt=An(l.stateNode.containerInfo),lt(t,l),tt(l),gt=a;break;case 12:lt(t,l),tt(l);break;case 13:lt(t,l),tt(l),l.child.flags&8192&&l.memoizedState!==null!=(u!==null&&u.memoizedState!==null)&&(gf=Et()),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,of(l,a)));break;case 22:e=l.memoizedState!==null;var i=u!==null&&u.memoizedState!==null,h=Bt,g=bl;if(Bt=h||e,bl=g||i,lt(t,l),bl=g,Bt=h,tt(l),a&8192)l:for(t=l.stateNode,t._visibility=e?t._visibility&-2:t._visibility|1,e&&(u===null||i||Bt||bl||pu(l)),u=null,t=l;;){if(t.tag===5||t.tag===26){if(u===null){i=u=t;try{if(n=i.stateNode,e)c=n.style,typeof c.setProperty=="function"?c.setProperty("display","none","important"):c.display="none";else{f=i.stateNode;var E=i.memoizedProps.style,y=E!=null&&E.hasOwnProperty("display")?E.display:null;f.style.display=y==null||typeof y=="boolean"?"":(""+y).trim()}}catch(r){il(i,i.return,r)}}}else if(t.tag===6){if(u===null){i=t;try{i.stateNode.nodeValue=e?"":i.memoizedProps}catch(r){il(i,i.return,r)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;u===t&&(u=null),t=t.return}u===t&&(u=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=l.updateQueue,a!==null&&(u=a.retryQueue,u!==null&&(a.retryQueue=null,of(l,u))));break;case 19:lt(t,l),tt(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,of(l,a)));break;case 30:break;case 21:break;default:lt(t,l),tt(l)}}function tt(l){var t=l.flags;if(t&2){try{for(var u,a=l.return;a!==null;){if(q2(a)){u=a;break}a=a.return}if(u==null)throw Error(m(160));switch(u.tag){case 27:var e=u.stateNode,n=ff(l);sn(l,n,e);break;case 5:var c=u.stateNode;u.flags&32&&(Zu(c,""),u.flags&=-33);var f=ff(l);sn(l,f,c);break;case 3:case 4:var i=u.stateNode.containerInfo,h=ff(l);sf(l,h,i);break;default:throw Error(m(161))}}catch(g){il(l,l.return,g)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function Q2(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;Q2(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function lu(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)Y2(l,t.alternate,t),t=t.sibling}function pu(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:It(4,t,t.return),pu(t);break;case 1:zt(t,t.return);var u=t.stateNode;typeof u.componentWillUnmount=="function"&&H2(t,t.return,u),pu(t);break;case 27:fe(t.stateNode);case 26:case 5:zt(t,t.return),pu(t);break;case 22:t.memoizedState===null&&pu(t);break;case 30:pu(t);break;default:pu(t)}l=l.sibling}}function tu(l,t,u){for(u=u&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,e=l,n=t,c=n.flags;switch(n.tag){case 0:case 11:case 15:tu(e,n,u),Fa(4,n);break;case 1:if(tu(e,n,u),a=n,e=a.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(h){il(a,a.return,h)}if(a=n,e=a.updateQueue,e!==null){var f=a.stateNode;try{var i=e.shared.hiddenCallbacks;if(i!==null)for(e.shared.hiddenCallbacks=null,e=0;e<i.length;e++)g0(i[e],f)}catch(h){il(a,a.return,h)}}u&&c&64&&N2(n),Pa(n,n.return);break;case 27:x2(n);case 26:case 5:tu(e,n,u),u&&a===null&&c&4&&C2(n),Pa(n,n.return);break;case 12:tu(e,n,u);break;case 13:tu(e,n,u),u&&c&4&&X2(e,n);break;case 22:n.memoizedState===null&&tu(e,n,u),Pa(n,n.return);break;case 30:break;default:tu(e,n,u)}t=t.sibling}}function vf(l,t){var u=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==u&&(l!=null&&l.refCount++,u!=null&&Ya(u))}function hf(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ya(l))}function _t(l,t,u,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)V2(l,t,u,a),t=t.sibling}function V2(l,t,u,a){var e=t.flags;switch(t.tag){case 0:case 11:case 15:_t(l,t,u,a),e&2048&&Fa(9,t);break;case 1:_t(l,t,u,a);break;case 3:_t(l,t,u,a),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ya(l)));break;case 12:if(e&2048){_t(l,t,u,a),l=t.stateNode;try{var n=t.memoizedProps,c=n.id,f=n.onPostCommit;typeof f=="function"&&f(c,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(i){il(t,t.return,i)}}else _t(l,t,u,a);break;case 13:_t(l,t,u,a);break;case 23:break;case 22:n=t.stateNode,c=t.alternate,t.memoizedState!==null?n._visibility&2?_t(l,t,u,a):Ia(l,t):n._visibility&2?_t(l,t,u,a):(n._visibility|=2,ca(l,t,u,a,(t.subtreeFlags&10256)!==0)),e&2048&&vf(c,t);break;case 24:_t(l,t,u,a),e&2048&&hf(t.alternate,t);break;default:_t(l,t,u,a)}}function ca(l,t,u,a,e){for(e=e&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var n=l,c=t,f=u,i=a,h=c.flags;switch(c.tag){case 0:case 11:case 15:ca(n,c,f,i,e),Fa(8,c);break;case 23:break;case 22:var g=c.stateNode;c.memoizedState!==null?g._visibility&2?ca(n,c,f,i,e):Ia(n,c):(g._visibility|=2,ca(n,c,f,i,e)),e&&h&2048&&vf(c.alternate,c);break;case 24:ca(n,c,f,i,e),e&&h&2048&&hf(c.alternate,c);break;default:ca(n,c,f,i,e)}t=t.sibling}}function Ia(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var u=l,a=t,e=a.flags;switch(a.tag){case 22:Ia(u,a),e&2048&&vf(a.alternate,a);break;case 24:Ia(u,a),e&2048&&hf(a.alternate,a);break;default:Ia(u,a)}t=t.sibling}}var le=8192;function fa(l){if(l.subtreeFlags&le)for(l=l.child;l!==null;)L2(l),l=l.sibling}function L2(l){switch(l.tag){case 26:fa(l),l.flags&le&&l.memoizedState!==null&&Sd(gt,l.memoizedState,l.memoizedProps);break;case 5:fa(l);break;case 3:case 4:var t=gt;gt=An(l.stateNode.containerInfo),fa(l),gt=t;break;case 22:l.memoizedState===null&&(t=l.alternate,t!==null&&t.memoizedState!==null?(t=le,le=16777216,fa(l),le=t):fa(l));break;default:fa(l)}}function K2(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function te(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Dl=a,w2(a,l)}K2(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)J2(l),l=l.sibling}function J2(l){switch(l.tag){case 0:case 11:case 15:te(l),l.flags&2048&&It(9,l,l.return);break;case 3:te(l);break;case 12:te(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,dn(l)):te(l);break;default:te(l)}}function dn(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Dl=a,w2(a,l)}K2(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:It(8,t,t.return),dn(t);break;case 22:u=t.stateNode,u._visibility&2&&(u._visibility&=-3,dn(t));break;default:dn(t)}l=l.sibling}}function w2(l,t){for(;Dl!==null;){var u=Dl;switch(u.tag){case 0:case 11:case 15:It(8,u,t);break;case 23:case 22:if(u.memoizedState!==null&&u.memoizedState.cachePool!==null){var a=u.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:Ya(u.memoizedState.cache)}if(a=u.child,a!==null)a.return=u,Dl=a;else l:for(u=l;Dl!==null;){a=Dl;var e=a.sibling,n=a.return;if(B2(a),a===u){Dl=null;break l}if(e!==null){e.return=n,Dl=e;break l}Dl=n}}}var q4={getCacheForType:function(l){var t=Yl(Al),u=t.data.get(l);return u===void 0&&(u=l(),t.data.set(l,u)),u}},x4=typeof WeakMap=="function"?WeakMap:Map,ul=0,sl=null,L=null,W=0,al=0,ut=null,uu=!1,ia=!1,yf=!1,Xt=0,gl=0,au=0,Nu=0,rf=0,vt=0,sa=0,ue=null,Kl=null,mf=!1,gf=0,on=1/0,vn=null,eu=null,Hl=0,nu=null,da=null,oa=0,Sf=0,bf=null,W2=null,ae=0,Ef=null;function at(){if((ul&2)!==0&&W!==0)return W&-W;if(S.T!==null){var l=Pu;return l!==0?l:Df()}return di()}function $2(){vt===0&&(vt=(W&536870912)===0||ll?ci():536870912);var l=ot.current;return l!==null&&(l.flags|=32),vt}function et(l,t,u){(l===sl&&(al===2||al===9)||l.cancelPendingCommit!==null)&&(va(l,0),cu(l,W,vt,!1)),Ta(l,u),((ul&2)===0||l!==sl)&&(l===sl&&((ul&2)===0&&(Nu|=u),gl===4&&cu(l,W,vt,!1)),Ot(l))}function k2(l,t,u){if((ul&6)!==0)throw Error(m(327));var a=!u&&(t&124)===0&&(t&l.expiredLanes)===0||Ea(l,t),e=a?B4(l,t):zf(l,t,!0),n=a;do{if(e===0){ia&&!a&&cu(l,t,0,!1);break}else{if(u=l.current.alternate,n&&!j4(u)){e=zf(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var c=0;else c=l.pendingLanes&-536870913,c=c!==0?c:c&536870912?536870912:0;if(c!==0){t=c;l:{var f=l;e=ue;var i=f.current.memoizedState.isDehydrated;if(i&&(va(f,c).flags|=256),c=zf(f,c,!1),c!==2){if(yf&&!i){f.errorRecoveryDisabledLanes|=n,Nu|=n,e=4;break l}n=Kl,Kl=e,n!==null&&(Kl===null?Kl=n:Kl.push.apply(Kl,n))}e=c}if(n=!1,e!==2)continue}}if(e===1){va(l,0),cu(l,t,0,!0);break}l:{switch(a=l,n=e,n){case 0:case 1:throw Error(m(345));case 4:if((t&4194048)!==t)break;case 6:cu(a,t,vt,!uu);break l;case 2:Kl=null;break;case 3:case 5:break;default:throw Error(m(329))}if((t&62914560)===t&&(e=gf+300-Et(),10<e)){if(cu(a,t,vt,!uu),Ae(a,0,!0)!==0)break l;a.timeoutHandle=O1(F2.bind(null,a,u,Kl,vn,mf,t,vt,Nu,sa,uu,n,2,-0,0),e);break l}F2(a,u,Kl,vn,mf,t,vt,Nu,sa,uu,n,0,-0,0)}}break}while(!0);Ot(l)}function F2(l,t,u,a,e,n,c,f,i,h,g,E,y,r){if(l.timeoutHandle=-1,E=t.subtreeFlags,(E&8192||(E&16785408)===16785408)&&(de={stylesheets:null,count:0,unsuspend:gd},L2(t),E=bd(),E!==null)){l.cancelPendingCommit=E(e1.bind(null,l,t,n,u,a,e,c,f,i,g,1,y,r)),cu(l,n,c,!h);return}e1(l,t,n,u,a,e,c,f,i)}function j4(l){for(var t=l;;){var u=t.tag;if((u===0||u===11||u===15)&&t.flags&16384&&(u=t.updateQueue,u!==null&&(u=u.stores,u!==null)))for(var a=0;a<u.length;a++){var e=u[a],n=e.getSnapshot;e=e.value;try{if(!Pl(n(),e))return!1}catch{return!1}}if(u=t.child,t.subtreeFlags&16384&&u!==null)u.return=t,t=u;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function cu(l,t,u,a){t&=~rf,t&=~Nu,l.suspendedLanes|=t,l.pingedLanes&=~t,a&&(l.warmLanes|=t),a=l.expirationTimes;for(var e=t;0<e;){var n=31-Fl(e),c=1<<n;a[n]=-1,e&=~c}u!==0&&ii(l,u,t)}function hn(){return(ul&6)===0?(ee(0),!1):!0}function Tf(){if(L!==null){if(al===0)var l=L.return;else l=L,Ht=Ou=null,Yc(l),ea=null,Wa=0,l=L;for(;l!==null;)p2(l.alternate,l),l=l.return;L=null}}function va(l,t){var u=l.timeoutHandle;u!==-1&&(l.timeoutHandle=-1,ld(u)),u=l.cancelPendingCommit,u!==null&&(l.cancelPendingCommit=null,u()),Tf(),sl=l,L=u=Rt(l.current,null),W=t,al=0,ut=null,uu=!1,ia=Ea(l,t),yf=!1,sa=vt=rf=Nu=au=gl=0,Kl=ue=null,mf=!1,(t&8)!==0&&(t|=t&32);var a=l.entangledLanes;if(a!==0)for(l=l.entanglements,a&=t;0<a;){var e=31-Fl(a),n=1<<e;t|=l[e],a&=~n}return Xt=t,qe(),u}function P2(l,t){Q=null,S.H=Ie,t===Ga||t===Ve?(t=r0(),al=3):t===v0?(t=r0(),al=4):al=t===m2?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,ut=t,L===null&&(gl=1,en(l,ft(t,l.current)))}function I2(){var l=S.H;return S.H=Ie,l===null?Ie:l}function l1(){var l=S.A;return S.A=q4,l}function Af(){gl=4,uu||(W&4194048)!==W&&ot.current!==null||(ia=!0),(au&134217727)===0&&(Nu&134217727)===0||sl===null||cu(sl,W,vt,!1)}function zf(l,t,u){var a=ul;ul|=2;var e=I2(),n=l1();(sl!==l||W!==t)&&(vn=null,va(l,t)),t=!1;var c=gl;l:do try{if(al!==0&&L!==null){var f=L,i=ut;switch(al){case 8:Tf(),c=6;break l;case 3:case 2:case 9:case 6:ot.current===null&&(t=!0);var h=al;if(al=0,ut=null,ha(l,f,i,h),u&&ia){c=0;break l}break;default:h=al,al=0,ut=null,ha(l,f,i,h)}}Y4(),c=gl;break}catch(g){P2(l,g)}while(!0);return t&&l.shellSuspendCounter++,Ht=Ou=null,ul=a,S.H=e,S.A=n,L===null&&(sl=null,W=0,qe()),c}function Y4(){for(;L!==null;)t1(L)}function B4(l,t){var u=ul;ul|=2;var a=I2(),e=l1();sl!==l||W!==t?(vn=null,on=Et()+500,va(l,t)):ia=Ea(l,t);l:do try{if(al!==0&&L!==null){t=L;var n=ut;t:switch(al){case 1:al=0,ut=null,ha(l,t,n,1);break;case 2:case 9:if(h0(n)){al=0,ut=null,u1(t);break}t=function(){al!==2&&al!==9||sl!==l||(al=7),Ot(l)},n.then(t,t);break l;case 3:al=7;break l;case 4:al=5;break l;case 7:h0(n)?(al=0,ut=null,u1(t)):(al=0,ut=null,ha(l,t,n,7));break;case 5:var c=null;switch(L.tag){case 26:c=L.memoizedState;case 5:case 27:var f=L;if(!c||Y1(c)){al=0,ut=null;var i=f.sibling;if(i!==null)L=i;else{var h=f.return;h!==null?(L=h,yn(h)):L=null}break t}}al=0,ut=null,ha(l,t,n,5);break;case 6:al=0,ut=null,ha(l,t,n,6);break;case 8:Tf(),gl=6;break l;default:throw Error(m(462))}}G4();break}catch(g){P2(l,g)}while(!0);return Ht=Ou=null,S.H=a,S.A=e,ul=u,L!==null?0:(sl=null,W=0,qe(),gl)}function G4(){for(;L!==null&&!fs();)t1(L)}function t1(l){var t=U2(l.alternate,l,Xt);l.memoizedProps=l.pendingProps,t===null?yn(l):L=t}function u1(l){var t=l,u=t.alternate;switch(t.tag){case 15:case 0:t=A2(u,t,t.pendingProps,t.type,void 0,W);break;case 11:t=A2(u,t,t.pendingProps,t.type.render,t.ref,W);break;case 5:Yc(t);default:p2(u,t),t=L=a0(t,Xt),t=U2(u,t,Xt)}l.memoizedProps=l.pendingProps,t===null?yn(l):L=t}function ha(l,t,u,a){Ht=Ou=null,Yc(t),ea=null,Wa=0;var e=t.return;try{if(U4(l,e,t,u,W)){gl=1,en(l,ft(u,l.current)),L=null;return}}catch(n){if(e!==null)throw L=e,n;gl=1,en(l,ft(u,l.current)),L=null;return}t.flags&32768?(ll||a===1?l=!0:ia||(W&536870912)!==0?l=!1:(uu=l=!0,(a===2||a===9||a===3||a===6)&&(a=ot.current,a!==null&&a.tag===13&&(a.flags|=16384))),a1(t,l)):yn(t)}function yn(l){var t=l;do{if((t.flags&32768)!==0){a1(t,uu);return}l=t.return;var u=p4(t.alternate,t,Xt);if(u!==null){L=u;return}if(t=t.sibling,t!==null){L=t;return}L=t=l}while(t!==null);gl===0&&(gl=5)}function a1(l,t){do{var u=N4(l.alternate,l);if(u!==null){u.flags&=32767,L=u;return}if(u=l.return,u!==null&&(u.flags|=32768,u.subtreeFlags=0,u.deletions=null),!t&&(l=l.sibling,l!==null)){L=l;return}L=l=u}while(l!==null);gl=6,L=null}function e1(l,t,u,a,e,n,c,f,i){l.cancelPendingCommit=null;do rn();while(Hl!==0);if((ul&6)!==0)throw Error(m(327));if(t!==null){if(t===l.current)throw Error(m(177));if(n=t.lanes|t.childLanes,n|=vc,gs(l,u,n,c,f,i),l===sl&&(L=sl=null,W=0),da=t,nu=l,oa=u,Sf=n,bf=e,W2=a,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,V4(be,function(){return s1(),null})):(l.callbackNode=null,l.callbackPriority=0),a=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||a){a=S.T,S.T=null,e=O.p,O.p=2,c=ul,ul|=4;try{H4(l,t,u)}finally{ul=c,O.p=e,S.T=a}}Hl=1,n1(),c1(),f1()}}function n1(){if(Hl===1){Hl=0;var l=nu,t=da,u=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||u){u=S.T,S.T=null;var a=O.p;O.p=2;var e=ul;ul|=4;try{Z2(t,l);var n=xf,c=wi(l.containerInfo),f=n.focusedElem,i=n.selectionRange;if(c!==f&&f&&f.ownerDocument&&Ji(f.ownerDocument.documentElement,f)){if(i!==null&&fc(f)){var h=i.start,g=i.end;if(g===void 0&&(g=h),"selectionStart"in f)f.selectionStart=h,f.selectionEnd=Math.min(g,f.value.length);else{var E=f.ownerDocument||document,y=E&&E.defaultView||window;if(y.getSelection){var r=y.getSelection(),Y=f.textContent.length,C=Math.min(i.start,Y),cl=i.end===void 0?C:Math.min(i.end,Y);!r.extend&&C>cl&&(c=cl,cl=C,C=c);var o=Ki(f,C),d=Ki(f,cl);if(o&&d&&(r.rangeCount!==1||r.anchorNode!==o.node||r.anchorOffset!==o.offset||r.focusNode!==d.node||r.focusOffset!==d.offset)){var v=E.createRange();v.setStart(o.node,o.offset),r.removeAllRanges(),C>cl?(r.addRange(v),r.extend(d.node,d.offset)):(v.setEnd(d.node,d.offset),r.addRange(v))}}}}for(E=[],r=f;r=r.parentNode;)r.nodeType===1&&E.push({element:r,left:r.scrollLeft,top:r.scrollTop});for(typeof f.focus=="function"&&f.focus(),f=0;f<E.length;f++){var b=E[f];b.element.scrollLeft=b.left,b.element.scrollTop=b.top}}Dn=!!qf,xf=qf=null}finally{ul=e,O.p=a,S.T=u}}l.current=t,Hl=2}}function c1(){if(Hl===2){Hl=0;var l=nu,t=da,u=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||u){u=S.T,S.T=null;var a=O.p;O.p=2;var e=ul;ul|=4;try{Y2(l,t.alternate,t)}finally{ul=e,O.p=a,S.T=u}}Hl=3}}function f1(){if(Hl===4||Hl===3){Hl=0,is();var l=nu,t=da,u=oa,a=W2;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Hl=5:(Hl=0,da=nu=null,i1(l,l.pendingLanes));var e=l.pendingLanes;if(e===0&&(eu=null),Xn(u),t=t.stateNode,kl&&typeof kl.onCommitFiberRoot=="function")try{kl.onCommitFiberRoot(ba,t,void 0,(t.current.flags&128)===128)}catch{}if(a!==null){t=S.T,e=O.p,O.p=2,S.T=null;try{for(var n=l.onRecoverableError,c=0;c<a.length;c++){var f=a[c];n(f.value,{componentStack:f.stack})}}finally{S.T=t,O.p=e}}(oa&3)!==0&&rn(),Ot(l),e=l.pendingLanes,(u&4194090)!==0&&(e&42)!==0?l===Ef?ae++:(ae=0,Ef=l):ae=0,ee(0)}}function i1(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,Ya(t)))}function rn(l){return n1(),c1(),f1(),s1()}function s1(){if(Hl!==5)return!1;var l=nu,t=Sf;Sf=0;var u=Xn(oa),a=S.T,e=O.p;try{O.p=32>u?32:u,S.T=null,u=bf,bf=null;var n=nu,c=oa;if(Hl=0,da=nu=null,oa=0,(ul&6)!==0)throw Error(m(331));var f=ul;if(ul|=4,J2(n.current),V2(n,n.current,c,u),ul=f,ee(0,!1),kl&&typeof kl.onPostCommitFiberRoot=="function")try{kl.onPostCommitFiberRoot(ba,n)}catch{}return!0}finally{O.p=e,S.T=a,i1(l,t)}}function d1(l,t,u){t=ft(u,t),t=Fc(l.stateNode,t,2),l=$t(l,t,2),l!==null&&(Ta(l,2),Ot(l))}function il(l,t,u){if(l.tag===3)d1(l,l,u);else for(;t!==null;){if(t.tag===3){d1(t,l,u);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(eu===null||!eu.has(a))){l=ft(u,l),u=y2(2),a=$t(t,u,2),a!==null&&(r2(u,a,t,l),Ta(a,2),Ot(a));break}}t=t.return}}function _f(l,t,u){var a=l.pingCache;if(a===null){a=l.pingCache=new x4;var e=new Set;a.set(t,e)}else e=a.get(t),e===void 0&&(e=new Set,a.set(t,e));e.has(u)||(yf=!0,e.add(u),l=X4.bind(null,l,t,u),t.then(l,l))}function X4(l,t,u){var a=l.pingCache;a!==null&&a.delete(t),l.pingedLanes|=l.suspendedLanes&u,l.warmLanes&=~u,sl===l&&(W&u)===u&&(gl===4||gl===3&&(W&62914560)===W&&300>Et()-gf?(ul&2)===0&&va(l,0):rf|=u,sa===W&&(sa=0)),Ot(l)}function o1(l,t){t===0&&(t=fi()),l=Wu(l,t),l!==null&&(Ta(l,t),Ot(l))}function Z4(l){var t=l.memoizedState,u=0;t!==null&&(u=t.retryLane),o1(l,u)}function Q4(l,t){var u=0;switch(l.tag){case 13:var a=l.stateNode,e=l.memoizedState;e!==null&&(u=e.retryLane);break;case 19:a=l.stateNode;break;case 22:a=l.stateNode._retryCache;break;default:throw Error(m(314))}a!==null&&a.delete(t),o1(l,u)}function V4(l,t){return jn(l,t)}var mn=null,ya=null,Of=!1,gn=!1,Mf=!1,Hu=0;function Ot(l){l!==ya&&l.next===null&&(ya===null?mn=ya=l:ya=ya.next=l),gn=!0,Of||(Of=!0,K4())}function ee(l,t){if(!Mf&&gn){Mf=!0;do for(var u=!1,a=mn;a!==null;){if(l!==0){var e=a.pendingLanes;if(e===0)var n=0;else{var c=a.suspendedLanes,f=a.pingedLanes;n=(1<<31-Fl(42|l)+1)-1,n&=e&~(c&~f),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(u=!0,r1(a,n))}else n=W,n=Ae(a,a===sl?n:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(n&3)===0||Ea(a,n)||(u=!0,r1(a,n));a=a.next}while(u);Mf=!1}}function L4(){v1()}function v1(){gn=Of=!1;var l=0;Hu!==0&&(I4()&&(l=Hu),Hu=0);for(var t=Et(),u=null,a=mn;a!==null;){var e=a.next,n=h1(a,t);n===0?(a.next=null,u===null?mn=e:u.next=e,e===null&&(ya=u)):(u=a,(l!==0||(n&3)!==0)&&(gn=!0)),a=e}ee(l)}function h1(l,t){for(var u=l.suspendedLanes,a=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var c=31-Fl(n),f=1<<c,i=e[c];i===-1?((f&u)===0||(f&a)!==0)&&(e[c]=ms(f,t)):i<=t&&(l.expiredLanes|=f),n&=~f}if(t=sl,u=W,u=Ae(l,l===t?u:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a=l.callbackNode,u===0||l===t&&(al===2||al===9)||l.cancelPendingCommit!==null)return a!==null&&a!==null&&Yn(a),l.callbackNode=null,l.callbackPriority=0;if((u&3)===0||Ea(l,u)){if(t=u&-u,t===l.callbackPriority)return t;switch(a!==null&&Yn(a),Xn(u)){case 2:case 8:u=ei;break;case 32:u=be;break;case 268435456:u=ni;break;default:u=be}return a=y1.bind(null,l),u=jn(u,a),l.callbackPriority=t,l.callbackNode=u,t}return a!==null&&a!==null&&Yn(a),l.callbackPriority=2,l.callbackNode=null,2}function y1(l,t){if(Hl!==0&&Hl!==5)return l.callbackNode=null,l.callbackPriority=0,null;var u=l.callbackNode;if(rn()&&l.callbackNode!==u)return null;var a=W;return a=Ae(l,l===sl?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a===0?null:(k2(l,a,t),h1(l,Et()),l.callbackNode!=null&&l.callbackNode===u?y1.bind(null,l):null)}function r1(l,t){if(rn())return null;k2(l,t,!0)}function K4(){td(function(){(ul&6)!==0?jn(ai,L4):v1()})}function Df(){return Hu===0&&(Hu=ci()),Hu}function m1(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:De(""+l)}function g1(l,t){var u=t.ownerDocument.createElement("input");return u.name=t.name,u.value=t.value,l.id&&u.setAttribute("form",l.id),t.parentNode.insertBefore(u,t),l=new FormData(l),u.parentNode.removeChild(u),l}function J4(l,t,u,a,e){if(t==="submit"&&u&&u.stateNode===e){var n=m1((e[Zl]||null).action),c=a.submitter;c&&(t=(t=c[Zl]||null)?m1(t.formAction):c.getAttribute("formAction"),t!==null&&(n=t,c=null));var f=new Ne("action","action",null,a,e);l.push({event:f,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(Hu!==0){var i=c?g1(e,c):new FormData(e);Jc(u,{pending:!0,data:i,method:e.method,action:n},null,i)}}else typeof n=="function"&&(f.preventDefault(),i=c?g1(e,c):new FormData(e),Jc(u,{pending:!0,data:i,method:e.method,action:n},n,i))},currentTarget:e}]})}}for(var Uf=0;Uf<oc.length;Uf++){var Rf=oc[Uf],w4=Rf.toLowerCase(),W4=Rf[0].toUpperCase()+Rf.slice(1);mt(w4,"on"+W4)}mt(ki,"onAnimationEnd"),mt(Fi,"onAnimationIteration"),mt(Pi,"onAnimationStart"),mt("dblclick","onDoubleClick"),mt("focusin","onFocus"),mt("focusout","onBlur"),mt(o4,"onTransitionRun"),mt(v4,"onTransitionStart"),mt(h4,"onTransitionCancel"),mt(Ii,"onTransitionEnd"),Bu("onMouseEnter",["mouseout","mouseover"]),Bu("onMouseLeave",["mouseout","mouseover"]),Bu("onPointerEnter",["pointerout","pointerover"]),Bu("onPointerLeave",["pointerout","pointerover"]),mu("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),mu("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),mu("onBeforeInput",["compositionend","keypress","textInput","paste"]),mu("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),mu("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),mu("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var ne="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),$4=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(ne));function S1(l,t){t=(t&4)!==0;for(var u=0;u<l.length;u++){var a=l[u],e=a.event;a=a.listeners;l:{var n=void 0;if(t)for(var c=a.length-1;0<=c;c--){var f=a[c],i=f.instance,h=f.currentTarget;if(f=f.listener,i!==n&&e.isPropagationStopped())break l;n=f,e.currentTarget=h;try{n(e)}catch(g){an(g)}e.currentTarget=null,n=i}else for(c=0;c<a.length;c++){if(f=a[c],i=f.instance,h=f.currentTarget,f=f.listener,i!==n&&e.isPropagationStopped())break l;n=f,e.currentTarget=h;try{n(e)}catch(g){an(g)}e.currentTarget=null,n=i}}}}function K(l,t){var u=t[Zn];u===void 0&&(u=t[Zn]=new Set);var a=l+"__bubble";u.has(a)||(b1(t,l,2,!1),u.add(a))}function pf(l,t,u){var a=0;t&&(a|=4),b1(u,l,a,t)}var Sn="_reactListening"+Math.random().toString(36).slice(2);function Nf(l){if(!l[Sn]){l[Sn]=!0,vi.forEach(function(u){u!=="selectionchange"&&($4.has(u)||pf(u,!1,l),pf(u,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[Sn]||(t[Sn]=!0,pf("selectionchange",!1,t))}}function b1(l,t,u,a){switch(V1(t)){case 2:var e=Ad;break;case 8:e=zd;break;default:e=Kf}u=e.bind(null,t,u,l),e=void 0,!Pn||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),a?e!==void 0?l.addEventListener(t,u,{capture:!0,passive:e}):l.addEventListener(t,u,!0):e!==void 0?l.addEventListener(t,u,{passive:e}):l.addEventListener(t,u,!1)}function Hf(l,t,u,a,e){var n=a;if((t&1)===0&&(t&2)===0&&a!==null)l:for(;;){if(a===null)return;var c=a.tag;if(c===3||c===4){var f=a.stateNode.containerInfo;if(f===e)break;if(c===4)for(c=a.return;c!==null;){var i=c.tag;if((i===3||i===4)&&c.stateNode.containerInfo===e)return;c=c.return}for(;f!==null;){if(c=xu(f),c===null)return;if(i=c.tag,i===5||i===6||i===26||i===27){a=n=c;continue l}f=f.parentNode}}a=a.return}Mi(function(){var h=n,g=kn(u),E=[];l:{var y=l0.get(l);if(y!==void 0){var r=Ne,Y=l;switch(l){case"keypress":if(Re(u)===0)break l;case"keydown":case"keyup":r=Vs;break;case"focusin":Y="focus",r=uc;break;case"focusout":Y="blur",r=uc;break;case"beforeblur":case"afterblur":r=uc;break;case"click":if(u.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":r=Ri;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":r=Ns;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":r=Js;break;case ki:case Fi:case Pi:r=qs;break;case Ii:r=Ws;break;case"scroll":case"scrollend":r=Rs;break;case"wheel":r=ks;break;case"copy":case"cut":case"paste":r=js;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":r=Ni;break;case"toggle":case"beforetoggle":r=Ps}var C=(t&4)!==0,cl=!C&&(l==="scroll"||l==="scrollend"),o=C?y!==null?y+"Capture":null:y;C=[];for(var d=h,v;d!==null;){var b=d;if(v=b.stateNode,b=b.tag,b!==5&&b!==26&&b!==27||v===null||o===null||(b=_a(d,o),b!=null&&C.push(ce(d,b,v))),cl)break;d=d.return}0<C.length&&(y=new r(y,Y,null,u,g),E.push({event:y,listeners:C}))}}if((t&7)===0){l:{if(y=l==="mouseover"||l==="pointerover",r=l==="mouseout"||l==="pointerout",y&&u!==$n&&(Y=u.relatedTarget||u.fromElement)&&(xu(Y)||Y[qu]))break l;if((r||y)&&(y=g.window===g?g:(y=g.ownerDocument)?y.defaultView||y.parentWindow:window,r?(Y=u.relatedTarget||u.toElement,r=h,Y=Y?xu(Y):null,Y!==null&&(cl=B(Y),C=Y.tag,Y!==cl||C!==5&&C!==27&&C!==6)&&(Y=null)):(r=null,Y=h),r!==Y)){if(C=Ri,b="onMouseLeave",o="onMouseEnter",d="mouse",(l==="pointerout"||l==="pointerover")&&(C=Ni,b="onPointerLeave",o="onPointerEnter",d="pointer"),cl=r==null?y:za(r),v=Y==null?y:za(Y),y=new C(b,d+"leave",r,u,g),y.target=cl,y.relatedTarget=v,b=null,xu(g)===h&&(C=new C(o,d+"enter",Y,u,g),C.target=v,C.relatedTarget=cl,b=C),cl=b,r&&Y)t:{for(C=r,o=Y,d=0,v=C;v;v=ra(v))d++;for(v=0,b=o;b;b=ra(b))v++;for(;0<d-v;)C=ra(C),d--;for(;0<v-d;)o=ra(o),v--;for(;d--;){if(C===o||o!==null&&C===o.alternate)break t;C=ra(C),o=ra(o)}C=null}else C=null;r!==null&&E1(E,y,r,C,!1),Y!==null&&cl!==null&&E1(E,cl,Y,C,!0)}}l:{if(y=h?za(h):window,r=y.nodeName&&y.nodeName.toLowerCase(),r==="select"||r==="input"&&y.type==="file")var D=Gi;else if(Yi(y))if(Xi)D=i4;else{D=c4;var V=n4}else r=y.nodeName,!r||r.toLowerCase()!=="input"||y.type!=="checkbox"&&y.type!=="radio"?h&&Wn(h.elementType)&&(D=Gi):D=f4;if(D&&(D=D(l,h))){Bi(E,D,u,g);break l}V&&V(l,y,h),l==="focusout"&&h&&y.type==="number"&&h.memoizedProps.value!=null&&wn(y,"number",y.value)}switch(V=h?za(h):window,l){case"focusin":(Yi(V)||V.contentEditable==="true")&&(Ku=V,ic=h,Ha=null);break;case"focusout":Ha=ic=Ku=null;break;case"mousedown":sc=!0;break;case"contextmenu":case"mouseup":case"dragend":sc=!1,Wi(E,u,g);break;case"selectionchange":if(d4)break;case"keydown":case"keyup":Wi(E,u,g)}var p;if(ec)l:{switch(l){case"compositionstart":var x="onCompositionStart";break l;case"compositionend":x="onCompositionEnd";break l;case"compositionupdate":x="onCompositionUpdate";break l}x=void 0}else Lu?xi(l,u)&&(x="onCompositionEnd"):l==="keydown"&&u.keyCode===229&&(x="onCompositionStart");x&&(Hi&&u.locale!=="ko"&&(Lu||x!=="onCompositionStart"?x==="onCompositionEnd"&&Lu&&(p=Di()):(Kt=g,In="value"in Kt?Kt.value:Kt.textContent,Lu=!0)),V=bn(h,x),0<V.length&&(x=new pi(x,l,null,u,g),E.push({event:x,listeners:V}),p?x.data=p:(p=ji(u),p!==null&&(x.data=p)))),(p=l4?t4(l,u):u4(l,u))&&(x=bn(h,"onBeforeInput"),0<x.length&&(V=new pi("onBeforeInput","beforeinput",null,u,g),E.push({event:V,listeners:x}),V.data=p)),J4(E,l,h,u,g)}S1(E,t)})}function ce(l,t,u){return{instance:l,listener:t,currentTarget:u}}function bn(l,t){for(var u=t+"Capture",a=[];l!==null;){var e=l,n=e.stateNode;if(e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=_a(l,u),e!=null&&a.unshift(ce(l,e,n)),e=_a(l,t),e!=null&&a.push(ce(l,e,n))),l.tag===3)return a;l=l.return}return[]}function ra(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function E1(l,t,u,a,e){for(var n=t._reactName,c=[];u!==null&&u!==a;){var f=u,i=f.alternate,h=f.stateNode;if(f=f.tag,i!==null&&i===a)break;f!==5&&f!==26&&f!==27||h===null||(i=h,e?(h=_a(u,n),h!=null&&c.unshift(ce(u,h,i))):e||(h=_a(u,n),h!=null&&c.push(ce(u,h,i)))),u=u.return}c.length!==0&&l.push({event:t,listeners:c})}var k4=/\r\n?/g,F4=/\u0000|\uFFFD/g;function T1(l){return(typeof l=="string"?l:""+l).replace(k4,`
`).replace(F4,"")}function A1(l,t){return t=T1(t),T1(l)===t}function En(){}function nl(l,t,u,a,e,n){switch(u){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||Zu(l,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&Zu(l,""+a);break;case"className":_e(l,"class",a);break;case"tabIndex":_e(l,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":_e(l,u,a);break;case"style":_i(l,a,n);break;case"data":if(t!=="object"){_e(l,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||u!=="href")){l.removeAttribute(u);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=De(""+a),l.setAttribute(u,a);break;case"action":case"formAction":if(typeof a=="function"){l.setAttribute(u,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(u==="formAction"?(t!=="input"&&nl(l,t,"name",e.name,e,null),nl(l,t,"formEncType",e.formEncType,e,null),nl(l,t,"formMethod",e.formMethod,e,null),nl(l,t,"formTarget",e.formTarget,e,null)):(nl(l,t,"encType",e.encType,e,null),nl(l,t,"method",e.method,e,null),nl(l,t,"target",e.target,e,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=De(""+a),l.setAttribute(u,a);break;case"onClick":a!=null&&(l.onclick=En);break;case"onScroll":a!=null&&K("scroll",l);break;case"onScrollEnd":a!=null&&K("scrollend",l);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(m(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(m(60));l.innerHTML=u}}break;case"multiple":l.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":l.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){l.removeAttribute("xlink:href");break}u=De(""+a),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",u);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""+a):l.removeAttribute(u);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""):l.removeAttribute(u);break;case"capture":case"download":a===!0?l.setAttribute(u,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,a):l.removeAttribute(u);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?l.setAttribute(u,a):l.removeAttribute(u);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?l.removeAttribute(u):l.setAttribute(u,a);break;case"popover":K("beforetoggle",l),K("toggle",l),ze(l,"popover",a);break;case"xlinkActuate":Dt(l,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Dt(l,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Dt(l,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Dt(l,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Dt(l,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Dt(l,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Dt(l,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Dt(l,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Dt(l,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":ze(l,"is",a);break;case"innerText":case"textContent":break;default:(!(2<u.length)||u[0]!=="o"&&u[0]!=="O"||u[1]!=="n"&&u[1]!=="N")&&(u=Ds.get(u)||u,ze(l,u,a))}}function Cf(l,t,u,a,e,n){switch(u){case"style":_i(l,a,n);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(m(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(m(60));l.innerHTML=u}}break;case"children":typeof a=="string"?Zu(l,a):(typeof a=="number"||typeof a=="bigint")&&Zu(l,""+a);break;case"onScroll":a!=null&&K("scroll",l);break;case"onScrollEnd":a!=null&&K("scrollend",l);break;case"onClick":a!=null&&(l.onclick=En);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!hi.hasOwnProperty(u))l:{if(u[0]==="o"&&u[1]==="n"&&(e=u.endsWith("Capture"),t=u.slice(2,e?u.length-7:void 0),n=l[Zl]||null,n=n!=null?n[u]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof a=="function")){typeof n!="function"&&n!==null&&(u in l?l[u]=null:l.hasAttribute(u)&&l.removeAttribute(u)),l.addEventListener(t,a,e);break l}u in l?l[u]=a:a===!0?l.setAttribute(u,""):ze(l,u,a)}}}function Cl(l,t,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":K("error",l),K("load",l);var a=!1,e=!1,n;for(n in u)if(u.hasOwnProperty(n)){var c=u[n];if(c!=null)switch(n){case"src":a=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(m(137,t));default:nl(l,t,n,c,u,null)}}e&&nl(l,t,"srcSet",u.srcSet,u,null),a&&nl(l,t,"src",u.src,u,null);return;case"input":K("invalid",l);var f=n=c=e=null,i=null,h=null;for(a in u)if(u.hasOwnProperty(a)){var g=u[a];if(g!=null)switch(a){case"name":e=g;break;case"type":c=g;break;case"checked":i=g;break;case"defaultChecked":h=g;break;case"value":n=g;break;case"defaultValue":f=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(m(137,t));break;default:nl(l,t,a,g,u,null)}}Ei(l,n,f,i,h,c,e,!1),Oe(l);return;case"select":K("invalid",l),a=c=n=null;for(e in u)if(u.hasOwnProperty(e)&&(f=u[e],f!=null))switch(e){case"value":n=f;break;case"defaultValue":c=f;break;case"multiple":a=f;default:nl(l,t,e,f,u,null)}t=n,u=c,l.multiple=!!a,t!=null?Xu(l,!!a,t,!1):u!=null&&Xu(l,!!a,u,!0);return;case"textarea":K("invalid",l),n=e=a=null;for(c in u)if(u.hasOwnProperty(c)&&(f=u[c],f!=null))switch(c){case"value":a=f;break;case"defaultValue":e=f;break;case"children":n=f;break;case"dangerouslySetInnerHTML":if(f!=null)throw Error(m(91));break;default:nl(l,t,c,f,u,null)}Ai(l,a,e,n),Oe(l);return;case"option":for(i in u)if(u.hasOwnProperty(i)&&(a=u[i],a!=null))switch(i){case"selected":l.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:nl(l,t,i,a,u,null)}return;case"dialog":K("beforetoggle",l),K("toggle",l),K("cancel",l),K("close",l);break;case"iframe":case"object":K("load",l);break;case"video":case"audio":for(a=0;a<ne.length;a++)K(ne[a],l);break;case"image":K("error",l),K("load",l);break;case"details":K("toggle",l);break;case"embed":case"source":case"link":K("error",l),K("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(h in u)if(u.hasOwnProperty(h)&&(a=u[h],a!=null))switch(h){case"children":case"dangerouslySetInnerHTML":throw Error(m(137,t));default:nl(l,t,h,a,u,null)}return;default:if(Wn(t)){for(g in u)u.hasOwnProperty(g)&&(a=u[g],a!==void 0&&Cf(l,t,g,a,u,void 0));return}}for(f in u)u.hasOwnProperty(f)&&(a=u[f],a!=null&&nl(l,t,f,a,u,null))}function P4(l,t,u,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,c=null,f=null,i=null,h=null,g=null;for(r in u){var E=u[r];if(u.hasOwnProperty(r)&&E!=null)switch(r){case"checked":break;case"value":break;case"defaultValue":i=E;default:a.hasOwnProperty(r)||nl(l,t,r,null,a,E)}}for(var y in a){var r=a[y];if(E=u[y],a.hasOwnProperty(y)&&(r!=null||E!=null))switch(y){case"type":n=r;break;case"name":e=r;break;case"checked":h=r;break;case"defaultChecked":g=r;break;case"value":c=r;break;case"defaultValue":f=r;break;case"children":case"dangerouslySetInnerHTML":if(r!=null)throw Error(m(137,t));break;default:r!==E&&nl(l,t,y,r,a,E)}}Jn(l,c,f,i,h,g,n,e);return;case"select":r=c=f=y=null;for(n in u)if(i=u[n],u.hasOwnProperty(n)&&i!=null)switch(n){case"value":break;case"multiple":r=i;default:a.hasOwnProperty(n)||nl(l,t,n,null,a,i)}for(e in a)if(n=a[e],i=u[e],a.hasOwnProperty(e)&&(n!=null||i!=null))switch(e){case"value":y=n;break;case"defaultValue":f=n;break;case"multiple":c=n;default:n!==i&&nl(l,t,e,n,a,i)}t=f,u=c,a=r,y!=null?Xu(l,!!u,y,!1):!!a!=!!u&&(t!=null?Xu(l,!!u,t,!0):Xu(l,!!u,u?[]:"",!1));return;case"textarea":r=y=null;for(f in u)if(e=u[f],u.hasOwnProperty(f)&&e!=null&&!a.hasOwnProperty(f))switch(f){case"value":break;case"children":break;default:nl(l,t,f,null,a,e)}for(c in a)if(e=a[c],n=u[c],a.hasOwnProperty(c)&&(e!=null||n!=null))switch(c){case"value":y=e;break;case"defaultValue":r=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(m(91));break;default:e!==n&&nl(l,t,c,e,a,n)}Ti(l,y,r);return;case"option":for(var Y in u)if(y=u[Y],u.hasOwnProperty(Y)&&y!=null&&!a.hasOwnProperty(Y))switch(Y){case"selected":l.selected=!1;break;default:nl(l,t,Y,null,a,y)}for(i in a)if(y=a[i],r=u[i],a.hasOwnProperty(i)&&y!==r&&(y!=null||r!=null))switch(i){case"selected":l.selected=y&&typeof y!="function"&&typeof y!="symbol";break;default:nl(l,t,i,y,a,r)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var C in u)y=u[C],u.hasOwnProperty(C)&&y!=null&&!a.hasOwnProperty(C)&&nl(l,t,C,null,a,y);for(h in a)if(y=a[h],r=u[h],a.hasOwnProperty(h)&&y!==r&&(y!=null||r!=null))switch(h){case"children":case"dangerouslySetInnerHTML":if(y!=null)throw Error(m(137,t));break;default:nl(l,t,h,y,a,r)}return;default:if(Wn(t)){for(var cl in u)y=u[cl],u.hasOwnProperty(cl)&&y!==void 0&&!a.hasOwnProperty(cl)&&Cf(l,t,cl,void 0,a,y);for(g in a)y=a[g],r=u[g],!a.hasOwnProperty(g)||y===r||y===void 0&&r===void 0||Cf(l,t,g,y,a,r);return}}for(var o in u)y=u[o],u.hasOwnProperty(o)&&y!=null&&!a.hasOwnProperty(o)&&nl(l,t,o,null,a,y);for(E in a)y=a[E],r=u[E],!a.hasOwnProperty(E)||y===r||y==null&&r==null||nl(l,t,E,y,a,r)}var qf=null,xf=null;function Tn(l){return l.nodeType===9?l:l.ownerDocument}function z1(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function _1(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function jf(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Yf=null;function I4(){var l=window.event;return l&&l.type==="popstate"?l===Yf?!1:(Yf=l,!0):(Yf=null,!1)}var O1=typeof setTimeout=="function"?setTimeout:void 0,ld=typeof clearTimeout=="function"?clearTimeout:void 0,M1=typeof Promise=="function"?Promise:void 0,td=typeof queueMicrotask=="function"?queueMicrotask:typeof M1<"u"?function(l){return M1.resolve(null).then(l).catch(ud)}:O1;function ud(l){setTimeout(function(){throw l})}function fu(l){return l==="head"}function D1(l,t){var u=t,a=0,e=0;do{var n=u.nextSibling;if(l.removeChild(u),n&&n.nodeType===8)if(u=n.data,u==="/$"){if(0<a&&8>a){u=a;var c=l.ownerDocument;if(u&1&&fe(c.documentElement),u&2&&fe(c.body),u&4)for(u=c.head,fe(u),c=u.firstChild;c;){var f=c.nextSibling,i=c.nodeName;c[Aa]||i==="SCRIPT"||i==="STYLE"||i==="LINK"&&c.rel.toLowerCase()==="stylesheet"||u.removeChild(c),c=f}}if(e===0){l.removeChild(n),re(t);return}e--}else u==="$"||u==="$?"||u==="$!"?e++:a=u.charCodeAt(0)-48;else a=0;u=n}while(u);re(t)}function Bf(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var u=t;switch(t=t.nextSibling,u.nodeName){case"HTML":case"HEAD":case"BODY":Bf(u),Qn(u);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(u.rel.toLowerCase()==="stylesheet")continue}l.removeChild(u)}}function ad(l,t,u,a){for(;l.nodeType===1;){var e=u;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(a){if(!l[Aa])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null||e.href===""?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=St(l.nextSibling),l===null)break}return null}function ed(l,t,u){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!u||(l=St(l.nextSibling),l===null))return null;return l}function Gf(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState==="complete"}function nd(l,t){var u=l.ownerDocument;if(l.data!=="$?"||u.readyState==="complete")t();else{var a=function(){t(),u.removeEventListener("DOMContentLoaded",a)};u.addEventListener("DOMContentLoaded",a),l._reactRetry=a}}function St(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return l}var Xf=null;function U1(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var u=l.data;if(u==="$"||u==="$!"||u==="$?"){if(t===0)return l;t--}else u==="/$"&&t++}l=l.previousSibling}return null}function R1(l,t,u){switch(t=Tn(u),l){case"html":if(l=t.documentElement,!l)throw Error(m(452));return l;case"head":if(l=t.head,!l)throw Error(m(453));return l;case"body":if(l=t.body,!l)throw Error(m(454));return l;default:throw Error(m(451))}}function fe(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);Qn(l)}var ht=new Map,p1=new Set;function An(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Zt=O.d;O.d={f:cd,r:fd,D:id,C:sd,L:dd,m:od,X:hd,S:vd,M:yd};function cd(){var l=Zt.f(),t=hn();return l||t}function fd(l){var t=ju(l);t!==null&&t.tag===5&&t.type==="form"?k0(t):Zt.r(l)}var ma=typeof document>"u"?null:document;function N1(l,t,u){var a=ma;if(a&&typeof t=="string"&&t){var e=ct(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof u=="string"&&(e+='[crossorigin="'+u+'"]'),p1.has(e)||(p1.add(e),l={rel:l,crossOrigin:u,href:t},a.querySelector(e)===null&&(t=a.createElement("link"),Cl(t,"link",l),Ol(t),a.head.appendChild(t)))}}function id(l){Zt.D(l),N1("dns-prefetch",l,null)}function sd(l,t){Zt.C(l,t),N1("preconnect",l,t)}function dd(l,t,u){Zt.L(l,t,u);var a=ma;if(a&&l&&t){var e='link[rel="preload"][as="'+ct(t)+'"]';t==="image"&&u&&u.imageSrcSet?(e+='[imagesrcset="'+ct(u.imageSrcSet)+'"]',typeof u.imageSizes=="string"&&(e+='[imagesizes="'+ct(u.imageSizes)+'"]')):e+='[href="'+ct(l)+'"]';var n=e;switch(t){case"style":n=ga(l);break;case"script":n=Sa(l)}ht.has(n)||(l=R({rel:"preload",href:t==="image"&&u&&u.imageSrcSet?void 0:l,as:t},u),ht.set(n,l),a.querySelector(e)!==null||t==="style"&&a.querySelector(ie(n))||t==="script"&&a.querySelector(se(n))||(t=a.createElement("link"),Cl(t,"link",l),Ol(t),a.head.appendChild(t)))}}function od(l,t){Zt.m(l,t);var u=ma;if(u&&l){var a=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+ct(a)+'"][href="'+ct(l)+'"]',n=e;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Sa(l)}if(!ht.has(n)&&(l=R({rel:"modulepreload",href:l},t),ht.set(n,l),u.querySelector(e)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(u.querySelector(se(n)))return}a=u.createElement("link"),Cl(a,"link",l),Ol(a),u.head.appendChild(a)}}}function vd(l,t,u){Zt.S(l,t,u);var a=ma;if(a&&l){var e=Yu(a).hoistableStyles,n=ga(l);t=t||"default";var c=e.get(n);if(!c){var f={loading:0,preload:null};if(c=a.querySelector(ie(n)))f.loading=5;else{l=R({rel:"stylesheet",href:l,"data-precedence":t},u),(u=ht.get(n))&&Zf(l,u);var i=c=a.createElement("link");Ol(i),Cl(i,"link",l),i._p=new Promise(function(h,g){i.onload=h,i.onerror=g}),i.addEventListener("load",function(){f.loading|=1}),i.addEventListener("error",function(){f.loading|=2}),f.loading|=4,zn(c,t,a)}c={type:"stylesheet",instance:c,count:1,state:f},e.set(n,c)}}}function hd(l,t){Zt.X(l,t);var u=ma;if(u&&l){var a=Yu(u).hoistableScripts,e=Sa(l),n=a.get(e);n||(n=u.querySelector(se(e)),n||(l=R({src:l,async:!0},t),(t=ht.get(e))&&Qf(l,t),n=u.createElement("script"),Ol(n),Cl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function yd(l,t){Zt.M(l,t);var u=ma;if(u&&l){var a=Yu(u).hoistableScripts,e=Sa(l),n=a.get(e);n||(n=u.querySelector(se(e)),n||(l=R({src:l,async:!0,type:"module"},t),(t=ht.get(e))&&Qf(l,t),n=u.createElement("script"),Ol(n),Cl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function H1(l,t,u,a){var e=(e=G.current)?An(e):null;if(!e)throw Error(m(446));switch(l){case"meta":case"title":return null;case"style":return typeof u.precedence=="string"&&typeof u.href=="string"?(t=ga(u.href),u=Yu(e).hoistableStyles,a=u.get(t),a||(a={type:"style",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(u.rel==="stylesheet"&&typeof u.href=="string"&&typeof u.precedence=="string"){l=ga(u.href);var n=Yu(e).hoistableStyles,c=n.get(l);if(c||(e=e.ownerDocument||e,c={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,c),(n=e.querySelector(ie(l)))&&!n._p&&(c.instance=n,c.state.loading=5),ht.has(l)||(u={rel:"preload",as:"style",href:u.href,crossOrigin:u.crossOrigin,integrity:u.integrity,media:u.media,hrefLang:u.hrefLang,referrerPolicy:u.referrerPolicy},ht.set(l,u),n||rd(e,l,u,c.state))),t&&a===null)throw Error(m(528,""));return c}if(t&&a!==null)throw Error(m(529,""));return null;case"script":return t=u.async,u=u.src,typeof u=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Sa(u),u=Yu(e).hoistableScripts,a=u.get(t),a||(a={type:"script",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(m(444,l))}}function ga(l){return'href="'+ct(l)+'"'}function ie(l){return'link[rel="stylesheet"]['+l+"]"}function C1(l){return R({},l,{"data-precedence":l.precedence,precedence:null})}function rd(l,t,u,a){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=l.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),Cl(t,"link",u),Ol(t),l.head.appendChild(t))}function Sa(l){return'[src="'+ct(l)+'"]'}function se(l){return"script[async]"+l}function q1(l,t,u){if(t.count++,t.instance===null)switch(t.type){case"style":var a=l.querySelector('style[data-href~="'+ct(u.href)+'"]');if(a)return t.instance=a,Ol(a),a;var e=R({},u,{"data-href":u.href,"data-precedence":u.precedence,href:null,precedence:null});return a=(l.ownerDocument||l).createElement("style"),Ol(a),Cl(a,"style",e),zn(a,u.precedence,l),t.instance=a;case"stylesheet":e=ga(u.href);var n=l.querySelector(ie(e));if(n)return t.state.loading|=4,t.instance=n,Ol(n),n;a=C1(u),(e=ht.get(e))&&Zf(a,e),n=(l.ownerDocument||l).createElement("link"),Ol(n);var c=n;return c._p=new Promise(function(f,i){c.onload=f,c.onerror=i}),Cl(n,"link",a),t.state.loading|=4,zn(n,u.precedence,l),t.instance=n;case"script":return n=Sa(u.src),(e=l.querySelector(se(n)))?(t.instance=e,Ol(e),e):(a=u,(e=ht.get(n))&&(a=R({},u),Qf(a,e)),l=l.ownerDocument||l,e=l.createElement("script"),Ol(e),Cl(e,"link",a),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(m(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(a=t.instance,t.state.loading|=4,zn(a,u.precedence,l));return t.instance}function zn(l,t,u){for(var a=u.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=a.length?a[a.length-1]:null,n=e,c=0;c<a.length;c++){var f=a[c];if(f.dataset.precedence===t)n=f;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=u.nodeType===9?u.head:u,t.insertBefore(l,t.firstChild))}function Zf(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function Qf(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var _n=null;function x1(l,t,u){if(_n===null){var a=new Map,e=_n=new Map;e.set(u,a)}else e=_n,a=e.get(u),a||(a=new Map,e.set(u,a));if(a.has(l))return a;for(a.set(l,null),u=u.getElementsByTagName(l),e=0;e<u.length;e++){var n=u[e];if(!(n[Aa]||n[jl]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var c=n.getAttribute(t)||"";c=l+c;var f=a.get(c);f?f.push(n):a.set(c,[n])}}return a}function j1(l,t,u){l=l.ownerDocument||l,l.head.insertBefore(u,t==="title"?l.querySelector("head > title"):null)}function md(l,t,u){if(u===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Y1(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}var de=null;function gd(){}function Sd(l,t,u){if(de===null)throw Error(m(475));var a=de;if(t.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&(t.state.loading&4)===0){if(t.instance===null){var e=ga(u.href),n=l.querySelector(ie(e));if(n){l=n._p,l!==null&&typeof l=="object"&&typeof l.then=="function"&&(a.count++,a=On.bind(a),l.then(a,a)),t.state.loading|=4,t.instance=n,Ol(n);return}n=l.ownerDocument||l,u=C1(u),(e=ht.get(e))&&Zf(u,e),n=n.createElement("link"),Ol(n);var c=n;c._p=new Promise(function(f,i){c.onload=f,c.onerror=i}),Cl(n,"link",u),t.instance=n}a.stylesheets===null&&(a.stylesheets=new Map),a.stylesheets.set(t,l),(l=t.state.preload)&&(t.state.loading&3)===0&&(a.count++,t=On.bind(a),l.addEventListener("load",t),l.addEventListener("error",t))}}function bd(){if(de===null)throw Error(m(475));var l=de;return l.stylesheets&&l.count===0&&Vf(l,l.stylesheets),0<l.count?function(t){var u=setTimeout(function(){if(l.stylesheets&&Vf(l,l.stylesheets),l.unsuspend){var a=l.unsuspend;l.unsuspend=null,a()}},6e4);return l.unsuspend=t,function(){l.unsuspend=null,clearTimeout(u)}}:null}function On(){if(this.count--,this.count===0){if(this.stylesheets)Vf(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Mn=null;function Vf(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Mn=new Map,t.forEach(Ed,l),Mn=null,On.call(l))}function Ed(l,t){if(!(t.state.loading&4)){var u=Mn.get(l);if(u)var a=u.get(null);else{u=new Map,Mn.set(l,u);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var c=e[n];(c.nodeName==="LINK"||c.getAttribute("media")!=="not all")&&(u.set(c.dataset.precedence,c),a=c)}a&&u.set(null,a)}e=t.instance,c=e.getAttribute("data-precedence"),n=u.get(c)||a,n===a&&u.set(null,e),u.set(c,e),this.count++,a=On.bind(this),e.addEventListener("load",a),e.addEventListener("error",a),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var oe={$$typeof:_l,Provider:null,Consumer:null,_currentValue:j,_currentValue2:j,_threadCount:0};function Td(l,t,u,a,e,n,c,f){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Bn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Bn(0),this.hiddenUpdates=Bn(null),this.identifierPrefix=a,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=c,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=f,this.incompleteTransitions=new Map}function B1(l,t,u,a,e,n,c,f,i,h,g,E){return l=new Td(l,t,u,c,f,i,h,E),t=1,n===!0&&(t|=24),n=Il(3,null,null,t),l.current=n,n.stateNode=l,t=zc(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:a,isDehydrated:u,cache:t},Dc(n),l}function G1(l){return l?(l=$u,l):$u}function X1(l,t,u,a,e,n){e=G1(e),a.context===null?a.context=e:a.pendingContext=e,a=Wt(t),a.payload={element:u},n=n===void 0?null:n,n!==null&&(a.callback=n),u=$t(l,a,t),u!==null&&(et(u,l,t),Za(u,l,t))}function Z1(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var u=l.retryLane;l.retryLane=u!==0&&u<t?u:t}}function Lf(l,t){Z1(l,t),(l=l.alternate)&&Z1(l,t)}function Q1(l){if(l.tag===13){var t=Wu(l,67108864);t!==null&&et(t,l,67108864),Lf(l,67108864)}}var Dn=!0;function Ad(l,t,u,a){var e=S.T;S.T=null;var n=O.p;try{O.p=2,Kf(l,t,u,a)}finally{O.p=n,S.T=e}}function zd(l,t,u,a){var e=S.T;S.T=null;var n=O.p;try{O.p=8,Kf(l,t,u,a)}finally{O.p=n,S.T=e}}function Kf(l,t,u,a){if(Dn){var e=Jf(a);if(e===null)Hf(l,t,a,Un,u),L1(l,a);else if(Od(e,l,t,u,a))a.stopPropagation();else if(L1(l,a),t&4&&-1<_d.indexOf(l)){for(;e!==null;){var n=ju(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var c=ru(n.pendingLanes);if(c!==0){var f=n;for(f.pendingLanes|=2,f.entangledLanes|=2;c;){var i=1<<31-Fl(c);f.entanglements[1]|=i,c&=~i}Ot(n),(ul&6)===0&&(on=Et()+500,ee(0))}}break;case 13:f=Wu(n,2),f!==null&&et(f,n,2),hn(),Lf(n,2)}if(n=Jf(a),n===null&&Hf(l,t,a,Un,u),n===e)break;e=n}e!==null&&a.stopPropagation()}else Hf(l,t,a,null,u)}}function Jf(l){return l=kn(l),wf(l)}var Un=null;function wf(l){if(Un=null,l=xu(l),l!==null){var t=B(l);if(t===null)l=null;else{var u=t.tag;if(u===13){if(l=tl(t),l!==null)return l;l=null}else if(u===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return Un=l,null}function V1(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(ss()){case ai:return 2;case ei:return 8;case be:case ds:return 32;case ni:return 268435456;default:return 32}default:return 32}}var Wf=!1,iu=null,su=null,du=null,ve=new Map,he=new Map,ou=[],_d="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function L1(l,t){switch(l){case"focusin":case"focusout":iu=null;break;case"dragenter":case"dragleave":su=null;break;case"mouseover":case"mouseout":du=null;break;case"pointerover":case"pointerout":ve.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":he.delete(t.pointerId)}}function ye(l,t,u,a,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:u,eventSystemFlags:a,nativeEvent:n,targetContainers:[e]},t!==null&&(t=ju(t),t!==null&&Q1(t)),l):(l.eventSystemFlags|=a,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function Od(l,t,u,a,e){switch(t){case"focusin":return iu=ye(iu,l,t,u,a,e),!0;case"dragenter":return su=ye(su,l,t,u,a,e),!0;case"mouseover":return du=ye(du,l,t,u,a,e),!0;case"pointerover":var n=e.pointerId;return ve.set(n,ye(ve.get(n)||null,l,t,u,a,e)),!0;case"gotpointercapture":return n=e.pointerId,he.set(n,ye(he.get(n)||null,l,t,u,a,e)),!0}return!1}function K1(l){var t=xu(l.target);if(t!==null){var u=B(t);if(u!==null){if(t=u.tag,t===13){if(t=tl(u),t!==null){l.blockedOn=t,Ss(l.priority,function(){if(u.tag===13){var a=at();a=Gn(a);var e=Wu(u,a);e!==null&&et(e,u,a),Lf(u,a)}});return}}else if(t===3&&u.stateNode.current.memoizedState.isDehydrated){l.blockedOn=u.tag===3?u.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Rn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var u=Jf(l.nativeEvent);if(u===null){u=l.nativeEvent;var a=new u.constructor(u.type,u);$n=a,u.target.dispatchEvent(a),$n=null}else return t=ju(u),t!==null&&Q1(t),l.blockedOn=u,!1;t.shift()}return!0}function J1(l,t,u){Rn(l)&&u.delete(t)}function Md(){Wf=!1,iu!==null&&Rn(iu)&&(iu=null),su!==null&&Rn(su)&&(su=null),du!==null&&Rn(du)&&(du=null),ve.forEach(J1),he.forEach(J1)}function pn(l,t){l.blockedOn===t&&(l.blockedOn=null,Wf||(Wf=!0,z.unstable_scheduleCallback(z.unstable_NormalPriority,Md)))}var Nn=null;function w1(l){Nn!==l&&(Nn=l,z.unstable_scheduleCallback(z.unstable_NormalPriority,function(){Nn===l&&(Nn=null);for(var t=0;t<l.length;t+=3){var u=l[t],a=l[t+1],e=l[t+2];if(typeof a!="function"){if(wf(a||u)===null)continue;break}var n=ju(u);n!==null&&(l.splice(t,3),t-=3,Jc(n,{pending:!0,data:e,method:u.method,action:a},a,e))}}))}function re(l){function t(i){return pn(i,l)}iu!==null&&pn(iu,l),su!==null&&pn(su,l),du!==null&&pn(du,l),ve.forEach(t),he.forEach(t);for(var u=0;u<ou.length;u++){var a=ou[u];a.blockedOn===l&&(a.blockedOn=null)}for(;0<ou.length&&(u=ou[0],u.blockedOn===null);)K1(u),u.blockedOn===null&&ou.shift();if(u=(l.ownerDocument||l).$$reactFormReplay,u!=null)for(a=0;a<u.length;a+=3){var e=u[a],n=u[a+1],c=e[Zl]||null;if(typeof n=="function")c||w1(u);else if(c){var f=null;if(n&&n.hasAttribute("formAction")){if(e=n,c=n[Zl]||null)f=c.formAction;else if(wf(e)!==null)continue}else f=c.action;typeof f=="function"?u[a+1]=f:(u.splice(a,3),a-=3),w1(u)}}}function $f(l){this._internalRoot=l}Hn.prototype.render=$f.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(m(409));var u=t.current,a=at();X1(u,a,l,t,null,null)},Hn.prototype.unmount=$f.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;X1(l.current,2,null,l,null,null),hn(),t[qu]=null}};function Hn(l){this._internalRoot=l}Hn.prototype.unstable_scheduleHydration=function(l){if(l){var t=di();l={blockedOn:null,target:l,priority:t};for(var u=0;u<ou.length&&t!==0&&t<ou[u].priority;u++);ou.splice(u,0,l),u===0&&K1(l)}};var W1=P.version;if(W1!=="19.1.1")throw Error(m(527,W1,"19.1.1"));O.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(m(188)):(l=Object.keys(l).join(","),Error(m(268,l)));return l=U(t),l=l!==null?T(l):null,l=l===null?null:l.stateNode,l};var Dd={bundleType:0,version:"19.1.1",rendererPackageName:"react-dom",currentDispatcherRef:S,reconcilerVersion:"19.1.1"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Cn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Cn.isDisabled&&Cn.supportsFiber)try{ba=Cn.inject(Dd),kl=Cn}catch{}}return ge.createRoot=function(l,t){if(!X(l))throw Error(m(299));var u=!1,a="",e=d2,n=o2,c=v2,f=null;return t!=null&&(t.unstable_strictMode===!0&&(u=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(c=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(f=t.unstable_transitionCallbacks)),t=B1(l,1,!1,null,null,u,a,e,n,c,f,null),l[qu]=t.current,Nf(l),new $f(t)},ge.hydrateRoot=function(l,t,u){if(!X(l))throw Error(m(299));var a=!1,e="",n=d2,c=o2,f=v2,i=null,h=null;return u!=null&&(u.unstable_strictMode===!0&&(a=!0),u.identifierPrefix!==void 0&&(e=u.identifierPrefix),u.onUncaughtError!==void 0&&(n=u.onUncaughtError),u.onCaughtError!==void 0&&(c=u.onCaughtError),u.onRecoverableError!==void 0&&(f=u.onRecoverableError),u.unstable_transitionCallbacks!==void 0&&(i=u.unstable_transitionCallbacks),u.formState!==void 0&&(h=u.formState)),t=B1(l,1,!0,t,u??null,a,e,n,c,f,i,h),t.context=G1(null),u=t.current,a=at(),a=Gn(a),e=Wt(a),e.callback=null,$t(u,e,a),u=a,t.current.lanes=u,Ta(t,u),Ot(t),l[qu]=t.current,Nf(l),new Hn(t)},ge.version="19.1.1",ge}var es;function Yd(){if(es)return Pf.exports;es=1;function z(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(z)}catch(P){console.error(P)}}return z(),Pf.exports=jd(),Pf.exports}var Bd=Yd();const Gd="data:image/svg+xml,%3csvg%20width='490'%20height='190'%20viewBox='0%200%20490%20190'%20fill='none'%20xmlns='http://www.w3.org/2000/svg'%3e%3cg%20clip-path='url(%23clip0_33_23)'%3e%3cpath%20d='M455.26%20148.48C444.41%20148.48%20436.47%20139.69%20436.47%20128.84V82.57H423.04V61.9H437.55L437.33%2040.92L459.04%2033.41V61.91H477.82V82.58H459.04V127.43H475.67V148.49H455.25L455.26%20148.48Z'%20fill='black'/%3e%3cpath%20d='M381.33%20149.48C369.96%20149.48%20361.35%20145.8%20355.14%20135.81L353.94%20135.98C354.11%20140.29%20354.28%20144.03%20354.28%20148.51H331.37V33.53L354.63%2025.67V53.97C354.63%2062.24%20354.63%2066.72%20353.77%2074.47L355.15%2074.81C361.53%2064.47%20371%2059.82%20382.03%2059.82C405.46%2059.82%20420.1%2079.8%20420.1%20105.3C420.1%20130.8%20404.94%20149.46%20381.34%20149.46L381.33%20149.48ZM375.82%20128.63C388.74%20128.63%20397.01%20118.92%20397.01%20104.97C397.01%2091.02%20388.74%2080.68%20375.82%2080.68C362.9%2080.68%20354.12%2090.84%20354.12%20105.14C354.12%20119.44%20362.56%20128.63%20375.82%20128.63Z'%20fill='black'/%3e%3cpath%20d='M262.51%20149.48C239.6%20149.48%20224.44%20130.13%20224.44%20104.97C224.44%2079.81%20239.43%2059.83%20263.37%2059.83C274.22%2059.83%20283.36%2064.14%20289.56%2074.3L290.76%2073.96C290.07%2066.72%20290.07%2061.73%20290.07%2053.98V33.54L313.33%2025.68V148.52H290.42C290.42%20144.21%20290.42%20140.29%20290.76%20135.98L289.56%20135.64C283.18%20145.8%20273.88%20149.48%20262.51%20149.48ZM268.88%20128.63C282.15%20128.63%20290.59%20119.27%20290.59%20104.97C290.59%2090.67%20282.15%2080.68%20268.88%2080.68C255.79%2080.85%20247.69%2091.19%20247.69%20105.14C247.69%20119.09%20255.79%20128.63%20268.88%20128.63Z'%20fill='black'/%3e%3cpath%20d='M485.216%20148.816C482.608%20148.816%20480.8%20146.976%20480.8%20144.368C480.8%20141.776%20482.624%20139.92%20485.216%20139.92C487.808%20139.92%20489.632%20141.776%20489.632%20144.368C489.632%20146.976%20487.824%20148.816%20485.216%20148.816ZM485.216%20148.032C487.328%20148.032%20488.752%20146.48%20488.752%20144.368C488.752%20142.256%20487.328%20140.72%20485.216%20140.72C483.104%20140.72%20481.68%20142.256%20481.68%20144.368C481.68%20146.48%20483.104%20148.032%20485.216%20148.032ZM483.744%20146.56V142.112H485.52C486.448%20142.112%20486.928%20142.64%20486.928%20143.424C486.928%20144.144%20486.448%20144.656%20485.696%20144.656H485.664L487.2%20146.544V146.56H486.144L484.592%20144.608H484.576V146.56H483.744ZM484.576%20144.064H485.408C485.84%20144.064%20486.08%20143.808%20486.08%20143.44C486.08%20143.088%20485.824%20142.848%20485.408%20142.848H484.576V144.064Z'%20fill='black'/%3e%3cpath%20d='M158.184%202.16438C166.564%20-2.6797%20175.59%201.19557%20182.359%207.97729C189.45%2015.082%20192.351%2022.8325%20187.839%2031.5518C186.227%2034.7812%20167.209%2067.721%20161.407%2077.0863C158.184%2082.2533%20156.572%2088.7121%20156.572%2094.8479C156.572%20100.984%20158.184%20107.443%20161.407%20112.933C167.209%20121.975%20186.227%20155.238%20187.839%20158.467C192.351%20167.509%20189.128%20174.291%20182.681%20181.396C175.267%20188.823%20167.854%20192.698%20158.828%20187.854C155.605%20185.917%2065.3511%20133.924%2065.3511%20133.924C66.9627%20144.581%2072.7648%20154.269%2080.1785%20160.082C79.2115%20160.405%2034.5761%20186.232%2031.5058%20187.854C23.0444%20192.326%2015.3286%20189.336%208.62001%20183.01C1.04465%20175.867%20-2.66173%20167.509%202.1733%20158.79C3.78498%20155.56%2022.8028%20122.298%2028.2825%20113.255C31.5058%20107.765%2033.4398%20101.63%2033.4398%2095.1709C33.4398%2088.7121%2031.5058%2082.5762%2028.2825%2077.4092C22.8028%2067.721%203.78498%2034.1354%202.1733%2031.2289C-2.66173%2022.5096%201.22016%2013.1436%207.97534%207.00847C15.6327%200.0538926%2022.8028%20-2.03382%2031.5058%202.16438C34.0845%203.1332%20124.016%2056.4182%20124.016%2056.4182C123.049%2046.0841%20117.892%2036.7189%20109.511%2030.2601C110.156%2029.9372%20154.96%203.45614%20158.184%202.16438ZM98.2293%20110.995L111.123%2098.0773C112.734%2096.4626%20112.734%2093.8791%20111.123%2091.9415L98.2293%2079.0239C96.2953%2077.0863%2093.7166%2077.0863%2091.7826%2079.0239L78.8892%2091.9415C77.2775%2093.5562%2077.2775%2096.4626%2078.8892%2098.0773L91.7826%20110.995C93.3942%20112.61%2096.2953%20112.61%2098.2293%20110.995Z'%20fill='%23FE6703'/%3e%3c/g%3e%3cdefs%3e%3cclipPath%20id='clip0_33_23'%3e%3crect%20width='490'%20height='190'%20fill='white'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e",Xd="data:image/svg+xml,%3csvg%20width='490'%20height='190'%20viewBox='0%200%20490%20190'%20fill='none'%20xmlns='http://www.w3.org/2000/svg'%3e%3cg%20clip-path='url(%23clip0_33_49)'%3e%3cpath%20d='M455.26%20148.48C444.41%20148.48%20436.47%20139.69%20436.47%20128.84V82.57H423.04V61.9H437.55L437.33%2040.92L459.04%2033.41V61.91H477.82V82.58H459.04V127.43H475.67V148.49H455.25L455.26%20148.48Z'%20fill='white'/%3e%3cpath%20d='M381.33%20149.48C369.96%20149.48%20361.35%20145.8%20355.14%20135.81L353.94%20135.98C354.11%20140.29%20354.28%20144.03%20354.28%20148.51H331.37V33.53L354.63%2025.67V53.97C354.63%2062.24%20354.63%2066.72%20353.77%2074.47L355.15%2074.81C361.53%2064.47%20371%2059.82%20382.03%2059.82C405.46%2059.82%20420.1%2079.8%20420.1%20105.3C420.1%20130.8%20404.94%20149.46%20381.34%20149.46L381.33%20149.48ZM375.82%20128.63C388.74%20128.63%20397.01%20118.92%20397.01%20104.97C397.01%2091.02%20388.74%2080.68%20375.82%2080.68C362.9%2080.68%20354.12%2090.84%20354.12%20105.14C354.12%20119.44%20362.56%20128.63%20375.82%20128.63Z'%20fill='white'/%3e%3cpath%20d='M262.51%20149.48C239.6%20149.48%20224.44%20130.13%20224.44%20104.97C224.44%2079.81%20239.43%2059.83%20263.37%2059.83C274.22%2059.83%20283.36%2064.14%20289.56%2074.3L290.76%2073.96C290.07%2066.72%20290.07%2061.73%20290.07%2053.98V33.54L313.33%2025.68V148.52H290.42C290.42%20144.21%20290.42%20140.29%20290.76%20135.98L289.56%20135.64C283.18%20145.8%20273.88%20149.48%20262.51%20149.48ZM268.88%20128.63C282.15%20128.63%20290.59%20119.27%20290.59%20104.97C290.59%2090.67%20282.15%2080.68%20268.88%2080.68C255.79%2080.85%20247.69%2091.19%20247.69%20105.14C247.69%20119.09%20255.79%20128.63%20268.88%20128.63Z'%20fill='white'/%3e%3cpath%20d='M485.216%20148.816C482.608%20148.816%20480.8%20146.976%20480.8%20144.368C480.8%20141.776%20482.624%20139.92%20485.216%20139.92C487.808%20139.92%20489.632%20141.776%20489.632%20144.368C489.632%20146.976%20487.824%20148.816%20485.216%20148.816ZM485.216%20148.032C487.328%20148.032%20488.752%20146.48%20488.752%20144.368C488.752%20142.256%20487.328%20140.72%20485.216%20140.72C483.104%20140.72%20481.68%20142.256%20481.68%20144.368C481.68%20146.48%20483.104%20148.032%20485.216%20148.032ZM483.744%20146.56V142.112H485.52C486.448%20142.112%20486.928%20142.64%20486.928%20143.424C486.928%20144.144%20486.448%20144.656%20485.696%20144.656H485.664L487.2%20146.544V146.56H486.144L484.592%20144.608H484.576V146.56H483.744ZM484.576%20144.064H485.408C485.84%20144.064%20486.08%20143.808%20486.08%20143.44C486.08%20143.088%20485.824%20142.848%20485.408%20142.848H484.576V144.064Z'%20fill='white'/%3e%3cpath%20d='M158.184%202.16438C166.564%20-2.6797%20175.59%201.19557%20182.359%207.97729C189.45%2015.082%20192.351%2022.8325%20187.839%2031.5518C186.227%2034.7812%20167.209%2067.721%20161.407%2077.0863C158.184%2082.2533%20156.572%2088.7121%20156.572%2094.8479C156.572%20100.984%20158.184%20107.443%20161.407%20112.933C167.209%20121.975%20186.227%20155.238%20187.839%20158.467C192.351%20167.509%20189.128%20174.291%20182.681%20181.396C175.267%20188.823%20167.854%20192.698%20158.828%20187.854C155.605%20185.917%2065.3511%20133.924%2065.3511%20133.924C66.9627%20144.581%2072.7648%20154.269%2080.1785%20160.082C79.2115%20160.405%2034.5761%20186.232%2031.5058%20187.854C23.0444%20192.326%2015.3286%20189.336%208.62001%20183.01C1.04465%20175.867%20-2.66173%20167.509%202.1733%20158.79C3.78498%20155.56%2022.8028%20122.298%2028.2825%20113.255C31.5058%20107.765%2033.4398%20101.63%2033.4398%2095.1709C33.4398%2088.7121%2031.5058%2082.5762%2028.2825%2077.4092C22.8028%2067.721%203.78498%2034.1354%202.1733%2031.2289C-2.66173%2022.5096%201.22016%2013.1436%207.97534%207.00847C15.6327%200.0538926%2022.8028%20-2.03382%2031.5058%202.16438C34.0845%203.1332%20124.016%2056.4182%20124.016%2056.4182C123.049%2046.0841%20117.892%2036.7189%20109.511%2030.2601C110.156%2029.9372%20154.96%203.45614%20158.184%202.16438ZM98.2293%20110.995L111.123%2098.0773C112.734%2096.4626%20112.734%2093.8791%20111.123%2091.9415L98.2293%2079.0239C96.2953%2077.0863%2093.7166%2077.0863%2091.7826%2079.0239L78.8892%2091.9415C77.2775%2093.5562%2077.2775%2096.4626%2078.8892%2098.0773L91.7826%20110.995C93.3942%20112.61%2096.2953%20112.61%2098.2293%20110.995Z'%20fill='%23FE6703'/%3e%3c/g%3e%3cdefs%3e%3cclipPath%20id='clip0_33_49'%3e%3crect%20width='490'%20height='190'%20fill='white'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e";function Zd(){const z=window.location.hash.startsWith("#")?window.location.hash.slice(1):window.location.hash,P=z.startsWith("?")?z.slice(1):z;return new URLSearchParams(P)}function Qd(){return Xl.useMemo(()=>Zd(),[]).get("status")}function Vd({value:z,onChange:P,options:J,placeholder:m,id:X}){const[B,tl]=Xl.useState(!1),yl=Xl.useRef(null),U=Xl.useRef(null);Xl.useEffect(()=>{function q(dl){yl.current&&!yl.current.contains(dl.target)&&tl(!1)}if(B)return document.addEventListener("mousedown",q),()=>{document.removeEventListener("mousedown",q)}},[B]),Xl.useEffect(()=>{function q(dl){if(!B){(dl.key==="Enter"||dl.key===" "||dl.key==="ArrowDown")&&(dl.preventDefault(),tl(!0));return}dl.key==="Escape"&&(tl(!1),U.current?.focus())}if(U.current?.contains(document.activeElement))return document.addEventListener("keydown",q),()=>{document.removeEventListener("keydown",q)}},[B]);const T=J.find(q=>q.id===z),R=()=>{tl(!B)},w=q=>{P(q.id.toString()),tl(!1),U.current?.focus()};return N.jsxs("div",{className:"custom-dropdown",ref:yl,children:[N.jsx("button",{ref:U,id:X,type:"button",className:`dropdown-trigger ${B?"open":""} ${T?"":"placeholder"}`,onClick:R,"aria-haspopup":"listbox","aria-expanded":B,"aria-labelledby":`${X}-label`,children:T?N.jsxs(N.Fragment,{children:[N.jsx("div",{className:"option-primary",children:T.name}),N.jsx("div",{className:"option-secondary",children:T.account_name})]}):m}),B&&N.jsx("div",{ref:yl,className:"dropdown-options",role:"listbox","aria-labelledby":`${X}-label`,children:J.map(q=>N.jsxs("button",{type:"button",className:`dropdown-option ${q.id===z?"selected":""}`,onClick:()=>w(q),role:"option","aria-selected":q.id===z,children:[N.jsx("div",{className:"option-primary",children:q.name}),N.jsx("div",{className:"option-secondary",children:q.account_name})]},`${q.account_id}-${q.id}`))})]})}function Ld(){const z=Qd(),[P,J]=Xl.useState(null),[m,X]=Xl.useState([]),[B,tl]=Xl.useState(null),[yl,U]=Xl.useState(!1),[T,R]=Xl.useState(""),[w,q]=Xl.useState(null);Xl.useEffect(()=>{z==="success"&&(U(!0),tl(null),fetch("/projects").then(async I=>{if(!I.ok)throw new Error(`Failed to load projects (${I.status})`);return I.json()}).then(I=>{X(I)}).catch(I=>{const ol=I instanceof Error?I.message:String(I);tl(ol)}).finally(()=>U(!1)))},[z]),Xl.useEffect(()=>{z==="success"&&(async()=>{try{const I=await fetch("/dbt_platform_context");if(!I.ok)return;const ol=await I.json();q(ol)}catch{}})()},[z]);const dl=async()=>{try{const I=await fetch("/shutdown",{method:"POST"}),ol=await I.text();I.ok?window.close():J(ol)}catch(I){J(String(I))}},Rl=async I=>{q(null);const ol=Number(I);R(Number.isNaN(ol)?"":ol);const yt=m.find(pl=>pl.id===ol);if(yt)try{const pl=await fetch("/selected_project",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({account_id:yt.account_id,project_id:yt.id})});if(pl.ok){const _l=await pl.json();q(_l)}else J(await pl.text()),q(null)}catch(pl){J(String(pl)),q(null)}};return N.jsxs("div",{className:"app-container",children:[N.jsxs("div",{className:"logo-container",children:[N.jsx("img",{src:Gd,alt:"dbt",className:"logo logo-light"}),N.jsx("img",{src:Xd,alt:"dbt",className:"logo logo-dark"})]}),N.jsxs("div",{className:"app-content",children:[N.jsxs("header",{className:"app-header",children:[N.jsx("h1",{children:"dbt Platform Setup"}),N.jsx("p",{children:"Configure your dbt Platform connection"})]}),z==="success"&&N.jsxs("section",{className:"project-selection-section",children:[N.jsxs("div",{className:"section-header",children:[N.jsx("h2",{children:"Select a Project"}),N.jsx("p",{children:"Choose the dbt project you want to work with"})]}),N.jsxs("div",{className:"form-content",children:[yl&&N.jsxs("div",{className:"loading-state",children:[N.jsx("div",{className:"spinner"}),N.jsx("span",{children:"Loading projects…"})]}),B&&N.jsxs("div",{className:"error-state",children:[N.jsx("strong",{children:"Error loading projects"}),N.jsx("p",{children:B})]}),!yl&&!B&&N.jsxs("div",{className:"form-group",children:[N.jsx("label",{htmlFor:"project-select",className:"form-label",id:"project-select-label",children:"Available Projects"}),N.jsx(Vd,{id:"project-select",value:T,onChange:Rl,options:m,placeholder:"Choose a project"})]})]})]}),w&&N.jsxs("section",{className:"context-section",children:[N.jsxs("div",{className:"section-header",children:[N.jsx("h2",{children:"Current Configuration"}),N.jsx("p",{children:"Your dbt Platform context is ready"})]}),N.jsxs("div",{className:"context-details",children:[N.jsxs("div",{className:"context-item",children:[N.jsx("strong",{children:"User ID:"})," ",w.decoded_access_token?.decoded_claims.sub]}),w.dev_environment&&N.jsxs("div",{className:"context-item",children:[N.jsx("strong",{children:"Development Environment:"}),N.jsx("div",{className:"environment-details",children:N.jsx("span",{className:"env-name",children:w.dev_environment.name})})]}),w.prod_environment&&N.jsxs("div",{className:"context-item",children:[N.jsx("strong",{children:"Production Environment:"}),N.jsx("div",{className:"environment-details",children:N.jsx("span",{className:"env-name",children:w.prod_environment.name})})]})]})]}),w&&N.jsx("div",{className:"button-container",children:N.jsx("button",{onClick:dl,className:"primary-button",children:"Continue"})}),P&&N.jsxs("section",{className:"response-section",children:[N.jsx("div",{className:"section-header",children:N.jsx("h3",{children:"Response"})}),N.jsx("pre",{className:"response-text",children:P})]})]})]})}Bd.createRoot(document.getElementById("root")).render(N.jsx(Xl.StrictMode,{children:N.jsx(Ld,{})}));let ns=!1;const cs=()=>{if(ns)return;ns=!0;const z="/shutdown";try{if("sendBeacon"in navigator){const P=new Blob([""],{type:"text/plain"});navigator.sendBeacon(z,P)}else fetch(z,{method:"POST",keepalive:!0}).catch(()=>{})}catch{}};window.addEventListener("pagehide",cs);window.addEventListener("beforeunload",cs);
